:root {
  --blue-1: $blue_1;
  --blue-2: $blue_2;
  --blue-3: $blue_3;
  --blue-4: $blue_4;
  --blue-5: $blue_5;
  --green-1: $green-1;
  --green-2: $green-2;
  --green-3: $green-3;
  --green-4: $green-4;
  --green-5: $green-5;
  --yellow-1: $yellow-1;
  --yellow-2: $yellow-2;
  --yellow-3: $yellow-3;
  --yellow-4: $yellow-4;
  --yellow-5: $yellow-5;
  --orange-1: $orange-1;
  --orange-2: $orange-2;
  --orange-3: $orange-3;
  --orange-4: $orange-4;
  --orange-5: $orange-5;
  --red-1: $red-1;
  --red-2: $red-2;
  --red-3: $red-3;
  --red-4: $red-4;
  --red-5: $red-5;
  --purple-1: $purple-1;
  --purple-2: $purple-2;
  --purple-3: $purple-3;
  --purple-4: $purple-4;
  --purple-5: $purple-5;
  --brown-1: $brown-1;
  --brown-2: $brown-2;
  --brown-3: $brown-3;
  --brown-4: $brown-4;
  --brown-5: $brown-5;
  --light-1: $light-1;
  --light-2: $light-2;
  --light-3: $light-3;
  --light-4: $light-4;
  --light-5: $light-5;
  --dark-1: $dark-1;
  --dark-2: $dark-2;
  --dark-3: $dark-3;
  --dark-4: $dark-4;
  --dark-5: $dark-5;
}

@define-color blue_1 #99c1f1;
@define-color blue_2 #62a0ea;
@define-color blue_3 #3281EA;
@define-color blue_4 #1c71d8;
@define-color blue_5 #1a5fb4;
@define-color green_1 #8ff0a4;
@define-color green_2 #57e389;
@define-color green_3 #33d17a;
@define-color green_4 #2ec27e;
@define-color green_5 #26a269;
@define-color yellow_1 #f9f06b;
@define-color yellow_2 #f8e45c;
@define-color yellow_3 #f6d32d;
@define-color yellow_4 #f5c211;
@define-color yellow_5 #e5a50a;
@define-color orange_1 #ffbe6f;
@define-color orange_2 #ffa348;
@define-color orange_3 #ff7800;
@define-color orange_4 #e66100;
@define-color orange_5 #c64600;
@define-color red_1 #f66151;
@define-color red_2 #ed333b;
@define-color red_3 #e01b24;
@define-color red_4 #c01c28;
@define-color red_5 #a51d2d;
@define-color purple_1 #dc8add;
@define-color purple_2 #c061cb;
@define-color purple_3 #9141ac;
@define-color purple_4 #813d9c;
@define-color purple_5 #613583;
@define-color brown_1 #cdab8f;
@define-color brown_2 #b5835a;
@define-color brown_3 #986a44;
@define-color brown_4 #865e3c;
@define-color brown_5 #63452c;
@define-color light_1 #ffffff;
@define-color light_2 #f6f5f4;
@define-color light_3 #deddda;
@define-color light_4 #c0bfbc;
@define-color light_5 #9a9996;
@define-color dark_1 #77767b;
@define-color dark_2 #5e5c64;
@define-color dark_3 #3d3846;
@define-color dark_4 #241f31;
@define-color dark_5 #000000;
/* GTK NAMED COLORS
   ----------------
   use responsibly! */
@define-color accent_bg_color #3281EA;
@define-color accent_fg_color white;
@define-color accent_color #3281EA;
@define-color destructive_bg_color #F44336;
@define-color destructive_fg_color white;
@define-color destructive_color #F44336;
@define-color success_bg_color #81C995;
@define-color success_fg_color rgba(0, 0, 0, 0.87);
@define-color success_color #81C995;
@define-color warning_bg_color #FBC02D;
@define-color warning_fg_color rgba(0, 0, 0, 0.87);
@define-color warning_color #FBC02D;
@define-color error_bg_color #F44336;
@define-color error_fg_color white;
@define-color error_color #F44336;
@define-color window_bg_color #212121;
@define-color window_fg_color white;
@define-color view_bg_color #2C2C2C;
@define-color view_fg_color white;
@define-color headerbar_bg_color #2C2C2C;
@define-color headerbar_fg_color white;
@define-color headerbar_border_color rgba(255, 255, 255, 0.12);
@define-color headerbar_backdrop_color #3C3C3C;
@define-color headerbar_shade_color rgba(255, 255, 255, 0.12);
@define-color card_bg_color #2C2C2C;
@define-color card_fg_color white;
@define-color card_shade_color rgba(255, 255, 255, 0.12);
@define-color dialog_bg_color #242424;
@define-color dialog_fg_color white;
@define-color popover_bg_color #3C3C3C;
@define-color popover_fg_color white;
@define-color shade_color rgba(255, 255, 255, 0.12);
@define-color scrollbar_outline_color rgba(255, 255, 255, 0.12);
@keyframes ripple {
  from {
    background-image: radial-gradient(circle farthest-corner at center, alpha(currentColor, 0.1) 30%, transparent 0%);
  }
  to {
    background-image: radial-gradient(circle farthest-corner at center, alpha(currentColor, 0.1) 100%, transparent 0%);
  }
}

@keyframes ripple-on-slider {
  from {
    background-image: radial-gradient(circle farthest-corner at center, alpha(currentColor, 0.12) 0%, transparent 0%);
  }
  to {
    background-image: radial-gradient(circle farthest-corner at center, alpha(currentColor, 0.12) 100%, transparent 0%);
  }
}

@keyframes ripple-on-headerbar {
  from {
    background-image: radial-gradient(circle farthest-corner at center, #3281EA 30%, transparent 0%);
  }
  to {
    background-image: radial-gradient(circle farthest-corner at center, #3281EA 100%, transparent 0%);
  }
}

/***************
 * Base States *
 ***************/
.background {
  background-color: #212121;
  color: white;
}

dnd {
  color: white;
}

.normal-icons {
  -gtk-icon-size: 16px;
}

.large-icons {
  -gtk-icon-size: 32px;
}

.lowres-icon:not(.large-icons) {
  -gtk-icon-size: 16px;
}

.symbolic-circular {
  background-color: rgba(255, 255, 255, 0.04);
  border-radius: 9999px;
  padding: 0;
  min-height: 32px;
  min-width: 32px;
}

spinner:disabled,
arrow:disabled,
scrollbar:disabled,
check:disabled,
radio:disabled,
treeview.expander:disabled {
  -gtk-icon-filter: opacity(0.5);
}

iconview, .view {
  background-color: #2C2C2C;
  color: white;
}

iconview:disabled, .view:disabled {
  color: rgba(255, 255, 255, 0.5);
}

textview text {
  background-color: #2C2C2C;
}

textview border {
  background-color: #242424;
  color: rgba(255, 255, 255, 0.7);
}

iconview:hover, iconview:selected {
  border-radius: 6px;
}

rubberband, .content-view rubberband, .content-view columnview.view > rubberband,
.content-view treeview.view > rubberband, .content-view .rubberband, columnview.view > rubberband,
treeview.view > rubberband, gridview > rubberband, flowbox > rubberband {
  border: 1px solid #3281EA;
  background-color: color-mix(in srgb, #3281EA 30%, transparent);
}

flowbox > flowboxchild {
  padding: 4px;
  border-radius: 12px;
}

flowbox > flowboxchild button.remove-button.osd {
  min-height: 24px;
  min-width: 24px;
  padding: 6px;
}

.content-view .tile:selected {
  background-color: transparent;
}

gridview > child {
  padding: 3px;
}

gridview > child:selected {
  outline-color: alpha(currentColor, 0.06);
}

gridview > child box {
  border-spacing: 8px;
  margin: 12px;
}

coverflow cover {
  color: white;
  background-color: #2C2C2C;
  border: 1px solid black;
}

label.separator {
  color: rgba(255, 255, 255, 0.7);
}

label:disabled {
  opacity: 1;
  filter: none;
}

row label:disabled, headerbar label:disabled, tab label:disabled, button label:disabled {
  color: inherit;
}

label.osd {
  border-radius: 12px;
  background-color: rgba(25, 25, 25, 0.9);
  color: white;
}

.dim-label, row.expander:not(:checked) image.expander-row-arrow, row.property > box.header > box.title > .title, row label.subtitle, .content-pane headerbar entry > text > placeholder, entry > text > placeholder {
  color: rgba(255, 255, 255, 0.5);
  opacity: 1;
}

.accent {
  color: #3281EA;
}

.success {
  color: #81C995;
}

.warning {
  color: #FBC02D;
}

.error {
  color: #F44336;
}

window.assistant .sidebar {
  padding: 4px 0;
}

window.assistant .sidebar label {
  min-height: 36px;
  padding: 0 12px;
  color: rgba(255, 255, 255, 0.5);
  font-weight: 500;
}

window.assistant .sidebar label.highlight {
  color: white;
}

toast, .osd popover.background > arrow,
.osd popover.background > contents, popover.background.touch-selection > arrow,
popover.background.touch-selection > contents, popover.background.magnifier > arrow,
popover.background.magnifier > contents, .osd {
  color: white;
  background-color: #2C2C2C;
  background-clip: padding-box;
  border-radius: 12px;
  border: none;
}

.osd {
  padding: 6px;
  margin: 6px;
  box-shadow: 0 3px 3px -1px rgba(0, 0, 0, 0.2), 0 6px 6px 0 rgba(0, 0, 0, 0.14), 0 1px 11px 0 rgba(0, 0, 0, 0.12);
}

.osd.circular {
  border-radius: 9999px;
}

/*********************
 * Spinner Animation *
 *********************/
@keyframes spin {
  to {
    transform: rotate(1turn);
  }
}

spinner {
  background: none;
  opacity: 0;
  -gtk-icon-source: -gtk-icontheme("process-working-symbolic");
}

spinner:checked {
  opacity: 1;
  animation: spin 1s linear infinite;
}

spinner:checked:disabled {
  opacity: 0.5;
}

.large-title {
  font-weight: 300;
  font-size: 24pt;
}

.title-1 {
  font-weight: 800;
  font-size: 20pt;
}

.title-2 {
  font-weight: 800;
  font-size: 15pt;
}

.title-3 {
  font-weight: 700;
  font-size: 15pt;
}

.title-4 {
  font-weight: 700;
  font-size: 13pt;
}

.heading, row.button .title, listview > header {
  font-weight: 700;
  font-size: 11pt;
}

.body {
  font-weight: 400;
  font-size: 11pt;
}

.caption {
  font-weight: 400;
  font-size: 9pt;
}

.caption-heading {
  font-weight: 700;
  font-size: 9pt;
}

/****************
 * Text Entries *
 ****************/
.content-pane headerbar entry, entry {
  caret-color: currentColor;
  transition: outline-color 300ms cubic-bezier(0, 0, 0.2, 1), outline-width 300ms cubic-bezier(0, 0, 0.2, 1), outline-offset 300ms cubic-bezier(0, 0, 0.2, 1);
  outline: 0 solid transparent;
  outline-offset: 4px;
  background-color: alpha(currentColor, 0.05);
  color: white;
}

.content-pane headerbar entry:focus-within, entry:focus-within {
  background-color: alpha(currentColor, 0.05);
  color: white;
  outline-color: #3281EA;
  outline-width: 2px;
  outline-offset: -2px;
}

.content-pane headerbar entry:not(:disabled):not(:focus-within):hover, entry:not(:disabled):not(:focus-within):hover, .content-pane headerbar entry:drop(active), entry:drop(active) {
  background-color: alpha(currentColor, 0.08);
  color: white;
  outline: 2px solid alpha(currentColor, 0.08);
  outline-offset: -2px;
}

.content-pane headerbar entry:disabled, entry:disabled {
  background-color: alpha(currentColor, 0.05);
  color: rgba(255, 255, 255, 0.5);
  outline: none;
  filter: none;
  opacity: 1;
}

.content-pane headerbar entry > text > block-cursor, entry > text > block-cursor {
  color: #212121;
  background-color: white;
}

.content-pane headerbar entry > image, entry > image {
  color: rgba(255, 255, 255, 0.7);
}

.content-pane headerbar entry > image:hover, entry > image:hover, .content-pane headerbar entry > image:active, entry > image:active {
  color: white;
}

.content-pane headerbar entry > image:disabled, entry > image:disabled {
  color: rgba(255, 255, 255, 0.5);
}

entry {
  min-height: 36px;
  padding: 0 8px;
  border-spacing: 6px;
  border-radius: 12px;
}

entry.flat {
  min-height: 0;
  padding: 2px;
  border-radius: 0;
  background-color: transparent;
}

entry image.left {
  margin-left: 2px;
  margin-right: 6px;
}

entry image.right {
  margin-left: 6px;
  margin-right: 2px;
}

entry undershoot.left > undershoot.left {
  box-shadow: none;
  background: linear-gradient(to right, alpha(rgba(0, 0, 0, 0.25), 0.75), transparent 4px);
}

entry undershoot.right > undershoot.right {
  box-shadow: none;
  background: linear-gradient(to left, alpha(rgba(0, 0, 0, 0.25), 0.75), transparent 4px);
}

entry.error {
  transition: outline-color 300ms cubic-bezier(0, 0, 0.2, 1), outline-width 300ms cubic-bezier(0, 0, 0.2, 1), outline-offset 300ms cubic-bezier(0, 0, 0.2, 1);
  outline: 0 solid transparent;
  outline-offset: 4px;
  background-color: alpha(currentColor, 0.05);
  color: #F44336;
}

entry.error selection {
  color: white;
  background-color: #F44336;
}

entry.error:not(:disabled):not(:focus-within):hover, entry.error:drop(active) {
  background-color: alpha(currentColor, 0.08);
  color: #F44336;
  outline: 2px solid alpha(currentColor, 0.08);
  outline-offset: -2px;
}

entry.error:focus-within {
  background-color: alpha(currentColor, 0.05);
  color: #F44336;
  outline-color: #F44336;
  outline-width: 2px;
  outline-offset: -2px;
}

entry.error:disabled {
  background-color: alpha(currentColor, 0.05);
  color: rgba(244, 67, 54, 0.35);
  outline: none;
  filter: none;
  opacity: 1;
}

entry.error > text > placeholder {
  color: rgba(244, 67, 54, 0.35);
}

entry.error > text > block-cursor {
  color: #F44336;
  background-color: white;
}

entry.error > image {
  color: rgba(244, 67, 54, 0.8);
}

entry.error > image:hover, entry.error > image:active {
  color: #F44336;
}

entry.error > image:disabled {
  color: rgba(244, 67, 54, 0.35);
}

entry.success {
  transition: outline-color 300ms cubic-bezier(0, 0, 0.2, 1), outline-width 300ms cubic-bezier(0, 0, 0.2, 1), outline-offset 300ms cubic-bezier(0, 0, 0.2, 1);
  outline: 0 solid transparent;
  outline-offset: 4px;
  background-color: alpha(currentColor, 0.05);
  color: #81C995;
}

entry.success selection {
  color: rgba(0, 0, 0, 0.87);
  background-color: #81C995;
}

entry.success:not(:disabled):not(:focus-within):hover, entry.success:drop(active) {
  background-color: alpha(currentColor, 0.08);
  color: #81C995;
  outline: 2px solid alpha(currentColor, 0.08);
  outline-offset: -2px;
}

entry.success:focus-within {
  background-color: alpha(currentColor, 0.05);
  color: #81C995;
  outline-color: #81C995;
  outline-width: 2px;
  outline-offset: -2px;
}

entry.success:disabled {
  background-color: alpha(currentColor, 0.05);
  color: rgba(129, 201, 149, 0.35);
  outline: none;
  filter: none;
  opacity: 1;
}

entry.success > text > placeholder {
  color: rgba(129, 201, 149, 0.35);
}

entry.success > text > block-cursor {
  color: #81C995;
  background-color: rgba(0, 0, 0, 0.87);
}

entry.success > image {
  color: rgba(129, 201, 149, 0.8);
}

entry.success > image:hover, entry.success > image:active {
  color: #81C995;
}

entry.success > image:disabled {
  color: rgba(129, 201, 149, 0.35);
}

entry.warning {
  transition: outline-color 300ms cubic-bezier(0, 0, 0.2, 1), outline-width 300ms cubic-bezier(0, 0, 0.2, 1), outline-offset 300ms cubic-bezier(0, 0, 0.2, 1);
  outline: 0 solid transparent;
  outline-offset: 4px;
  background-color: alpha(currentColor, 0.05);
  color: #FBC02D;
}

entry.warning selection {
  color: rgba(0, 0, 0, 0.87);
  background-color: #FBC02D;
}

entry.warning:not(:disabled):not(:focus-within):hover, entry.warning:drop(active) {
  background-color: alpha(currentColor, 0.08);
  color: #FBC02D;
  outline: 2px solid alpha(currentColor, 0.08);
  outline-offset: -2px;
}

entry.warning:focus-within {
  background-color: alpha(currentColor, 0.05);
  color: #FBC02D;
  outline-color: #FBC02D;
  outline-width: 2px;
  outline-offset: -2px;
}

entry.warning:disabled {
  background-color: alpha(currentColor, 0.05);
  color: rgba(251, 192, 45, 0.35);
  outline: none;
  filter: none;
  opacity: 1;
}

entry.warning > text > placeholder {
  color: rgba(251, 192, 45, 0.35);
}

entry.warning > text > block-cursor {
  color: #FBC02D;
  background-color: rgba(0, 0, 0, 0.87);
}

entry.warning > image {
  color: rgba(251, 192, 45, 0.8);
}

entry.warning > image:hover, entry.warning > image:active {
  color: #FBC02D;
}

entry.warning > image:disabled {
  color: rgba(251, 192, 45, 0.35);
}

entry > progress,
entry progress > trough > progress {
  margin: 2px -8px;
  border-bottom: 2px solid #3281EA;
  background-color: transparent;
}

treeview entry.flat, treeview entry {
  background-color: #2C2C2C;
}

treeview entry.flat, treeview entry.flat:focus-within, treeview entry, treeview entry:focus-within {
  border-image: none;
  box-shadow: none;
}

.entry-tag {
  margin: 2px;
  border-radius: 9999px;
  box-shadow: none;
  background-color: rgba(255, 255, 255, 0.15);
  color: white;
}

.entry-tag:hover {
  background-image: image(alpha(currentColor, 0.08));
}

:dir(ltr) .entry-tag {
  margin-left: 4px;
  margin-right: 0;
  padding-left: 12px;
  padding-right: 8px;
}

:dir(rtl) .entry-tag {
  margin-left: 0;
  margin-right: 4px;
  padding-left: 8px;
  padding-right: 12px;
}

.entry-tag.button {
  box-shadow: none;
  background-color: transparent;
}

.entry-tag.button:not(:hover):not(:active) {
  color: rgba(255, 255, 255, 0.7);
}

editablelabel > stack > text {
  transition: outline-color 300ms cubic-bezier(0, 0, 0.2, 1), outline-width 300ms cubic-bezier(0, 0, 0.2, 1), outline-offset 300ms cubic-bezier(0, 0, 0.2, 1);
  outline: 0 solid transparent;
  outline-offset: 4px;
  background-color: alpha(currentColor, 0.05);
  color: white;
}

/***********
 * Buttons *
 ***********/
@keyframes needs-attention {
  from {
    background-image: radial-gradient(farthest-side, #3281EA 0%, transparent 0%);
  }
  to {
    background-image: radial-gradient(farthest-side, #3281EA 95%, transparent);
  }
}

.nautilus-window tabbar tab > button.flat, .nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable button.sidebar-button,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable button.sidebar-button, infobar.warning > revealer > box button, infobar.warning:backdrop > revealer > box button, popover.background.touch-selection button, popover.background.magnifier button, headerbar.selection-mode button:not(.suggested-action):not(.destructive-action) {
  color: rgba(255, 255, 255, 0.7);
}

.nautilus-window tabbar tab > button.flat:focus, .nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable button.sidebar-button:focus,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable button.sidebar-button:focus, infobar.warning > revealer > box button:focus, popover.background.touch-selection button:focus, popover.background.magnifier button:focus, headerbar.selection-mode button:focus:not(.suggested-action):not(.destructive-action), .nautilus-window tabbar tab > button.flat:hover, .nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable button.sidebar-button:hover,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable button.sidebar-button:hover, infobar.warning > revealer > box button:hover, popover.background.touch-selection button:hover, popover.background.magnifier button:hover, headerbar.selection-mode button:hover:not(.suggested-action):not(.destructive-action), .nautilus-window tabbar tab > button.flat:active, .nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable button.sidebar-button:active,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable button.sidebar-button:active, infobar.warning > revealer > box button:active, popover.background.touch-selection button:active, popover.background.magnifier button:active, headerbar.selection-mode button:active:not(.suggested-action):not(.destructive-action), .nautilus-window tabbar tab > button.flat:checked, .nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable button.sidebar-button:checked,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable button.sidebar-button:checked, infobar.warning > revealer > box button:checked, popover.background.touch-selection button:checked, popover.background.magnifier button:checked, headerbar.selection-mode button:checked:not(.suggested-action):not(.destructive-action) {
  color: white;
}

.nautilus-window tabbar tab > button.flat:disabled, .nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable button.sidebar-button:disabled,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable button.sidebar-button:disabled, infobar.warning > revealer > box button:disabled, popover.background.touch-selection button:disabled, popover.background.magnifier button:disabled, headerbar.selection-mode button:disabled:not(.suggested-action):not(.destructive-action) {
  color: rgba(255, 255, 255, 0.3);
}

.nautilus-window tabbar tab > button.flat:checked:disabled, .nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable button.sidebar-button:checked:disabled,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable button.sidebar-button:checked:disabled, infobar.warning > revealer > box button:checked:disabled, popover.background.touch-selection button:checked:disabled, popover.background.magnifier button:checked:disabled, headerbar.selection-mode button:checked:disabled:not(.suggested-action):not(.destructive-action) {
  color: rgba(255, 255, 255, 0.5);
}

.nautilus-window headerbar popover.background > contents button:not(.suggested-action):not(.destructive-action), row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child, row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr):last-child, row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child,
row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque),
row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child,
row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child, button {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1), background-size 0, background-image 0;
  outline: none;
  box-shadow: inset 0 0 0 2px transparent;
  background-color: alpha(currentColor, 0.05);
  background-image: radial-gradient(circle, transparent 0%, transparent 0%);
  background-repeat: no-repeat;
  background-position: center;
  background-size: 1000% 1000%;
  color: white;
}

.nautilus-window headerbar popover.background > contents button:focus:not(.suggested-action):not(.destructive-action), row.spin spinbutton > button.image-button.up:focus:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child, row.spin spinbutton > button.image-button.up:focus:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr), row.spin spinbutton > button.image-button.up:focus:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child,
row.spin spinbutton > button.image-button.down:focus:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque),
row.spin spinbutton > button.image-button.down:focus:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child,
row.spin spinbutton > button.image-button.down:focus:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child, button:focus {
  box-shadow: inset 0 0 0 2px alpha(currentColor, 0.08);
}

.nautilus-window headerbar popover.background > contents button:hover:not(.suggested-action):not(.destructive-action), row.spin spinbutton > button.image-button.up:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child, row.spin spinbutton > button.image-button.up:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr), row.spin spinbutton > button.image-button.up:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child,
row.spin spinbutton > button.image-button.down:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque),
row.spin spinbutton > button.image-button.down:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child,
row.spin spinbutton > button.image-button.down:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child, button:hover {
  background-color: alpha(currentColor, 0.08);
}

.nautilus-window headerbar popover.background > contents button:active:not(.suggested-action):not(.destructive-action), row.spin spinbutton > button.image-button.up:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child, row.spin spinbutton > button.image-button.up:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr), row.spin spinbutton > button.image-button.up:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child,
row.spin spinbutton > button.image-button.down:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque),
row.spin spinbutton > button.image-button.down:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child,
row.spin spinbutton > button.image-button.down:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child, button:active {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1), background-size 0ms, background-image 0ms, border 0ms;
  animation: ripple 225ms cubic-bezier(0, 0, 0.2, 1) forwards;
  background-color: alpha(currentColor, 0.08);
  background-image: radial-gradient(circle, alpha(currentColor, 0.12) 10%, transparent 0%);
  background-size: 100% 100%;
}

.nautilus-window headerbar popover.background > contents button:disabled:not(.suggested-action):not(.destructive-action), row.spin spinbutton > button.image-button.up:disabled:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child, row.spin spinbutton > button.image-button.up:disabled:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr), row.spin spinbutton > button.image-button.up:disabled:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child,
row.spin spinbutton > button.image-button.down:disabled:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque),
row.spin spinbutton > button.image-button.down:disabled:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child,
row.spin spinbutton > button.image-button.down:disabled:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child, button:disabled {
  box-shadow: none;
  background-color: alpha(currentColor, 0.05);
  color: rgba(255, 255, 255, 0.5);
  filter: none;
  opacity: 1;
}

.nautilus-window headerbar popover.background > contents button:checked:not(.suggested-action):not(.destructive-action), row.spin spinbutton > button.image-button.up:checked:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child, row.spin spinbutton > button.image-button.up:checked:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr), row.spin spinbutton > button.image-button.up:checked:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child,
row.spin spinbutton > button.image-button.down:checked:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque),
row.spin spinbutton > button.image-button.down:checked:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child,
row.spin spinbutton > button.image-button.down:checked:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child, button:checked {
  box-shadow: none;
  background-color: #3281EA;
  color: white;
}

.nautilus-window headerbar popover.background > contents button:checked:hover:not(.suggested-action):not(.destructive-action), row.spin spinbutton > button.image-button.up:checked:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child,
row.spin spinbutton > button.image-button.down:checked:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque),
row.spin spinbutton > button.image-button.down:checked:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child,
row.spin spinbutton > button.image-button.down:checked:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child, button:checked:hover {
  box-shadow: inset 0 0 0 2px transparent;
}

.nautilus-window headerbar popover.background > contents button:checked:disabled:not(.suggested-action):not(.destructive-action), row.spin spinbutton > button.image-button.up:checked:disabled:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child,
row.spin spinbutton > button.image-button.down:checked:disabled:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque),
row.spin spinbutton > button.image-button.down:checked:disabled:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child,
row.spin spinbutton > button.image-button.down:checked:disabled:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child, button:checked:disabled {
  background-color: alpha(currentColor, 0.1);
  color: rgba(255, 255, 255, 0.5);
}

button {
  min-height: 24px;
  min-width: 24px;
  padding: 6px;
  border-radius: 12px;
  font-weight: 500;
}

button:drop(active) {
  background-color: alpha(currentColor, 0.08);
}

.card.category-tile-iconless, .nautilus-window tabbar tab:active > button.flat, .nautilus-window tabbar tab:checked > button.flat, .nautilus-window tabbar tab:selected > button.flat, .nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:selected button.sidebar-button,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:selected button.sidebar-button, stackswitcher.linked:not(.vertical) > button:not(.suggested-action):not(.destructive-action), placessidebar .navigation-sidebar > row button.sidebar-button, calendar > header > button, row button.circular, check,
radio, scrollbar button, notebook > header > tabs > arrow, popover.background modelbutton, spinbutton > button.image-button.up,
spinbutton > button.image-button.down, tabbar tab button.image-button,
dnd tab button.image-button, splitbutton.flat > button,
splitbutton.flat > menubutton > button, menubutton.flat > button, .nautilus-window headerbar popover.background > contents button.flat:not(.suggested-action):not(.destructive-action), filechooser #pathbarbox > stack > box > button, window.messagedialog .response-area button, window.dialog.message.csd .dialog-action-area > button, .app-notification button, headerbar button:not(.suggested-action):not(.destructive-action), .toolbar > button,
toolbar > button, dropdown > .linked:not(.vertical) > button:not(:only-child),
combobox > .linked:not(.vertical) > button:not(:only-child), button.flat {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1), background-size 0, background-image 0;
  outline: none;
  box-shadow: inset 0 0 0 2px transparent;
  background-color: transparent;
  background-image: radial-gradient(circle, transparent 0%, transparent 0%);
  background-repeat: no-repeat;
  background-position: center;
  background-size: 1000% 1000%;
  color: rgba(255, 255, 255, 0.7);
}

.card.category-tile-iconless:focus, .nautilus-window tabbar tab:active > button.flat:focus, .nautilus-window tabbar tab:checked > button.flat:focus, .nautilus-window tabbar tab:selected > button.flat:focus, .nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:selected button.sidebar-button:focus,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:selected button.sidebar-button:focus, stackswitcher.linked:not(.vertical) > button:focus:not(.suggested-action):not(.destructive-action), placessidebar .navigation-sidebar > row button.sidebar-button:focus, calendar > header > button:focus, row button.circular:focus, check:focus,
radio:focus, scrollbar button:focus, notebook > header > tabs > arrow:focus, popover.background modelbutton:focus, spinbutton > button.image-button.up:focus,
spinbutton > button.image-button.down:focus, tabbar tab button.image-button:focus,
dnd tab button.image-button:focus, splitbutton.flat > button:focus,
splitbutton.flat > menubutton > button:focus, menubutton.flat > button:focus, .nautilus-window headerbar popover.background > contents button.flat:focus:not(.suggested-action):not(.destructive-action), filechooser #pathbarbox > stack > box > button:focus, window.messagedialog .response-area button:focus, window.dialog.message.csd .dialog-action-area > button:focus, .app-notification button:focus, headerbar button:focus:not(.suggested-action):not(.destructive-action), .toolbar > button:focus,
toolbar > button:focus, dropdown > .linked:not(.vertical) > button:focus:not(:only-child),
combobox > .linked:not(.vertical) > button:focus:not(:only-child), button.flat:focus {
  box-shadow: inset 0 0 0 2px alpha(currentColor, 0.08);
  color: white;
}

.card.category-tile-iconless:hover, .nautilus-window tabbar tab:active > button.flat:hover, .nautilus-window tabbar tab:checked > button.flat:hover, .nautilus-window tabbar tab:selected > button.flat:hover, .nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:selected button.sidebar-button:hover,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:selected button.sidebar-button:hover, stackswitcher.linked:not(.vertical) > button:hover:not(.suggested-action):not(.destructive-action), placessidebar .navigation-sidebar > row button.sidebar-button:hover, calendar > header > button:hover, row button.circular:hover, check:hover,
radio:hover, scrollbar button:hover, notebook > header > tabs > arrow:hover, popover.background modelbutton:hover, spinbutton > button.image-button.up:hover,
spinbutton > button.image-button.down:hover, tabbar tab button.image-button:hover,
dnd tab button.image-button:hover, splitbutton.flat > button:hover,
splitbutton.flat > menubutton > button:hover, menubutton.flat > button:hover, .nautilus-window headerbar popover.background > contents button.flat:hover:not(.suggested-action):not(.destructive-action), filechooser #pathbarbox > stack > box > button:hover, window.messagedialog .response-area button:hover, window.dialog.message.csd .dialog-action-area > button:hover, .app-notification button:hover, headerbar button:hover:not(.suggested-action):not(.destructive-action), .toolbar > button:hover,
toolbar > button:hover, dropdown > .linked:not(.vertical) > button:hover:not(:only-child),
combobox > .linked:not(.vertical) > button:hover:not(:only-child), button.flat:hover {
  background-color: alpha(currentColor, 0.08);
  color: white;
}

.card.category-tile-iconless:active, .nautilus-window tabbar tab:active > button.flat:active, .nautilus-window tabbar tab:checked > button.flat:active, .nautilus-window tabbar tab:selected > button.flat:active, .nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:selected button.sidebar-button:active,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:selected button.sidebar-button:active, stackswitcher.linked:not(.vertical) > button:active:not(.suggested-action):not(.destructive-action), placessidebar .navigation-sidebar > row button.sidebar-button:active, calendar > header > button:active, row button.circular:active, check:active,
radio:active, scrollbar button:active, notebook > header > tabs > arrow:active, popover.background modelbutton:active, spinbutton > button.image-button.up:active,
spinbutton > button.image-button.down:active, tabbar tab button.image-button:active,
dnd tab button.image-button:active, splitbutton.flat > button:active,
splitbutton.flat > menubutton > button:active, menubutton.flat > button:active, .nautilus-window headerbar popover.background > contents button.flat:active:not(.suggested-action):not(.destructive-action), filechooser #pathbarbox > stack > box > button:active, window.messagedialog .response-area button:active, window.dialog.message.csd .dialog-action-area > button:active, .app-notification button:active, headerbar button:active:not(.suggested-action):not(.destructive-action), .toolbar > button:active,
toolbar > button:active, dropdown > .linked:not(.vertical) > button:active:not(:only-child),
combobox > .linked:not(.vertical) > button:active:not(:only-child), button.flat:active {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1), background-size 0ms, background-image 0ms;
  animation: ripple 225ms cubic-bezier(0, 0, 0.2, 1) forwards;
  background-color: alpha(currentColor, 0.08);
  background-image: radial-gradient(circle, alpha(currentColor, 0.12) 10%, transparent 0%);
  background-size: 100% 100%;
  color: white;
}

.card.category-tile-iconless:disabled, .nautilus-window tabbar tab:active > button.flat:disabled, .nautilus-window tabbar tab:checked > button.flat:disabled, .nautilus-window tabbar tab:selected > button.flat:disabled, .nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:selected button.sidebar-button:disabled,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:selected button.sidebar-button:disabled, stackswitcher.linked:not(.vertical) > button:disabled:not(.suggested-action):not(.destructive-action), placessidebar .navigation-sidebar > row button.sidebar-button:disabled, calendar > header > button:disabled, row button.circular:disabled, check:disabled,
radio:disabled, scrollbar button:disabled, notebook > header > tabs > arrow:disabled, popover.background modelbutton:disabled, spinbutton > button.image-button.up:disabled,
spinbutton > button.image-button.down:disabled, tabbar tab button.image-button:disabled,
dnd tab button.image-button:disabled, splitbutton.flat > button:disabled,
splitbutton.flat > menubutton > button:disabled, menubutton.flat > button:disabled, .nautilus-window headerbar popover.background > contents button.flat:disabled:not(.suggested-action):not(.destructive-action), filechooser #pathbarbox > stack > box > button:disabled, window.messagedialog .response-area button:disabled, window.dialog.message.csd .dialog-action-area > button:disabled, .app-notification button:disabled, headerbar button:disabled:not(.suggested-action):not(.destructive-action), .toolbar > button:disabled,
toolbar > button:disabled, dropdown > .linked:not(.vertical) > button:disabled:not(:only-child),
combobox > .linked:not(.vertical) > button:disabled:not(:only-child), button.flat:disabled {
  box-shadow: none;
  background-color: transparent;
  color: rgba(255, 255, 255, 0.3);
}

tabbar tab button.image-button:checked,
dnd tab button.image-button:checked, splitbutton.flat > button:checked,
splitbutton.flat > menubutton > button:checked, menubutton.flat > button:checked, .nautilus-window headerbar popover.background > contents button.flat:checked:not(.suggested-action):not(.destructive-action), filechooser #pathbarbox > stack > box > button:checked, window.messagedialog .response-area button:checked, window.dialog.message.csd .dialog-action-area > button:checked, .app-notification button:checked, headerbar button:checked:not(.suggested-action):not(.destructive-action), .toolbar > button:checked,
toolbar > button:checked, dropdown > .linked:not(.vertical) > button:checked:not(:only-child),
combobox > .linked:not(.vertical) > button:checked:not(:only-child), button.flat:checked, button.flat:checked:hover {
  background-color: alpha(currentColor, 0.1);
  color: white;
}

tabbar tab button.image-button:checked:disabled,
dnd tab button.image-button:checked:disabled, splitbutton.flat > button:checked:disabled,
splitbutton.flat > menubutton > button:checked:disabled, menubutton.flat > button:checked:disabled, .nautilus-window headerbar popover.background > contents button.flat:checked:disabled:not(.suggested-action):not(.destructive-action), filechooser #pathbarbox > stack > box > button:checked:disabled, window.messagedialog .response-area button:checked:disabled, window.dialog.message.csd .dialog-action-area > button:checked:disabled, .app-notification button:checked:disabled, headerbar button:checked:disabled:not(.suggested-action):not(.destructive-action), .toolbar > button:checked:disabled,
toolbar > button:checked:disabled, dropdown > .linked:not(.vertical) > button:checked:disabled:not(:only-child),
combobox > .linked:not(.vertical) > button:checked:disabled:not(:only-child), button.flat:checked:disabled {
  background-color: alpha(currentColor, 0.1);
  color: rgba(255, 255, 255, 0.5);
}

button.text-button {
  min-width: 32px;
  padding-left: 16px;
  padding-right: 16px;
}

button.text-button.flat {
  min-width: 48px;
  padding-left: 8px;
  padding-right: 8px;
}

button.image-button {
  min-width: 24px;
  padding: 6px;
}

button.text-button.image-button {
  min-width: 24px;
  padding: 6px;
  border-radius: 12px;
}

button.text-button.image-button label:first-child {
  margin-left: 10px;
}

button.text-button.image-button label:last-child {
  margin-right: 10px;
}

button.text-button.image-button.flat label:first-child {
  margin-left: 6px;
}

button.text-button.image-button.flat label:last-child {
  margin-right: 6px;
}

button.text-button.image-button image:not(:only-child) {
  margin: 0 4px;
}

.linked:not(.vertical) > button.flat:not(:only-child), .linked.vertical > button.flat:not(:only-child) {
  border-radius: 12px;
}

.linked:not(.vertical) > button.flat:focus, .linked.vertical > button.flat:focus {
  box-shadow: inset 0 0 0 2px alpha(currentColor, 0.08);
}

.linked:not(.vertical) > menubutton:first-child > button {
  border-radius: 12px 0 0 12px;
}

.linked:not(.vertical) > menubutton:last-child > button {
  border-radius: 0 12px 12px 0;
}

button.osd {
  min-height: 24px;
  min-width: 24px;
  padding: 6px;
  box-shadow: none;
  background-color: rgba(0, 0, 0, 0.5);
  border: none;
  background-clip: padding-box;
  color: rgba(255, 255, 255, 0.85);
}

button.osd:hover {
  background-color: rgba(0, 0, 0, 0.65);
  color: white;
}

button.osd:active {
  background-color: rgba(0, 0, 0, 0.75);
  color: white;
}

button.osd:disabled {
  opacity: 0;
  color: rgba(255, 255, 255, 0.35);
}

button.suggested-action {
  background-color: #3281EA;
  color: white;
  box-shadow: none;
}

button.suggested-action:disabled {
  color: rgba(255, 255, 255, 0.45);
  background-color: rgba(50, 129, 234, 0.25);
}

button.suggested-action:hover {
  color: white;
  background-color: #478eec;
  box-shadow: none;
}

button.suggested-action:active {
  color: white;
  background-color: #5b9aee;
}

button.suggested-action:checked {
  background-color: #5194ed;
}

button.suggested-action:focus {
  box-shadow: 0 0 0 2px rgba(50, 129, 234, 0.35);
}

button.suggested-action.flat {
  background-color: transparent;
  color: #3281EA;
}

button.suggested-action.flat:disabled {
  color: rgba(255, 255, 255, 0.45);
  background-color: transparent;
}

button.suggested-action.flat:checked {
  background-color: rgba(50, 129, 234, 0.3);
}

button.destructive-action {
  background-color: #F44336;
  color: white;
  box-shadow: none;
}

button.destructive-action:disabled {
  color: rgba(255, 255, 255, 0.45);
  background-color: rgba(244, 67, 54, 0.25);
}

button.destructive-action:hover {
  color: white;
  background-color: #f5564a;
  box-shadow: none;
}

button.destructive-action:active {
  color: white;
  background-color: #f6695e;
}

button.destructive-action:checked {
  background-color: #f65f54;
}

button.destructive-action:focus {
  box-shadow: 0 0 0 2px rgba(244, 67, 54, 0.35);
}

button.destructive-action.flat {
  background-color: transparent;
  color: #F44336;
}

button.destructive-action.flat:disabled {
  color: rgba(255, 255, 255, 0.45);
  background-color: transparent;
}

button.destructive-action.flat:checked {
  background-color: rgba(244, 67, 54, 0.3);
}

stackswitcher > button > label {
  margin: 0 -6px;
  padding: 0 6px;
}

stackswitcher > button > image {
  margin: -3px -6px;
  padding: 3px 6px;
}

stackswitcher > button.needs-attention:checked > label,
stackswitcher > button.needs-attention:checked > image {
  animation: none;
  background-image: none;
}

button.font > box, button.file > box {
  border-spacing: 6px;
}

button.font > box > box > label, button.file > box > box > label {
  font-weight: bold;
}

menubutton.circular > button, filechooser #pathbarbox > stack > box > button, row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child, row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr):last-child, row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child,
row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque),
row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child,
row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child, check,
radio, headerbar windowcontrols button:not(.suggested-action):not(.destructive-action), button.image-button, button.close, button.circular {
  border-radius: 9999px;
}

menubutton.circular > button label, filechooser #pathbarbox > stack > box > button label, row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child label, row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr):last-child label, row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child label,
row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) label,
row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child label,
row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child label, check label,
radio label, headerbar windowcontrols button:not(.suggested-action):not(.destructive-action) label, button.image-button label, button.close label, button.circular label {
  padding: 0;
}

.floating-bar button, placessidebar .navigation-sidebar > row button.sidebar-button, notebook > header tab button.flat, popover.menu box.circular-buttons button.circular.image-button.model, spinbutton > button.image-button.up,
spinbutton > button.image-button.down {
  min-height: 24px;
  min-width: 24px;
  padding: 0;
  border-radius: 9999px;
}

stacksidebar row.needs-attention > label, stackswitcher > button.needs-attention > label,
stackswitcher > button.needs-attention > image {
  animation: needs-attention 225ms cubic-bezier(0, 0, 0.2, 1) forwards;
  background-repeat: no-repeat;
  background-position: right 3px;
  background-size: 6px 6px;
}

stacksidebar row.needs-attention > label:dir(rtl), stackswitcher > button.needs-attention > label:dir(rtl),
stackswitcher > button.needs-attention > image:dir(rtl) {
  background-position: left 3px;
}

.linked:not(.vertical) > entry, .linked:not(.vertical) > button, .linked:not(.vertical) > button.image-button {
  border-radius: 0;
}

.linked:not(.vertical) > entry:first-child, .linked:not(.vertical) > button:first-child {
  border-top-left-radius: 12px;
  border-bottom-left-radius: 12px;
}

.linked:not(.vertical) > entry:last-child, .linked:not(.vertical) > button:last-child {
  border-top-right-radius: 12px;
  border-bottom-right-radius: 12px;
}

.linked:not(.vertical) > entry:only-child, .linked:not(.vertical) > button:only-child {
  border-radius: 12px;
}

.linked.vertical > entry, .linked.vertical > button, .linked.vertical > button.image-button {
  border-radius: 0;
}

.linked.vertical > entry:first-child, .linked.vertical > button:first-child {
  border-top-left-radius: 12px;
  border-top-right-radius: 12px;
}

.linked.vertical > entry:last-child, .linked.vertical > button:last-child {
  border-bottom-left-radius: 12px;
  border-bottom-right-radius: 12px;
}

.linked.vertical > entry:only-child, .linked.vertical > button:only-child {
  border-radius: 12px;
}

button.color {
  min-height: 24px;
  min-width: 24px;
  padding: 6px;
}


list > row button.image-button:not(.flat) {
  background-color: transparent;
  box-shadow: none;
  border: none;
}


list > row button.image-button:not(.flat):hover {
  background-color: alpha(currentColor, 0.08);
}


list > row button.image-button:not(.flat):active,
list > row button.image-button:not(.flat):checked {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1), background-size 0ms, background-image 0ms, border 0ms;
  animation: ripple 225ms cubic-bezier(0, 0, 0.2, 1) forwards;
  background-color: alpha(currentColor, 0.08);
  background-image: radial-gradient(circle, alpha(currentColor, 0.12) 10%, transparent 0%);
  background-size: 100% 100%;
}


list > row button.image-button:not(.flat).suggested-action {
  background-color: #3281EA;
  color: white;
}


list > row button.image-button:not(.flat).destructive-action {
  background-color: #F44336;
  color: white;
}

/*********
 * Links *
 *********/
link {
  color: #3281EA;
}

link:visited {
  color: #BA68C8;
}

button.link:link, button.link:link:focus, button.link:link:hover, button.link:link:active {
  color: #3281EA;
}

button.link:visited, button.link:visited:focus, button.link:visited:hover, button.link:visited:active {
  color: #BA68C8;
}

button.link > label {
  text-decoration-line: underline;
}

/*****************
 * GtkSpinButton *
 *****************/
spinbutton {
  transition: outline-color 300ms cubic-bezier(0, 0, 0.2, 1), outline-width 300ms cubic-bezier(0, 0, 0.2, 1), outline-offset 300ms cubic-bezier(0, 0, 0.2, 1);
  outline: 0 solid transparent;
  outline-offset: 4px;
  background-color: alpha(currentColor, 0.05);
  color: white;
  border-radius: 12px;
  padding: 0;
  border-spacing: 0;
}

spinbutton:focus-within {
  background-color: alpha(currentColor, 0.05);
  color: white;
  outline-color: #3281EA;
  outline-width: 2px;
  outline-offset: -2px;
}

spinbutton:disabled {
  background-color: alpha(currentColor, 0.05);
  color: rgba(255, 255, 255, 0.5);
  outline: none;
  filter: none;
  opacity: 1;
}

spinbutton > text {
  margin: 0;
  border-image: none;
  border-radius: 0;
  box-shadow: none;
  background-color: transparent;
}

spinbutton > button.image-button.up,
spinbutton > button.image-button.down {
  padding: 0;
  margin: 6px;
  border: none;
}

spinbutton > button.image-button.up:focus:not(:hover):not(:active):not(:disabled),
spinbutton > button.image-button.down:focus:not(:hover):not(:active):not(:disabled) {
  background-color: transparent;
  color: rgba(255, 255, 255, 0.7);
  outline: none;
  box-shadow: none;
}

spinbutton:not(.vertical) > text {
  min-width: 32px;
  padding-left: 12px;
}

spinbutton:not(.vertical) > button.up:dir(ltr), spinbutton:not(.vertical) > button.down:dir(rtl) {
  margin-left: 3px;
}

spinbutton:not(.vertical) > button.up:dir(rtl), spinbutton:not(.vertical) > button.down:dir(ltr) {
  margin-right: 3px;
}

spinbutton.vertical:disabled {
  color: rgba(255, 255, 255, 0.5);
}

spinbutton.vertical > text {
  min-height: 36px;
  min-width: 42px;
  padding: 0;
}

spinbutton.vertical > button.image-button.up,
spinbutton.vertical > button.image-button.down {
  margin: 6px;
  min-width: 30px;
  min-height: 30px;
}

list > row spinbutton:not(.vertical) > button {
  margin: 6px;
}

list > row spinbutton:not(.vertical) > button.up:dir(ltr), list > row spinbutton:not(.vertical) > button.down:dir(rtl) {
  margin-left: 3px;
}

list > row spinbutton:not(.vertical) > button.up:dir(rtl), list > row spinbutton:not(.vertical) > button.down:dir(ltr) {
  margin-right: 3px;
}

/**************
 * ComboBoxes *
 **************/
dropdown > button > box {
  border-spacing: 6px;
}

dropdown > button label {
  margin-left: 6px;
}

dropdown arrow,
combobox arrow {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
  min-height: 16px;
  min-width: 16px;
}

dropdown > popover.menu,
combobox > popover.menu {
  margin-top: 6px;
  padding: 0;
}

dropdown button.combo cellview:dir(ltr),
combobox button.combo cellview:dir(ltr) {
  margin-left: -2px;
}

dropdown button.combo cellview:dir(rtl),
combobox button.combo cellview:dir(rtl) {
  margin-right: -2px;
}

dropdown.linked button:nth-child(2):dir(ltr),
combobox.linked button:nth-child(2):dir(ltr) {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}

dropdown.linked button:nth-child(2):dir(rtl),
combobox.linked button:nth-child(2):dir(rtl) {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
}

dropdown > .linked:not(.vertical) > entry:not(:only-child),
combobox > .linked:not(.vertical) > entry:not(:only-child) {
  border-radius: 12px;
}

dropdown > .linked:not(.vertical) > entry:not(:only-child):first-child,
combobox > .linked:not(.vertical) > entry:not(:only-child):first-child {
  margin-right: -36px;
  padding-right: 36px;
}

dropdown > .linked:not(.vertical) > entry:not(:only-child):last-child,
combobox > .linked:not(.vertical) > entry:not(:only-child):last-child {
  margin-left: -36px;
  padding-left: 36px;
}

dropdown > .linked:not(.vertical) > button:not(:only-child),
combobox > .linked:not(.vertical) > button:not(:only-child) {
  min-height: 16px;
  min-width: 16px;
  margin: 6px;
  padding: 4px;
  border-radius: 12px;
}

.linked:not(.vertical) > combobox:not(:first-child) > box > button.combo {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}

.linked:not(.vertical) > combobox:not(:last-child) > box > button.combo {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
}

.linked.vertical > combobox:not(:first-child) > box > button.combo {
  border-top-left-radius: 0;
  border-top-right-radius: 0;
}

.linked.vertical > combobox:not(:last-child) > box > button.combo {
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0;
}

button.combo:only-child {
  border-radius: 12px;
  font-weight: normal;
  transition: outline-color 300ms cubic-bezier(0, 0, 0.2, 1), outline-width 300ms cubic-bezier(0, 0, 0.2, 1), outline-offset 300ms cubic-bezier(0, 0, 0.2, 1);
  outline: 0 solid transparent;
  outline-offset: 4px;
  background-color: alpha(currentColor, 0.05);
  color: white;
}

button.combo:only-child:focus {
  box-shadow: inset 0 0 0 2px alpha(currentColor, 0.08);
  color: white;
}

button.combo:only-child:hover {
  background-color: alpha(currentColor, 0.08);
  color: white;
}

button.combo:only-child:active {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1), background-size 0ms, background-image 0ms;
  animation: ripple 225ms cubic-bezier(0, 0, 0.2, 1) forwards;
  background-color: alpha(currentColor, 0.08);
  background-image: radial-gradient(circle, alpha(currentColor, 0.12) 10%, transparent 0%);
  background-size: 100% 100%;
  color: white;
}

button.combo:only-child:checked {
  background-color: alpha(currentColor, 0.1);
  color: white;
}

button.combo:only-child:disabled {
  box-shadow: none;
  background-color: alpha(currentColor, 0.05);
  color: rgba(255, 255, 255, 0.5);
  filter: none;
  opacity: 1;
}

.app-notification, .toolbar.osd,
toolbar.osd {
  transition: box-shadow 75ms cubic-bezier(0, 0, 0.2, 1);
  padding: 6px;
  border-radius: 12px;
  box-shadow: 0 2px 2px -1px rgba(0, 0, 0, 0.2), 0 4px 4px 0 rgba(0, 0, 0, 0.14), 0 1px 6px 0 rgba(0, 0, 0, 0.12), inset 0 1px rgba(255, 255, 255, 0.1);
  background-color: #3C3C3C;
  color: white;
}

.app-notification:backdrop, .toolbar.osd:backdrop,
toolbar.osd:backdrop {
  box-shadow: 0 3px 2px -3px rgba(0, 0, 0, 0.3), 0 2px 2px -1px rgba(0, 0, 0, 0.24), 0 1px 3px 0 rgba(0, 0, 0, 0.12), inset 0 1px rgba(255, 255, 255, 0.1);
  color: rgba(255, 255, 255, 0.5);
}

/************
 * Toolbars *
 ************/
.toolbar,
toolbar {
  padding: 6px;
  background-color: #212121;
  border-spacing: 0;
}

.toolbar button.pill,
toolbar button.pill {
  padding: 6px 32px;
}

.osd .toolbar, .osd toolbar {
  background-color: transparent;
}

.toolbar.osd.left, .toolbar.osd.right, .toolbar.osd.top, .toolbar.osd.bottom,
toolbar.osd.left,
toolbar.osd.right,
toolbar.osd.top,
toolbar.osd.bottom {
  border-radius: 0;
}

.toolbar.osd.bottom,
toolbar.osd.bottom {
  box-shadow: none;
  background-color: transparent;
  background-image: linear-gradient(to bottom, transparent, rgba(0, 0, 0, 0.1) 30%, rgba(0, 0, 0, 0.2) 50%, rgba(0, 0, 0, 0.4));
}

.toolbar.horizontal > separator,
toolbar.horizontal > separator {
  margin: 2px;
}

.toolbar.vertical > separator,
toolbar.vertical > separator {
  margin: 2px;
}

.toolbar:not(.inline-toolbar):not(.osd) switch,
toolbar:not(.inline-toolbar):not(.osd) switch {
  margin: 8px 2px;
}

.toolbar > button {
  border-radius: 6px;
}

.bottom-bar .toolbar {
  padding: 6px;
}

.bottom-bar .toolbar button {
  border-radius: 12px;
}

searchbar > revealer > box {
  padding: 6px;
  border-spacing: 0;
  border-style: solid;
  border-width: 0 0 1px;
  border-color: rgba(255, 255, 255, 0.12);
  background-color: #212121;
  background-clip: border-box;
  box-shadow: none;
}

searchbar > revealer > box entry,
searchbar > revealer > box button,
searchbar > revealer > box menubutton,
searchbar > revealer > box splitbutton {
  margin: 0;
}

/***************
 * Header bars *
 ***************/
.content-pane headerbar button:not(.suggested-action):not(.destructive-action), window.about headerbar button:not(.suggested-action):not(.destructive-action), .info headerbar button:not(.suggested-action):not(.destructive-action), .about headerbar button:not(.suggested-action):not(.destructive-action), headerbar.flat button:not(.suggested-action):not(.destructive-action) {
  color: rgba(255, 255, 255, 0.7);
}

.content-pane headerbar button:focus:not(.suggested-action):not(.destructive-action), .info headerbar button:focus:not(.suggested-action):not(.destructive-action), .about headerbar button:focus:not(.suggested-action):not(.destructive-action), headerbar.flat button:focus:not(.suggested-action):not(.destructive-action), .content-pane headerbar button:hover:not(.suggested-action):not(.destructive-action), .info headerbar button:hover:not(.suggested-action):not(.destructive-action), .about headerbar button:hover:not(.suggested-action):not(.destructive-action), headerbar.flat button:hover:not(.suggested-action):not(.destructive-action), .content-pane headerbar button:active:not(.suggested-action):not(.destructive-action), .info headerbar button:active:not(.suggested-action):not(.destructive-action), .about headerbar button:active:not(.suggested-action):not(.destructive-action), headerbar.flat button:active:not(.suggested-action):not(.destructive-action), .content-pane headerbar button:checked:not(.suggested-action):not(.destructive-action), .info headerbar button:checked:not(.suggested-action):not(.destructive-action), .about headerbar button:checked:not(.suggested-action):not(.destructive-action), headerbar.flat button:checked:not(.suggested-action):not(.destructive-action) {
  color: white;
}

.content-pane headerbar button:disabled:not(.suggested-action):not(.destructive-action), .info headerbar button:disabled:not(.suggested-action):not(.destructive-action), .about headerbar button:disabled:not(.suggested-action):not(.destructive-action), headerbar.flat button:disabled:not(.suggested-action):not(.destructive-action) {
  color: rgba(255, 255, 255, 0.3);
}

.content-pane headerbar button:checked:disabled:not(.suggested-action):not(.destructive-action), .info headerbar button:checked:disabled:not(.suggested-action):not(.destructive-action), .about headerbar button:checked:disabled:not(.suggested-action):not(.destructive-action), headerbar.flat button:checked:disabled:not(.suggested-action):not(.destructive-action) {
  background-color: transparent;
  color: rgba(255, 255, 255, 0.5);
}

.content-pane headerbar button:backdrop:not(.suggested-action):not(.destructive-action), .info headerbar button:backdrop:not(.suggested-action):not(.destructive-action), .about headerbar button:backdrop:not(.suggested-action):not(.destructive-action), headerbar.flat button:backdrop:not(.suggested-action):not(.destructive-action) {
  color: rgba(255, 255, 255, 0.5);
}

.content-pane headerbar button:backdrop:focus:not(.suggested-action):not(.destructive-action), .info headerbar button:backdrop:focus:not(.suggested-action):not(.destructive-action), .about headerbar button:backdrop:focus:not(.suggested-action):not(.destructive-action), headerbar.flat button:backdrop:focus:not(.suggested-action):not(.destructive-action), .content-pane headerbar button:backdrop:hover:not(.suggested-action):not(.destructive-action), .info headerbar button:backdrop:hover:not(.suggested-action):not(.destructive-action), .about headerbar button:backdrop:hover:not(.suggested-action):not(.destructive-action), headerbar.flat button:backdrop:hover:not(.suggested-action):not(.destructive-action), .content-pane headerbar button:backdrop:active:not(.suggested-action):not(.destructive-action), .info headerbar button:backdrop:active:not(.suggested-action):not(.destructive-action), .about headerbar button:backdrop:active:not(.suggested-action):not(.destructive-action), headerbar.flat button:backdrop:active:not(.suggested-action):not(.destructive-action) {
  color: rgba(255, 255, 255, 0.7);
}

.content-pane headerbar button:backdrop:disabled:not(.suggested-action):not(.destructive-action), .info headerbar button:backdrop:disabled:not(.suggested-action):not(.destructive-action), .about headerbar button:backdrop:disabled:not(.suggested-action):not(.destructive-action), headerbar.flat button:backdrop:disabled:not(.suggested-action):not(.destructive-action) {
  color: rgba(255, 255, 255, 0.3);
}

.content-pane headerbar button:backdrop:checked:not(.suggested-action):not(.destructive-action), .info headerbar button:backdrop:checked:not(.suggested-action):not(.destructive-action), .about headerbar button:backdrop:checked:not(.suggested-action):not(.destructive-action), headerbar.flat button:backdrop:checked:not(.suggested-action):not(.destructive-action) {
  color: rgba(255, 255, 255, 0.7);
}

.content-pane headerbar button:backdrop:checked:disabled:not(.suggested-action):not(.destructive-action), .info headerbar button:backdrop:checked:disabled:not(.suggested-action):not(.destructive-action), .about headerbar button:backdrop:checked:disabled:not(.suggested-action):not(.destructive-action), headerbar.flat button:backdrop:checked:disabled:not(.suggested-action):not(.destructive-action) {
  color: rgba(255, 255, 255, 0.3);
}

headerbar button:not(.suggested-action):not(.destructive-action) {
  color: rgba(255, 255, 255, 0.7);
}

headerbar button:focus:not(.suggested-action):not(.destructive-action), headerbar button:hover:not(.suggested-action):not(.destructive-action), headerbar button:active:not(.suggested-action):not(.destructive-action), headerbar button:checked:not(.suggested-action):not(.destructive-action) {
  color: white;
}

headerbar button:disabled:not(.suggested-action):not(.destructive-action) {
  color: rgba(255, 255, 255, 0.3);
}

headerbar button:checked:disabled:not(.suggested-action):not(.destructive-action) {
  background-color: transparent;
  color: rgba(255, 255, 255, 0.5);
}

headerbar button:backdrop:not(.suggested-action):not(.destructive-action) {
  color: rgba(255, 255, 255, 0.5);
}

headerbar button:backdrop:focus:not(.suggested-action):not(.destructive-action), headerbar button:backdrop:hover:not(.suggested-action):not(.destructive-action), headerbar button:backdrop:active:not(.suggested-action):not(.destructive-action) {
  color: rgba(255, 255, 255, 0.7);
}

headerbar button:backdrop:disabled:not(.suggested-action):not(.destructive-action) {
  color: rgba(255, 255, 255, 0.3);
}

headerbar button:backdrop:checked:not(.suggested-action):not(.destructive-action) {
  color: rgba(255, 255, 255, 0.7);
}

headerbar button:backdrop:checked:disabled:not(.suggested-action):not(.destructive-action) {
  color: rgba(255, 255, 255, 0.3);
}

headerbar entry {
  caret-color: white;
}

headerbar entry, headerbar entry:drop(active), headerbar entry:focus-within {
  color: white;
}

headerbar entry:not(:disabled):not(:focus-within):hover {
  color: white;
}

headerbar entry:disabled {
  color: rgba(255, 255, 255, 0.5);
}

headerbar entry > text > placeholder {
  color: rgba(255, 255, 255, 0.5);
}

headerbar entry > text > block-cursor {
  color: #2C2C2C;
  background-color: white;
}

headerbar entry > image {
  color: rgba(255, 255, 255, 0.7);
}

headerbar entry > image:hover, headerbar entry > image:active {
  color: white;
}

headerbar entry > image:disabled {
  color: rgba(255, 255, 255, 0.5);
}

headerbar {
  transition: background-color 75ms cubic-bezier(0, 0, 0.2, 1), color 75ms cubic-bezier(0, 0, 0.2, 1);
  box-shadow: inset 0 -1px rgba(255, 255, 255, 0.12), inset 0 1px rgba(255, 255, 255, 0.1);
  color: white;
  min-height: 48px;
  padding: 0;
  margin: 0;
  background-color: #2C2C2C;
  border-radius: 18px 18px 0 0;
}

headerbar:disabled {
  color: rgba(255, 255, 255, 0.5);
}

headerbar:backdrop {
  color: rgba(255, 255, 255, 0.7);
  background-color: #3C3C3C;
  filter: none;
}

headerbar:backdrop > windowhandle {
  filter: none;
  transition: none;
}

headerbar:backdrop:disabled {
  color: rgba(255, 255, 255, 0.3);
}

.info headerbar, .about headerbar, headerbar.flat {
  color: white;
}

.info headerbar, .info headerbar:backdrop, .about headerbar, .about headerbar:backdrop, headerbar.flat, headerbar.flat:backdrop {
  background-color: transparent;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
}

.info headerbar .subtitle,
.info headerbar .dim-label,
.info headerbar row.expander:not(:checked) image.expander-row-arrow,
row.expander:not(:checked) .info headerbar image.expander-row-arrow,
.info headerbar row.property > box.header > box.title > .title,
.info headerbar row label.subtitle,
row .info headerbar label.subtitle,
.info .content-pane headerbar entry > text > placeholder,
.content-pane .info headerbar entry > text > placeholder,
.info headerbar entry > text > placeholder, .about headerbar .subtitle,
.about headerbar .dim-label,
.about headerbar row.expander:not(:checked) image.expander-row-arrow,
row.expander:not(:checked) .about headerbar image.expander-row-arrow,
.about headerbar row.property > box.header > box.title > .title,
.about headerbar row label.subtitle,
row .about headerbar label.subtitle,
.about .content-pane headerbar entry > text > placeholder,
.content-pane .about headerbar entry > text > placeholder,
.about headerbar entry > text > placeholder, headerbar.flat .subtitle,
headerbar.flat .dim-label,
headerbar.flat row.expander:not(:checked) image.expander-row-arrow,
row.expander:not(:checked) headerbar.flat image.expander-row-arrow,
headerbar.flat row.property > box.header > box.title > .title,
headerbar.flat row label.subtitle,
row headerbar.flat label.subtitle,
.content-pane headerbar.flat entry > text > placeholder,
headerbar.flat entry > text > placeholder {
  color: rgba(255, 255, 255, 0.7);
}

.info headerbar .subtitle:backdrop,
.info headerbar .dim-label:backdrop,
.info headerbar row.expander:not(:checked) image.expander-row-arrow:backdrop,
row.expander:not(:checked) .info headerbar image.expander-row-arrow:backdrop,
.info headerbar row.property > box.header > box.title > .title:backdrop,
.info headerbar row label.subtitle:backdrop,
row .info headerbar label.subtitle:backdrop,
.info .content-pane headerbar entry > text > placeholder:backdrop,
.content-pane .info headerbar entry > text > placeholder:backdrop,
.info headerbar entry > text > placeholder:backdrop, .about headerbar .subtitle:backdrop,
.about headerbar .dim-label:backdrop,
.about headerbar row.expander:not(:checked) image.expander-row-arrow:backdrop,
row.expander:not(:checked) .about headerbar image.expander-row-arrow:backdrop,
.about headerbar row.property > box.header > box.title > .title:backdrop,
.about headerbar row label.subtitle:backdrop,
row .about headerbar label.subtitle:backdrop,
.about .content-pane headerbar entry > text > placeholder:backdrop,
.content-pane .about headerbar entry > text > placeholder:backdrop,
.about headerbar entry > text > placeholder:backdrop, headerbar.flat .subtitle:backdrop,
headerbar.flat .dim-label:backdrop,
headerbar.flat row.expander:not(:checked) image.expander-row-arrow:backdrop,
row.expander:not(:checked) headerbar.flat image.expander-row-arrow:backdrop,
headerbar.flat row.property > box.header > box.title > .title:backdrop,
headerbar.flat row label.subtitle:backdrop,
row headerbar.flat label.subtitle:backdrop,
.content-pane headerbar.flat entry > text > placeholder:backdrop,
headerbar.flat entry > text > placeholder:backdrop {
  color: rgba(255, 255, 255, 0.5);
}

headerbar .title {
  padding: 0 12px;
  font-weight: bold;
}

headerbar .subtitle {
  padding: 0 12px;
  font-size: smaller;
}

headerbar .subtitle,
headerbar .dim-label,
headerbar row.expander:not(:checked) image.expander-row-arrow,
row.expander:not(:checked) headerbar image.expander-row-arrow,
headerbar row.property > box.header > box.title > .title,
headerbar row label.subtitle,
row headerbar label.subtitle,
.content-pane headerbar entry > text > placeholder,
headerbar entry > text > placeholder {
  transition: color 75ms cubic-bezier(0, 0, 0.2, 1);
  color: rgba(255, 255, 255, 0.7);
}

headerbar .subtitle:backdrop,
headerbar .dim-label:backdrop,
headerbar row.expander:not(:checked) image.expander-row-arrow:backdrop,
row.expander:not(:checked) headerbar image.expander-row-arrow:backdrop,
headerbar row.property > box.header > box.title > .title:backdrop,
headerbar row label.subtitle:backdrop,
row headerbar label.subtitle:backdrop,
.content-pane headerbar entry > text > placeholder:backdrop,
headerbar entry > text > placeholder:backdrop {
  color: rgba(255, 255, 255, 0.5);
}

headerbar headerbar {
  background-color: transparent;
  box-shadow: none;
}

headerbar splitbutton {
  border-radius: 9999px;
}

headerbar splitbutton > button, headerbar splitbutton > menubutton > button {
  min-height: 24px;
  min-width: 24px;
  padding: 6px;
  border-radius: 9999px;
}

headerbar splitbutton > button:dir(ltr),
headerbar splitbutton > menubutton > button:dir(rtl) {
  border-top-right-radius: 9999px;
  border-bottom-right-radius: 9999px;
}

headerbar splitbutton > button:dir(rtl),
headerbar splitbutton > menubutton > button:dir(ltr) {
  border-top-left-radius: 9999px;
  border-bottom-left-radius: 9999px;
}

headerbar .linked:not(.vertical) > entry:not(:only-child) {
  border-radius: 12px;
}

headerbar .linked:not(.vertical) > button:not(.suggested-action):not(.destructive-action) {
  border-radius: 9999px;
}

headerbar button.suggested-action:disabled,
headerbar button.destructive-action:disabled {
  background-color: rgba(255, 255, 255, 0.04);
  color: rgba(255, 255, 255, 0.5);
}

headerbar button.toggle {
  border-radius: 9999px;
}

headerbar popover.background button, headerbar popover.background entry, headerbar popover.background spinbutton {
  border-radius: 5px;
}

headerbar popover.background .linked:not(.vertical) > button:not(.suggested-action):not(.destructive-action) {
  border-radius: 0;
}

headerbar popover.background .linked:not(.vertical) > button:not(.suggested-action):not(.destructive-action):first-child {
  border-radius: 5px 0 0 5px;
}

headerbar popover.background .linked:not(.vertical) > button:not(.suggested-action):not(.destructive-action):last-child {
  border-radius: 0 5px 5px 0;
}

headerbar popover.background .linked:not(.vertical) > button:not(.suggested-action):not(.destructive-action):only-child {
  border-radius: 5px;
}

headerbar stackswitcher {
  border-radius: 9999px;
}

headerbar stackswitcher.linked:not(.vertical) > button:not(.suggested-action):not(.destructive-action).text-button {
  border-radius: 9999px;
  color: rgba(255, 255, 255, 0.7);
}

headerbar stackswitcher.linked:not(.vertical) > button:not(.suggested-action):not(.destructive-action).text-button:focus, headerbar stackswitcher.linked:not(.vertical) > button:not(.suggested-action):not(.destructive-action).text-button:hover, headerbar stackswitcher.linked:not(.vertical) > button:not(.suggested-action):not(.destructive-action).text-button:active {
  color: white;
}

headerbar stackswitcher.linked:not(.vertical) > button:not(.suggested-action):not(.destructive-action).text-button:disabled {
  color: rgba(255, 255, 255, 0.3);
}

headerbar stackswitcher.linked:not(.vertical) > button:not(.suggested-action):not(.destructive-action).text-button:checked {
  color: white;
}

headerbar stackswitcher.linked:not(.vertical) > button:not(.suggested-action):not(.destructive-action).text-button:checked:disabled {
  color: rgba(255, 255, 255, 0.5);
}

headerbar stackswitcher.linked:not(.vertical) > button:not(.suggested-action):not(.destructive-action).text-button:backdrop {
  color: rgba(255, 255, 255, 0.5);
}

headerbar stackswitcher.linked:not(.vertical) > button:not(.suggested-action):not(.destructive-action).text-button:backdrop:focus, headerbar stackswitcher.linked:not(.vertical) > button:not(.suggested-action):not(.destructive-action).text-button:backdrop:hover, headerbar stackswitcher.linked:not(.vertical) > button:not(.suggested-action):not(.destructive-action).text-button:backdrop:active {
  color: rgba(255, 255, 255, 0.7);
}

headerbar stackswitcher.linked:not(.vertical) > button:not(.suggested-action):not(.destructive-action).text-button:backdrop:disabled {
  color: rgba(255, 255, 255, 0.3);
}

headerbar stackswitcher.linked:not(.vertical) > button:not(.suggested-action):not(.destructive-action).text-button:backdrop:checked {
  color: rgba(255, 255, 255, 0.5);
}

headerbar stackswitcher.linked:not(.vertical) > button:not(.suggested-action):not(.destructive-action).text-button:backdrop:checked:disabled {
  color: rgba(255, 255, 255, 0.3);
}

headerbar > windowhandle > box {
  padding: 6px;
}

headerbar > windowhandle > box,
headerbar > windowhandle > box > box.start,
headerbar > windowhandle > box > box.end {
  border-spacing: 6px;
}

headerbar > windowhandle > box > box.start:dir(ltr),
headerbar > windowhandle > box > box.end:dir(rtl), headerbar > windowhandle > box > widget > box.start:dir(ltr),
headerbar > windowhandle > box > widget > box.end:dir(rtl) {
  margin-right: 6px;
}

headerbar > windowhandle > box > box.start:dir(rtl),
headerbar > windowhandle > box > box.end:dir(ltr), headerbar > windowhandle > box > widget > box.start:dir(rtl),
headerbar > windowhandle > box > widget > box.end:dir(ltr) {
  margin-left: 6px;
}

headerbar switch {
  margin-top: 9px;
  margin-bottom: 9px;
}

headerbar.selection-mode {
  transition: background-color 0.1ms 225ms, color 75ms cubic-bezier(0, 0, 0.2, 1);
  animation: ripple-on-headerbar 225ms cubic-bezier(0, 0, 0.2, 1);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.12);
  background-color: #3281EA;
  color: white;
}

headerbar.selection-mode:backdrop {
  color: rgba(255, 255, 255, 0.7);
}

headerbar.selection-mode .subtitle:link {
  color: white;
}

headerbar.selection-mode .selection-menu {
  padding-left: 16px;
  padding-right: 16px;
}

headerbar.selection-mode .selection-menu .arrow {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

headerbar .selection-mode {
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.12);
  background-color: #3281EA;
}

.tiled headerbar, .tiled-top headerbar, .tiled-right headerbar, .tiled-bottom headerbar, .tiled-left headerbar, .maximized headerbar, .fullscreen headerbar {
  border-radius: 0;
  box-shadow: inset 0 -1px rgba(255, 255, 255, 0.12);
}

headerbar.default-decoration {
  min-height: 24px;
  padding: 0;
  background-image: none;
  background-color: #2C2C2C;
  border-radius: 18px 18px 0 0;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
}

.tiled headerbar.default-decoration, .maximized headerbar.default-decoration, .fullscreen headerbar.default-decoration {
  box-shadow: none;
  border-radius: 0;
}

headerbar.default-decoration > windowhandle > box {
  padding: 0 6px;
}

headerbar.default-decoration windowcontrols button,
headerbar.default-decoration windowcontrols menubutton {
  padding: 0;
  min-height: 24px;
  min-width: 24px;
  margin: 6px 0;
}

.solid-csd headerbar:dir(rtl), .solid-csd headerbar:dir(ltr) {
  border-radius: 0;
  box-shadow: none;
}

window.devel headerbar > windowhandle {
  background-image: cross-fade(5% -gtk-recolor(url("assets/scalable/devel-symbolic.svg")), image(transparent));
  background-repeat: repeat-x;
}

headerbar windowcontrols {
  border-spacing: 6px;
}

headerbar windowcontrols.start:dir(ltr), headerbar windowcontrols.end:dir(rtl) {
  margin-right: 6px;
}

headerbar windowcontrols.start:dir(rtl), headerbar windowcontrols.end:dir(ltr) {
  margin-left: 6px;
}

headerbar windowcontrols button:not(.suggested-action):not(.destructive-action) > image {
  padding: 0;
  border: none;
  outline: none;
  box-shadow: none;
  background-color: transparent;
  background-image: none;
}

/************
 * Pathbars *
 ************/

pathbar > button {
  padding-left: 6px;
  padding-right: 6px;
  border-radius: 12px;
  border-spacing: 3px;
}


pathbar > button label,
pathbar > button image {
  margin-left: 3px;
  margin-right: 3px;
}


pathbar > button label:not(:only-child):first-child {
  margin-left: 0;
}


pathbar > button label:not(:only-child):last-child {
  margin-right: 0;
}


pathbar > button.text-button {
  min-width: 0;
}


pathbar > button.slider-button {
  padding-left: 4px;
  padding-right: 4px;
}

.pathbar {
  background-color: rgba(255, 255, 255, 0.04);
  color: rgba(255, 255, 255, 0.7);
  border: none;
  border-radius: 12px;
  padding: 2px;
}

headerbar .pathbar {
  margin-top: 6px;
  margin-bottom: 6px;
  background-color: rgba(255, 255, 255, 0.04);
  color: rgba(255, 255, 255, 0.7);
}

.pathbar > button {
  margin-top: 0;
  margin-bottom: 0;
  min-height: 20px;
  border-radius: 10px;
  border: none;
  box-shadow: none;
}

.pathbar > button:last-child {
  background-color: alpha(currentColor, 0.1);
  color: white;
}

/**************
 * Tree Views *
 **************/
columnview.view,
treeview.view {
  border-left-color: #404040;
  border-top-color: #404040;
}

columnview.view:selected,
treeview.view:selected {
  background-color: #2C2C2C;
  background-image: image(alpha(currentColor, 0.1));
  box-shadow: none;
}

columnview.view:hover, columnview.view:selected,
treeview.view:hover,
treeview.view:selected {
  border-radius: 0;
  box-shadow: none;
}

columnview.view.separator,
treeview.view.separator {
  min-height: 5px;
  color: rgba(255, 255, 255, 0.12);
}

columnview.view:drop(active),
treeview.view:drop(active) {
  box-shadow: none;
}

columnview.view:drop(active).after,
treeview.view:drop(active).after {
  border-top-style: none;
}

columnview.view:drop(active).before,
treeview.view:drop(active).before {
  border-bottom-style: none;
}

columnview.view > dndtarget:drop(active),
treeview.view > dndtarget:drop(active) {
  border-style: solid none;
  border-width: 1px;
  border-color: alpha(currentColor, 0.06);
}

columnview.view > dndtarget:drop(active).after,
treeview.view > dndtarget:drop(active).after {
  border-top-style: none;
}

columnview.view > dndtarget:drop(active).before,
treeview.view > dndtarget:drop(active).before {
  border-bottom-style: none;
}

columnview.view.expander,
treeview.view.expander {
  min-width: 16px;
  min-height: 16px;
  color: rgba(255, 255, 255, 0.7);
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
}

columnview.view.expander:dir(rtl),
treeview.view.expander:dir(rtl) {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl");
}

columnview.view.expander:checked,
treeview.view.expander:checked {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

columnview.view.expander:hover,
treeview.view.expander:hover {
  color: white;
}

columnview.view.expander:selected,
treeview.view.expander:selected {
  color: #3281EA;
}

columnview.view.expander:selected:hover,
treeview.view.expander:selected:hover {
  color: rgba(50, 129, 234, 0.65);
}

columnview.view.expander:disabled,
treeview.view.expander:disabled {
  color: rgba(255, 255, 255, 0.3);
}

columnview.view.progressbar,
treeview.view.progressbar {
  border-bottom: 6px solid #3281EA;
  box-shadow: none;
  background-color: transparent;
  background-image: none;
}

columnview.view.progressbar:selected:hover,
treeview.view.progressbar:selected:hover {
  box-shadow: none;
}

columnview.view.trough,
treeview.view.trough {
  border-bottom: 6px solid rgba(255, 255, 255, 0.15);
  box-shadow: none;
  background-color: transparent;
  background-image: none;
}

columnview.view.trough:selected:hover,
treeview.view.trough:selected:hover {
  box-shadow: none;
}

columnview.view > header > button,
treeview.view > header > button {
  padding: 2px 6px;
  border-style: none solid solid none;
  border-width: 1px;
  border-color: rgba(255, 255, 255, 0.12);
  border-radius: 0;
  background-clip: border-box;
}

columnview.view > header > button:not(:focus):not(:hover):not(:active),
treeview.view > header > button:not(:focus):not(:hover):not(:active) {
  color: rgba(255, 255, 255, 0.7);
}

columnview.view > header > button, columnview.view > header > button:disabled,
treeview.view > header > button,
treeview.view > header > button:disabled {
  background-color: #2C2C2C;
}

columnview.view > header > button:last-child,
treeview.view > header > button:last-child {
  border-right-style: none;
}

columnview.view > header > button sort-indicator,
treeview.view > header > button sort-indicator {
  min-height: 16px;
  min-width: 16px;
}

columnview.view > header > button sort-indicator.ascending,
treeview.view > header > button sort-indicator.ascending {
  -gtk-icon-source: -gtk-icontheme("pan-up-symbolic");
}

columnview.view > header > button sort-indicator.descending,
treeview.view > header > button sort-indicator.descending {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

columnview.view button.dnd,
columnview.view header.button.dnd,
treeview.view button.dnd,
treeview.view header.button.dnd {
  padding: 2px 6px;
  border-style: none solid solid;
  border-width: 1px;
  border-color: rgba(255, 255, 255, 0.12);
  border-radius: 0;
  box-shadow: none;
  background-color: #2C2C2C;
  background-clip: border-box;
  color: #3281EA;
}

columnview.view acceleditor > label,
treeview.view acceleditor > label {
  background-color: #3281EA;
}

/*********
 * Menus *
 *********/
menubar {
  padding: 0;
  background-color: #2C2C2C;
  color: white;
}

menubar:backdrop {
  background-color: #3C3C3C;
  color: rgba(255, 255, 255, 0.7);
}

.csd menubar {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1);
}

menubar > item {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1);
  min-height: 20px;
  padding: 4px 8px;
  color: rgba(255, 255, 255, 0.7);
}

menubar > item:selected {
  transition: none;
  background-color: alpha(currentColor, 0.1);
  color: white;
}

menubar > item:disabled {
  color: rgba(255, 255, 255, 0.3);
}

menubar > item label:disabled {
  color: inherit;
}

menubar > item popover.menu popover.menu {
  margin-left: 9px;
}

menubar > item popover.menu.background popover.menu.background > contents {
  margin: 0;
}

/**********************
 * Popover Base Menus *
 **********************/
popover.menu box.inline-buttons {
  padding: 0 14px;
}

popover.menu box.inline-buttons button.image-button.model {
  min-height: 28px;
  min-width: 28px;
  padding: 0;
  border: none;
  outline: none;
  transition: none;
}

popover.menu box.inline-buttons button.image-button.model:selected {
  background-image: image(alpha(currentColor, 0.06));
}

popover.menu box.circular-buttons {
  padding: 6px;
}

popover.menu box.circular-buttons button.circular.image-button.model {
  padding: 6px;
}

popover.menu box.circular-buttons button.circular.image-button.model:focus {
  background-color: alpha(currentColor, 0.06);
}

popover.menu arrow.left,
popover.menu radio.left,
popover.menu check.left {
  margin-left: 0;
  margin-right: 0;
}

popover.menu arrow.right,
popover.menu radio.right,
popover.menu check.right {
  margin-left: 0;
  margin-right: 0;
}

popover.menu label.title {
  font-weight: bold;
  padding: 3px 32px;
}

/************
 * Popovers *
 ************/
popover.background {
  font: initial;
  padding: 0;
  color: white;
}

popover.background, popover.background:backdrop {
  background-color: transparent;
}

popover.background > arrow,
popover.background > contents {
  transition: box-shadow 75ms cubic-bezier(0, 0, 0.2, 1);
  padding: 6px;
  box-shadow: 0 3px 3px -1px rgba(0, 0, 0, 0.2), 0 6px 6px 0 rgba(0, 0, 0, 0.14), 0 1px 11px 0 rgba(0, 0, 0, 0.12);
  background-color: #3C3C3C;
  border: none;
  border-radius: 11px;
  color: white;
}

popover.background:backdrop > arrow,
popover.background:backdrop > contents {
  box-shadow: 0 3px 2px -3px rgba(0, 0, 0, 0.3), 0 2px 2px -1px rgba(0, 0, 0, 0.24), 0 1px 3px 0 rgba(0, 0, 0, 0.12);
}

popover.background > contents > list,
popover.background > contents > .view,
popover.background > contents > toolbar {
  border-style: none;
  box-shadow: none;
  background-color: transparent;
}

popover.background > contents > scrolledwindow > viewport > stack > box {
  padding: 0;
}

popover.background > contents separator {
  background-color: rgba(255, 255, 255, 0.12);
  margin: 3px 0;
}

popover.background > contents list {
  background-color: transparent;
  padding: 0;
}

popover.background > contents list > row {
  padding: 6px 12px;
  margin: 0;
}

popover.background > contents list separator {
  margin: 0;
}

popover.background > contents button, popover.background > contents entry, popover.background > contents spinbutton {
  border-radius: 5px;
}

popover.background .view:not(:selected),
popover.background toolbar {
  background-color: #3C3C3C;
}

popover.background .linked > button:not(.radio):first-child {
  border-radius: 5px 0 0 5px;
}

popover.background .linked > button:not(.radio):last-child {
  border-radius: 0 5px 5px 0;
}

popover.background .linked > button:not(.radio):only-child {
  border-radius: 5px;
}

popover.background modelbutton {
  transition: background-color 75ms cubic-bezier(0, 0, 0.2, 1);
  min-height: 22px;
  min-width: 56px;
  padding: 3px 9px;
  border-radius: 5px;
  color: white;
  font: initial;
  text-shadow: none;
  border-spacing: 6px;
}

popover.background modelbutton:focus {
  box-shadow: none;
  outline: none;
}

popover.background modelbutton accelerator {
  color: rgba(255, 255, 255, 0.5);
  margin-left: 30px;
}

popover.background modelbutton accelerator:disabled {
  color: rgba(255, 255, 255, 0.12);
}

popover.background modelbutton arrow.left {
  -gtk-icon-source: -gtk-icontheme("go-previous-symbolic");
}

popover.background modelbutton arrow.right {
  -gtk-icon-source: -gtk-icontheme("go-next-symbolic");
}

popover.background.menu button,
popover.background button.model {
  min-height: 32px;
  padding: 0 8px;
  border-radius: 5px;
}

.osd popover.background, popover.background.touch-selection, popover.background.magnifier {
  background-color: transparent;
}

popover.background listview {
  padding: 0;
}

popover.background listview > row {
  padding: 6px 12px;
  border-radius: 5px;
  margin: 0;
}

magnifier {
  background-color: #2C2C2C;
}

/*************
 * Notebooks *
 *************/
notebook > header tab {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1);
  min-height: 24px;
  min-width: 24px;
  padding: 6px 12px;
  border-width: 1px;
  border-color: transparent;
  border-style: solid;
  outline: none;
  background-clip: padding-box;
  box-shadow: none;
  color: rgba(255, 255, 255, 0.7);
  font-weight: 500;
}

notebook > header tab:hover {
  background-color: #404040;
  color: white;
}

notebook > header tab:disabled {
  color: rgba(255, 255, 255, 0.3);
}

notebook > header tab:checked {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1);
  background-color: #2C2C2C;
  background-clip: padding-box;
  border-color: #404040;
  color: white;
  box-shadow: none;
}

notebook > header tab:checked:disabled {
  color: rgba(255, 255, 255, 0.5);
}

notebook > header tab:checked.reorderable-page {
  background-color: #2C2C2C;
}

notebook {
  background-color: #2C2C2C;
}

frame > paned > notebook > header, notebook.frame > header {
  background-color: #242424;
}

notebook.frame {
  border-radius: 12px;
}

notebook.frame frame > border {
  border: none;
  border-radius: 12px;
}

notebook.frame frame > list row.activatable {
  border-radius: 12px;
}

notebook:focus tab:checked {
  box-shadow: none;
}

notebook.frame > header.top {
  border-radius: 12px 12px 0 0;
}

notebook.frame > header.bottom {
  border-radius: 0 0 12px 12px;
}

notebook.frame > header.left {
  border-radius: 12px 0 0 12px;
}

notebook.frame > header.right {
  border-radius: 0 12px 12px 0;
}

notebook > header {
  border: none;
  background-color: #212121;
  padding: 0;
}

notebook > header.top {
  box-shadow: inset 0 -1px #404040;
}

notebook > header.top > tabs {
  margin: 4px 0 0;
}

notebook > header.top > tabs > tab {
  border-radius: 12px 12px 0 0;
  border-bottom: none;
}

notebook > header.bottom {
  box-shadow: inset 0 1px #404040;
}

notebook > header.bottom > tabs {
  margin: 0 0 4px;
}

notebook > header.bottom > tabs > tab {
  border-radius: 0 0 12px 12px;
  border-top: none;
}

notebook > header.left {
  box-shadow: inset -1px 0 #404040;
}

notebook > header.left > tabs {
  margin: 0 0 0 4px;
}

notebook > header.left > tabs > tab {
  border-radius: 12px 0 0 12px;
  border-right: none;
}

notebook > header.right {
  box-shadow: inset 1px 0 #404040;
}

notebook > header.right > tabs {
  margin: 0 4px 0 0;
}

notebook > header.right > tabs > tab {
  border-radius: 0 12px 12px 0;
  border-left: none;
}

notebook > header.top > tabs > arrow {
  border-top-style: none;
}

notebook > header.bottom > tabs > arrow {
  border-bottom-style: none;
}

notebook > header.top > tabs > arrow, notebook > header.bottom > tabs > arrow {
  padding-left: 4px;
  padding-right: 4px;
}

notebook > header.top > tabs > arrow.down, notebook > header.bottom > tabs > arrow.down {
  margin-left: -8px;
  -gtk-icon-source: -gtk-icontheme("pan-start-symbolic");
}

notebook > header.top > tabs > arrow.up, notebook > header.bottom > tabs > arrow.up {
  margin-right: -8px;
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
}

notebook > header.left > tabs > arrow {
  border-left-style: none;
}

notebook > header.right > tabs > arrow {
  border-right-style: none;
}

notebook > header.left > tabs > arrow, notebook > header.right > tabs > arrow {
  padding-top: 4px;
  padding-bottom: 4px;
}

notebook > header.left > tabs > arrow.down, notebook > header.right > tabs > arrow.down {
  margin-top: -8px;
  -gtk-icon-source: -gtk-icontheme("pan-up-symbolic");
}

notebook > header.left > tabs > arrow.up, notebook > header.right > tabs > arrow.up {
  margin-bottom: -8px;
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

notebook > header > tabs > arrow {
  min-height: 16px;
  min-width: 16px;
  border-radius: 0;
}

notebook > header tab > box {
  transition: background-color 75ms cubic-bezier(0, 0, 0.2, 1);
  margin: -6px -12px;
  padding: 6px 12px;
}

notebook > header tab > box:drop(active) {
  background-color: rgba(255, 255, 255, 0.12);
  color: white;
}

notebook > header tab button.flat:last-child {
  margin-left: 6px;
  margin-right: -6px;
}

notebook > header tab button.flat:first-child {
  margin-left: -6px;
  margin-right: 6px;
}

notebook > header.top tabs, notebook > header.bottom tabs {
  padding-left: 8px;
  padding-right: 8px;
}

notebook > header.top tabs:not(:only-child):first-child, notebook > header.bottom tabs:not(:only-child):first-child {
  margin-left: 0;
}

notebook > header.top tabs:not(:only-child):last-child, notebook > header.bottom tabs:not(:only-child):last-child {
  margin-right: 0;
}

notebook > header.top tabs tab.reorderable-page, notebook > header.bottom tabs tab.reorderable-page {
  border-style: solid;
}

notebook > header.left tabs, notebook > header.right tabs {
  padding-top: 8px;
  padding-bottom: 8px;
}

notebook > header.left tabs:not(:only-child):first-child, notebook > header.right tabs:not(:only-child):first-child {
  margin-top: 0;
}

notebook > header.left tabs:not(:only-child):last-child, notebook > header.right tabs:not(:only-child):last-child {
  margin-bottom: 0;
}

notebook > header.left tabs tab.reorderable-page, notebook > header.right tabs tab.reorderable-page {
  border-style: solid;
}

notebook > stack:not(:only-child) {
  background-color: transparent;
  border-radius: 12px;
}

/**************
 * Scrollbars *
 **************/
scrollbar {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1);
  background-color: #2C2C2C;
}

scrollbar.top {
  border-bottom: 1px solid rgba(255, 255, 255, 0.12);
}

scrollbar.bottom {
  border-top: 1px solid rgba(255, 255, 255, 0.12);
}

scrollbar.left {
  border-right: 1px solid rgba(255, 255, 255, 0.12);
}

scrollbar.right {
  border-left: 1px solid rgba(255, 255, 255, 0.12);
}

scrollbar > range > trough {
  box-shadow: none;
  outline: none;
  background: none;
}

scrollbar > range > trough > slider {
  transition: background-color 75ms cubic-bezier(0, 0, 0.2, 1);
  min-width: 8px;
  min-height: 8px;
  border: 4px solid transparent;
  border-radius: 9999px;
  background-clip: padding-box;
  box-shadow: none;
  outline: none;
  background-color: rgba(255, 255, 255, 0.3);
}

scrollbar > range > trough > slider:hover {
  background-color: rgba(255, 255, 255, 0.5);
}

scrollbar > range > trough > slider:active {
  background-color: rgba(255, 255, 255, 0.7);
}

scrollbar > range > trough > slider:disabled {
  background-color: rgba(255, 255, 255, 0.3);
}

scrollbar > range.fine-tune > trough > slider {
  min-width: 4px;
  min-height: 4px;
}

scrollbar > range.fine-tune.horizontal > trough > slider {
  margin: 3px;
}

scrollbar > range.fine-tune.vertical > trough > slider {
  margin: 3px;
}

scrollbar.overlay-indicator:not(.fine-tune) > range > trough > slider {
  transition-property: background-color, min-height, min-width;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering) {
  border-color: transparent;
  background-color: transparent;
  box-shadow: none;
  outline: none;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering) > range > trough {
  padding: 0;
  margin: 0;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering) > range > trough > slider {
  min-width: 4px;
  min-height: 4px;
  margin: 3px;
  border: 1px solid rgba(44, 44, 44, 0.3);
  box-shadow: none;
  outline: none;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering) button {
  min-width: 4px;
  min-height: 4px;
  margin: 3px;
  border: 1px solid rgba(44, 44, 44, 0.3);
  border-radius: 9999px;
  background-color: rgba(255, 255, 255, 0.5);
  background-clip: padding-box;
  -gtk-icon-source: none;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering) button:disabled {
  background-color: rgba(255, 255, 255, 0.3);
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering).horizontal > range > trough > slider {
  min-width: 24px;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering).horizontal button {
  min-width: 8px;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering).vertical > range > trough > slider {
  min-height: 24px;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering).vertical button {
  min-height: 8px;
}

scrollbar.overlay-indicator.dragging, scrollbar.overlay-indicator.hovering {
  background-color: rgba(60, 60, 60, 0.9);
}

scrollbar.overlay-indicator.dragging > range > trough, scrollbar.overlay-indicator.hovering > range > trough {
  padding: 0;
  margin: 0;
}

scrollbar.overlay-indicator.dragging > range > trough > slider, scrollbar.overlay-indicator.hovering > range > trough > slider {
  margin: 3px;
}

scrollbar.horizontal > range > trough > slider {
  min-width: 24px;
}

scrollbar.vertical > range > trough > slider {
  min-height: 24px;
}

scrollbar button {
  min-width: 16px;
  min-height: 16px;
  padding: 0;
  border-radius: 0;
}

scrollbar.vertical button.down {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

scrollbar.vertical button.up {
  -gtk-icon-source: -gtk-icontheme("pan-up-symbolic");
}

scrollbar.horizontal button.down {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
}

scrollbar.horizontal button.up {
  -gtk-icon-source: -gtk-icontheme("pan-start-symbolic");
}

/**********
 * Switch *
 **********/
switch {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1);
  margin: 6px 0;
  padding: 0 2px;
  border: 5px solid transparent;
  border-radius: 9999px;
  background-color: rgba(255, 255, 255, 0.3);
  background-clip: padding-box;
  font-size: 0;
  color: transparent;
}

switch:checked {
  background-color: color-mix(in srgb, #3281EA 50%, transparent);
}

switch:disabled {
  opacity: 0.5;
}

switch image {
  margin: -8px;
  color: transparent;
}

switch > slider {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1);
  min-width: 20px;
  min-height: 20px;
  margin: -3px -2px;
  border-radius: 9999px;
  outline: none;
  box-shadow: 0 0 0 10px transparent, 0 2px 2px -2px rgba(0, 0, 0, 0.3), 0 1px 2px -1px rgba(0, 0, 0, 0.24), 0 1px 2px -1px rgba(0, 0, 0, 0.17);
  background-color: #3C3C3C;
}

switch:focus > slider {
  box-shadow: 0 0 0 10px alpha(currentColor, 0.08), 0 2px 2px -2px rgba(0, 0, 0, 0.3), 0 1px 2px -1px rgba(0, 0, 0, 0.24), 0 1px 2px -1px rgba(0, 0, 0, 0.17);
}

switch:hover > slider {
  box-shadow: 0 0 0 10px alpha(currentColor, 0.08), 0 2px 2px -2px rgba(0, 0, 0, 0.3), 0 1px 2px -1px rgba(0, 0, 0, 0.24), 0 1px 2px -1px rgba(0, 0, 0, 0.17);
}

switch:focus:hover > slider {
  box-shadow: 0 0 0 10px alpha(currentColor, 0.16), 0 2px 2px -2px rgba(0, 0, 0, 0.3), 0 1px 2px -1px rgba(0, 0, 0, 0.24), 0 1px 2px -1px rgba(0, 0, 0, 0.17);
}

switch:checked > slider {
  background-color: #3281EA;
  color: #3281EA;
}

/*************************
 * Check and Radio items *
 *************************/
checkbutton,
radiobutton {
  outline: none;
  border-spacing: 4px;
}

checkbutton.text-button,
radiobutton.text-button {
  padding: 3px;
}

checkbutton.text-button label:not(:only-child),
radiobutton.text-button label:not(:only-child) {
  margin: 0 4px;
}

popover checkbutton.text-button > check:dir(ltr), popover radiobutton.text-button > check:dir(ltr) {
  margin-left: -16px;
}

popover checkbutton.text-button > check:dir(rtl), popover radiobutton.text-button > check:dir(rtl) {
  margin-right: -16px;
}

check,
radio {
  min-height: 24px;
  min-width: 24px;
  margin: -8px;
  padding: 8px;
  border: none;
}

check:checked, check:indeterminate,
radio:checked,
radio:indeterminate {
  color: #81C995;
}

check:checked:disabled, check:indeterminate:disabled,
radio:checked:disabled,
radio:indeterminate:disabled {
  color: rgba(255, 255, 255, 0.3);
}

check:not(:hover):focus,
radio:not(:hover):focus {
  background-color: transparent;
}

popover modelbutton check, popover modelbutton radio {
  margin: 0;
  padding: 0;
}

popover modelbutton check, popover modelbutton check:focus, popover modelbutton check:hover, popover modelbutton check:focus:hover, popover modelbutton check:active, popover modelbutton check:disabled, popover modelbutton radio, popover modelbutton radio:focus, popover modelbutton radio:hover, popover modelbutton radio:focus:hover, popover modelbutton radio:active, popover modelbutton radio:disabled {
  transition: none;
  box-shadow: none;
  background: none;
  border: none;
}

popover modelbutton check:not(:checked):not(:indeterminate):not(:disabled), popover modelbutton radio:not(:checked):not(:indeterminate):not(:disabled) {
  color: rgba(255, 255, 255, 0.7);
}

popover modelbutton check, popover modelbutton check:hover, popover modelbutton check:disabled, popover modelbutton radio, popover modelbutton radio:hover, popover modelbutton radio:disabled {
  box-shadow: none;
}

popover modelbutton check.left:dir(rtl), popover modelbutton radio.left:dir(rtl) {
  margin-left: -12px;
  margin-right: -4px;
}

popover modelbutton check.right:dir(ltr), popover modelbutton radio.right:dir(ltr) {
  margin-left: -4px;
  margin-right: -12px;
}


check {
  -gtk-icon-size: 24px;
  -gtk-icon-source: -gtk-scaled(-gtk-recolor(url("assets/scalable/unchecked-symbolic.svg")), -gtk-recolor(url("assets/scalable/unchecked-symbolic@2.svg")));
}


check:checked {
  -gtk-icon-source: -gtk-scaled(-gtk-recolor(url("assets/scalable/checkbox-checked-symbolic.svg")), -gtk-recolor(url("assets/scalable/checkbox-checked-symbolic@2.svg")));
}


check:indeterminate {
  -gtk-icon-source: -gtk-scaled(-gtk-recolor(url("assets/scalable/mixed-symbolic.svg")), -gtk-recolor(url("assets/scalable/mixed-symbolic@2.svg")));
}


radio {
  -gtk-icon-size: 24px;
  -gtk-icon-source: -gtk-scaled(-gtk-recolor(url("assets/scalable/unchecked-symbolic.svg")), -gtk-recolor(url("assets/scalable/unchecked-symbolic@2.svg")));
}


radio:checked {
  -gtk-icon-source: -gtk-scaled(-gtk-recolor(url("assets/scalable/radio-checked-symbolic.svg")), -gtk-recolor(url("assets/scalable/radio-checked-symbolic@2.svg")));
}


radio:indeterminate {
  -gtk-icon-source: -gtk-scaled(-gtk-recolor(url("assets/scalable/mixed-symbolic.svg")), -gtk-recolor(url("assets/scalable/mixed-symbolic@2.svg")));
}


popover.menu check {
  min-height: 18px;
  min-width: 18px;
  -gtk-icon-size: 18px;
  -gtk-icon-source: -gtk-scaled(-gtk-recolor(url("assets/scalable/small-unchecked-symbolic.svg")), -gtk-recolor(url("assets/scalable/small-unchecked-symbolic@2.svg")));
}


popover.menu check:checked {
  -gtk-icon-source: -gtk-scaled(-gtk-recolor(url("assets/scalable/small-checkbox-checked-symbolic.svg")), -gtk-recolor(url("assets/scalable/small-checkbox-checked-symbolic@2.svg")));
}


popover.menu check:indeterminate {
  -gtk-icon-source: -gtk-scaled(-gtk-recolor(url("assets/scalable/small-mixed-symbolic.svg")), -gtk-recolor(url("assets/scalable/small-mixed-symbolic@2.svg")));
}


popover.menu radio {
  min-height: 18px;
  min-width: 18px;
  border-image: none;
  -gtk-icon-size: 18px;
  -gtk-icon-source: -gtk-scaled(-gtk-recolor(url("assets/scalable/small-unchecked-symbolic.svg")), -gtk-recolor(url("assets/scalable/small-unchecked-symbolic@2.svg")));
}


popover.menu radio:checked {
  -gtk-icon-source: -gtk-scaled(-gtk-recolor(url("assets/scalable/small-radio-checked-symbolic.svg")), -gtk-recolor(url("assets/scalable/small-radio-checked-symbolic@2.svg")));
}


popover.menu radio:indeterminate {
  -gtk-icon-source: -gtk-scaled(-gtk-recolor(url("assets/scalable/small-mixed-symbolic.svg")), -gtk-recolor(url("assets/scalable/small-mixed-symbolic@2.svg")));
}

treeview.view check, treeview.view radio,
columnview.view check,
columnview.view radio {
  padding: 0;
  box-shadow: none;
  background: none;
  color: rgba(255, 255, 255, 0.7);
}

treeview.view check:hover, treeview.view check:active, treeview.view radio:hover, treeview.view radio:active,
columnview.view check:hover,
columnview.view check:active,
columnview.view radio:hover,
columnview.view radio:active {
  color: white;
}

treeview.view check:disabled, treeview.view radio:disabled,
columnview.view check:disabled,
columnview.view radio:disabled {
  color: rgba(255, 255, 255, 0.3);
}

treeview.view check:checked, treeview.view check:indeterminate, treeview.view radio:checked, treeview.view radio:indeterminate,
columnview.view check:checked,
columnview.view check:indeterminate,
columnview.view radio:checked,
columnview.view radio:indeterminate {
  color: #81C995;
}

treeview.view check:checked:disabled, treeview.view check:indeterminate:disabled, treeview.view radio:checked:disabled, treeview.view radio:indeterminate:disabled,
columnview.view check:checked:disabled,
columnview.view check:indeterminate:disabled,
columnview.view radio:checked:disabled,
columnview.view radio:indeterminate:disabled {
  color: rgba(255, 255, 255, 0.3);
}

treeview.view:hover check, treeview.view:hover radio, treeview.view:selected check, treeview.view:selected radio, treeview.view:focus check, treeview.view:focus radio, treeview.view:focus-within check, treeview.view:focus-within radio,
columnview.view:hover check,
columnview.view:hover radio,
columnview.view:selected check,
columnview.view:selected radio,
columnview.view:focus check,
columnview.view:focus radio,
columnview.view:focus-within check,
columnview.view:focus-within radio {
  box-shadow: none;
  background-color: transparent;
}

treeview.view radio:checked {
  -gtk-icon-source: -gtk-recolor(url("assets/scalable/radio-checked-symbolic.svg"));
  border-image: none;
}

checkbutton.selection-mode {
  border-radius: 9999px;
}

checkbutton.selection-mode check, checkbutton.selection-mode radio {
  padding: 6px;
  border-radius: 9999px;
  -gtk-icon-size: 36px;
  -gtk-icon-source: -gtk-scaled(-gtk-recolor(url("assets/scalable/selection-unchecked-symbolic.svg")), -gtk-recolor(url("assets/scalable/selection-unchecked-symbolic@2.svg")));
}

checkbutton.selection-mode check:checked, checkbutton.selection-mode radio:checked {
  -gtk-icon-source: -gtk-scaled(-gtk-recolor(url("assets/scalable/selection-checked-symbolic.svg")), -gtk-recolor(url("assets/scalable/selection-checked-symbolic@2.svg")));
}

checkbutton.selection-mode label:dir(ltr) {
  margin-right: 6px;
}

checkbutton.selection-mode label:dir(rtl) {
  margin-left: 6px;
}

/************
 * GtkScale *
 ************/
scale {
  min-height: 2px;
  min-width: 2px;
}

scale.horizontal {
  padding: 17px 12px;
}

scale.vertical {
  padding: 12px 17px;
}

scale.fine-tune.horizontal {
  min-height: 4px;
  padding-top: 16px;
  padding-bottom: 16px;
}

scale.fine-tune.vertical {
  min-width: 4px;
  padding-left: 16px;
  padding-right: 16px;
}

scale.fine-tune > trough > slider {
  min-height: 32px;
  min-width: 32px;
  margin: -14px;
}

scale > trough {
  transition: background-color 75ms cubic-bezier(0, 0, 0.2, 1);
  outline: none;
  background-color: rgba(255, 255, 255, 0.3);
}

scale > trough:disabled {
  background-color: rgba(255, 255, 255, 0.15);
}

scale > trough > slider {
  transition: background-color 75ms cubic-bezier(0, 0, 0.2, 1), background-size 300ms cubic-bezier(0, 0, 0.2, 1), background-image 1200ms cubic-bezier(0, 0, 0.2, 1);
  background-repeat: no-repeat;
  background-position: center;
  background-size: auto, 1000% 1000%;
  min-height: 32px;
  min-width: 32px;
  margin: -15px;
  border-radius: 50%;
  color: #3281EA;
  background-color: transparent;
}

scale > trough > slider, scale > trough > slider:focus, scale > trough > slider:hover, scale > trough > slider:active {
  border: none;
  box-shadow: none;
  outline: none;
}

scale > trough > slider {
  background-image: -gtk-scaled(url("assets/scale-slider-dark.png"), url("assets/scale-slider-dark@2.png")), radial-gradient(circle, transparent 10%, transparent 0%);
}

scale > trough > slider:disabled {
  background-image: -gtk-scaled(url("assets/scale-slider-disabled-dark.png"), url("assets/scale-slider-disabled-dark@2.png")), radial-gradient(circle, transparent 10%, transparent 0%);
}

scale > trough > slider:focus {
  background-color: alpha(currentColor, 0.08);
}

scale > trough > slider:hover {
  background-color: alpha(currentColor, 0.08);
}

scale > trough > slider:focus:hover {
  background-color: alpha(currentColor, 0.16);
}

scale > trough > slider:active {
  transition: background-color 75ms cubic-bezier(0, 0, 0.2, 1), background-size 0, background-image 0;
  background-image: -gtk-scaled(url("assets/scale-slider-dark.png"), url("assets/scale-slider-dark@2.png")), radial-gradient(circle, alpha(currentColor, 0.12) 10%, transparent 0%);
  background-size: auto, 0% 0%;
  color: #3281EA;
}

scale > trough > highlight {
  transition: background-color 75ms cubic-bezier(0, 0, 0.2, 1);
  background-color: #3281EA;
}

scale > trough > highlight:disabled {
  background-color: rgba(255, 255, 255, 0.3);
}

scale > trough > fill {
  transition: background-color 75ms cubic-bezier(0, 0, 0.2, 1);
  background-color: rgba(255, 255, 255, 0.3);
}

scale > trough > fill:disabled {
  background-color: transparent;
}

scale > marks,
scale > value {
  color: rgba(255, 255, 255, 0.7);
}

scale > marks indicator {
  background-color: rgba(255, 255, 255, 0.3);
  color: transparent;
}

scale.horizontal marks.top {
  margin-bottom: 7px;
  margin-top: -15px;
}

scale.horizontal.fine-tune marks.top {
  margin-bottom: 6px;
  margin-top: -14px;
}

scale.horizontal marks.bottom {
  margin-top: 7px;
  margin-bottom: -15px;
}

scale.horizontal.fine-tune marks.bottom {
  margin-top: 6px;
  margin-bottom: -14px;
}

scale.vertical marks.top {
  margin-right: 7px;
  margin-left: -15px;
}

scale.vertical.fine-tune marks.top {
  margin-right: 6px;
  margin-left: -14px;
}

scale.vertical marks.bottom {
  margin-left: 7px;
  margin-right: -15px;
}

scale.vertical.fine-tune marks.bottom {
  margin-left: 6px;
  margin-right: -14px;
}

scale.horizontal > marks indicator {
  min-height: 8px;
  min-width: 1px;
}

scale.vertical > marks indicator {
  min-height: 1px;
  min-width: 8px;
}

scale.marks-before:not(.marks-after) > trough > slider, scale.marks-after:not(.marks-before) > trough > slider {
  transform: none;
  box-shadow: none;
  border: none;
}

scale.marks-before:not(.marks-after) > trough > slider:disabled, scale.marks-after:not(.marks-before) > trough > slider:disabled {
  box-shadow: none;
}

scale.horizontal.marks-before:not(.marks-after) > trough > slider {
  background-image: -gtk-scaled(url("assets/scale-horz-marks-before-slider-dark.png"), url("assets/scale-horz-marks-before-slider-dark@2.png")), radial-gradient(circle, transparent 10%, transparent 0%);
}

scale.horizontal.marks-before:not(.marks-after) > trough > slider:disabled {
  background-image: -gtk-scaled(url("assets/scale-horz-marks-before-slider-disabled-dark.png"), url("assets/scale-horz-marks-before-slider-disabled-dark@2.png")), radial-gradient(circle, transparent 10%, transparent 0%);
}

scale.horizontal.marks-before:not(.marks-after) > trough > slider:active {
  background-image: -gtk-scaled(url("assets/scale-horz-marks-before-slider-dark.png"), url("assets/scale-horz-marks-before-slider-dark@2.png")), radial-gradient(circle, alpha(currentColor, 0.12) 10%, transparent 0%);
}

scale.horizontal.marks-after:not(.marks-before) > trough > slider {
  background-image: -gtk-scaled(url("assets/scale-horz-marks-after-slider-dark.png"), url("assets/scale-horz-marks-after-slider-dark@2.png")), radial-gradient(circle, transparent 10%, transparent 0%);
}

scale.horizontal.marks-after:not(.marks-before) > trough > slider:disabled {
  background-image: -gtk-scaled(url("assets/scale-horz-marks-after-slider-disabled-dark.png"), url("assets/scale-horz-marks-after-slider-disabled-dark@2.png")), radial-gradient(circle, transparent 10%, transparent 0%);
}

scale.horizontal.marks-after:not(.marks-before) > trough > slider:active {
  background-image: -gtk-scaled(url("assets/scale-horz-marks-after-slider-dark.png"), url("assets/scale-horz-marks-after-slider-dark@2.png")), radial-gradient(circle, alpha(currentColor, 0.12) 10%, transparent 0%);
}

scale.vertical.marks-before:not(.marks-after) > trough > slider {
  background-image: -gtk-scaled(url("assets/scale-vert-marks-before-slider-dark.png"), url("assets/scale-vert-marks-before-slider-dark@2.png")), radial-gradient(circle, transparent 10%, transparent 0%);
}

scale.vertical.marks-before:not(.marks-after) > trough > slider:disabled {
  background-image: -gtk-scaled(url("assets/scale-vert-marks-before-slider-disabled-dark.png"), url("assets/scale-vert-marks-before-slider-disabled-dark@2.png")), radial-gradient(circle, transparent 10%, transparent 0%);
}

scale.vertical.marks-before:not(.marks-after) > trough > slider:active {
  background-image: -gtk-scaled(url("assets/scale-vert-marks-before-slider-dark.png"), url("assets/scale-vert-marks-before-slider-dark@2.png")), radial-gradient(circle, alpha(currentColor, 0.12) 10%, transparent 0%);
}

scale.vertical.marks-after:not(.marks-before) > trough > slider {
  background-image: -gtk-scaled(url("assets/scale-vert-marks-after-slider-dark.png"), url("assets/scale-vert-marks-after-slider-dark@2.png")), radial-gradient(circle, transparent 10%, transparent 0%);
}

scale.vertical.marks-after:not(.marks-before) > trough > slider:disabled {
  background-image: -gtk-scaled(url("assets/scale-vert-marks-after-slider-disabled-dark.png"), url("assets/scale-vert-marks-after-slider-disabled-dark@2.png")), radial-gradient(circle, transparent 10%, transparent 0%);
}

scale.vertical.marks-after:not(.marks-before) > trough > slider:active {
  background-image: -gtk-scaled(url("assets/scale-vert-marks-after-slider-dark.png"), url("assets/scale-vert-marks-after-slider-dark@2.png")), radial-gradient(circle, alpha(currentColor, 0.12) 10%, transparent 0%);
}

scale.color {
  min-height: 0;
  min-width: 0;
}

scale.color.horizontal {
  padding: 0 0 12px 0;
}

scale.color.horizontal > trough > slider:dir(ltr), scale.color.horizontal > trough > slider:dir(rtl) {
  margin-bottom: -24px;
  margin-top: 8px;
}

scale.color.vertical:dir(ltr) {
  padding: 0 0 0 12px;
}

scale.color.vertical:dir(ltr) > trough > slider {
  margin-left: -24px;
  margin-right: 8px;
}

scale.color.vertical:dir(rtl) {
  padding: 0 12px 0 0;
}

scale.color.vertical:dir(rtl) > trough > slider {
  margin-right: -24px;
  margin-left: 8px;
}

/*****************
 * Progress bars *
 *****************/
progressbar {
  color: rgba(255, 255, 255, 0.7);
  font-size: smaller;
}

progressbar.horizontal trough,
progressbar.horizontal progress {
  min-height: 6px;
}

progressbar.vertical trough,
progressbar.vertical progress {
  min-width: 6px;
}

progressbar trough {
  border-radius: 12px;
  background-color: rgba(255, 255, 255, 0.15);
}

progressbar progress {
  border-radius: 12px;
  background-color: #3281EA;
}

progressbar.osd {
  min-width: 6px;
  min-height: 6px;
  background-color: transparent;
  box-shadow: none;
  margin: 0;
  padding: 0;
}

progressbar.osd trough {
  background-color: transparent;
}

progressbar.osd progress {
  background-color: #3281EA;
}

progressbar trough.empty progress {
  all: unset;
}

/*************
 * Level Bar *
 *************/
levelbar.horizontal block {
  min-height: 6px;
}

levelbar.horizontal.discrete block {
  min-width: 36px;
}

levelbar.horizontal.discrete block:not(:last-child) {
  margin-right: 2px;
}

levelbar.vertical block {
  min-width: 6px;
}

levelbar.vertical.discrete block {
  min-height: 36px;
}

levelbar.vertical.discrete block:not(:last-child) {
  margin-bottom: 2px;
}

levelbar trough {
  border-radius: 12px;
}

levelbar block.low {
  background-color: #FBC02D;
}

levelbar block.high, levelbar block:not(.empty) {
  background-color: #3281EA;
}

levelbar block.full {
  background-color: #81C995;
}

levelbar block.empty {
  background-color: rgba(255, 255, 255, 0.15);
}

/****************
 * Print dialog *
*****************/
window.dialog.print drawing {
  color: white;
  background: none;
  border: none;
  padding: 0;
}

window.dialog.print drawing paper {
  padding: 0;
  border: 1px solid rgba(255, 255, 255, 0.12);
  background-color: #2C2C2C;
  color: white;
}

window.dialog.print .dialog-action-box {
  margin: 12px;
}

/**********
 * Frames *
 **********/
frame,
.frame {
  border: 1px solid rgba(255, 255, 255, 0.12);
}

frame > list,
.frame > list {
  border: none;
}

frame.view,
.frame.view {
  border-radius: 12px;
}

frame.flat,
.frame.flat {
  border-style: none;
}

frame {
  border-radius: 12px;
}

frame > label {
  margin: 4px;
}

frame.flat > border, statusbar frame > border {
  border: none;
}

actionbar {
  box-shadow: none;
}

actionbar > revealer > box {
  padding: 6px;
  border-spacing: 6px;
  border-top: 1px solid rgba(255, 255, 255, 0.12);
  background-color: #2C2C2C;
  background-clip: border-box;
  box-shadow: none;
}

actionbar > revealer > box, actionbar > revealer > box > box.start, actionbar > revealer > box > box.end {
  border-spacing: 6px;
}

actionbar > revealer > box entry,
actionbar > revealer > box button,
actionbar > revealer > box menubutton,
actionbar > revealer > box splitbutton {
  margin: 0;
}

statusbar {
  padding: 6px 18px;
}

scrolledwindow viewport.frame {
  border: none;
}

stack scrolledwindow.frame viewport.frame list {
  border: none;
}

scrolledwindow > overshoot.top {
  background-size: 200% 70%;
  background-image: radial-gradient(farthest-side at top, rgba(255, 255, 255, 0.04) 99%, transparent 100%);
  background-repeat: no-repeat;
  background-position: center top;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

scrolledwindow > overshoot.bottom {
  background-size: 200% 70%;
  background-image: radial-gradient(farthest-side at bottom, rgba(255, 255, 255, 0.04) 99%, transparent 100%);
  background-repeat: no-repeat;
  background-position: center bottom;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

scrolledwindow > overshoot.left {
  background-size: 200% 70%;
  background-image: radial-gradient(farthest-side at left, rgba(255, 255, 255, 0.04) 99%, transparent 100%);
  background-repeat: no-repeat;
  background-position: left center;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

scrolledwindow > overshoot.right {
  background-size: 200% 70%;
  background-image: radial-gradient(farthest-side at right, rgba(255, 255, 255, 0.04) 99%, transparent 100%);
  background-repeat: no-repeat;
  background-position: right center;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

scrolledwindow.undershoot-top > undershoot.top {
  box-shadow: none;
  background: linear-gradient(to bottom, alpha(rgba(0, 0, 0, 0.25), 0.75), transparent 4px);
}

scrolledwindow.undershoot-bottom > undershoot.bottom {
  box-shadow: none;
  background: linear-gradient(to top, alpha(rgba(0, 0, 0, 0.25), 0.75), transparent 4px);
}

scrolledwindow.undershoot-start:dir(ltr) > undershoot.left {
  box-shadow: none;
  background: linear-gradient(to right, alpha(rgba(0, 0, 0, 0.25), 0.75), transparent 4px);
}

scrolledwindow.undershoot-start:dir(rtl) > undershoot.right {
  box-shadow: none;
  background: linear-gradient(to left, alpha(rgba(0, 0, 0, 0.25), 0.75), transparent 4px);
}

scrolledwindow.undershoot-end:dir(ltr) > undershoot.right {
  box-shadow: none;
  background: linear-gradient(to left, alpha(rgba(0, 0, 0, 0.25), 0.75), transparent 4px);
}

scrolledwindow.undershoot-end:dir(rtl) > undershoot.left {
  box-shadow: none;
  background: linear-gradient(to right, alpha(rgba(0, 0, 0, 0.25), 0.75), transparent 4px);
}

scrolledwindow > junction {
  border: none;
  background-color: #2C2C2C;
}

scrolledwindow > undershoot.top, scrolledwindow > undershoot.bottom, scrolledwindow > undershoot.left, scrolledwindow > undershoot.right {
  box-shadow: none;
}

separator {
  min-width: 1px;
  min-height: 1px;
  background-color: rgba(255, 255, 255, 0.12);
}

separator.spacer {
  background-color: transparent;
}

separator.spacer.horizontal {
  min-width: 12px;
}

separator.spacer.vertical {
  min-height: 12px;
}

stacksidebar + separator.vertical,
stacksidebar separator.horizontal, button.font separator, button.file separator {
  min-width: 0;
  min-height: 0;
  background-color: transparent;
}

/*********
 * Lists *
 *********/
listview,
list {
  border-color: rgba(255, 255, 255, 0.12);
  background-color: #2C2C2C;
  background-clip: padding-box;
  color: rgba(255, 255, 255, 0.7);
}

listview > row,
list > row {
  padding: 2px;
  background-clip: padding-box;
}

listview > row.expander,
list > row.expander {
  padding: 0px;
}

listview > row.expander .row-header,
list > row.expander .row-header {
  padding: 2px;
}

listview.horizontal row.separator, listview.separators.horizontal > row:not(.separator),
list.horizontal row.separator,
list.separators.horizontal > row:not(.separator) {
  border-left: 1px solid rgba(255, 255, 255, 0.12);
}

listview:not(.horizontal) row.separator, listview.separators:not(.horizontal) > row:not(.separator),
list:not(.horizontal) row.separator,
list.separators:not(.horizontal) > row:not(.separator) {
  border-bottom: 1px solid rgba(255, 255, 255, 0.12);
}

list.frame {
  border-radius: 12px;
}

listview > header {
  padding: 2px;
  padding-top: 18px;
  padding-bottom: 6px;
}

button listview.view {
  background-color: transparent;
}

menubutton.flat > button:checked listview.view > row {
  color: white;
}

list.operations-list > row {
  border-radius: 5px;
}

list.operations-list > row, list.operations-list > row:focus {
  background-color: transparent;
}

row {
  background-clip: padding-box;
  color: rgba(255, 255, 255, 0.7);
}

columnview.view > header > button,
treeview.view > header > button, row.activatable {
  color: rgba(255, 255, 255, 0.7);
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1), background-size 300ms cubic-bezier(0, 0, 0.2, 1), background-image 1200ms cubic-bezier(0, 0, 0.2, 1);
  outline: none;
  box-shadow: none;
  background-color: transparent;
  background-image: radial-gradient(circle farthest-corner at center, transparent 30%, transparent 0%);
  background-repeat: no-repeat;
  background-position: center;
  background-size: 1000% 1000%;
}

columnview.view > header > button:focus,
treeview.view > header > button:focus, row.activatable:focus {
  background-color: alpha(currentColor, 0.08);
  color: white;
}

columnview.view > header > button:hover,
treeview.view > header > button:hover, row.activatable:hover {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1), box-shadow 0ms, background-size 300ms cubic-bezier(0, 0, 0.2, 1), background-image 1200ms cubic-bezier(0, 0, 0.2, 1);
  background-color: alpha(currentColor, 0.08);
  color: white;
}

columnview.view > header > button.has-open-popup,
treeview.view > header > button.has-open-popup, columnview.view > header > button:active,
treeview.view > header > button:active, row.activatable.has-open-popup, row.activatable:active {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1), background-size 0ms, background-image 0ms;
  animation: ripple 225ms cubic-bezier(0, 0, 0.2, 1) forwards;
  background-color: alpha(currentColor, 0.08);
  background-image: radial-gradient(circle farthest-corner at center, alpha(currentColor, 0.12) 30%, transparent 0%);
  background-size: 100% 100%;
  color: white;
}

button row.activatable, button row.activatable:hover, button row.activatable.has-open-popup, button row.activatable:active, button row.activatable:active:hover {
  background-color: transparent;
  box-shadow: none;
  background-image: none;
  transition: none;
  animation: none;
}

button:checked row.activatable, button:checked:hover row.activatable {
  color: white;
}

row:selected {
  background-color: alpha(currentColor, 0.06);
  color: inherit;
}

row:selected button image,
row:selected button label {
  color: inherit;
}

row:selected:disabled {
  color: rgba(255, 255, 255, 0.5);
}

row:disabled, row:disabled > .header {
  color: rgba(255, 255, 255, 0.3);
}

treeexpander {
  border-spacing: 4px;
}

columnview > listview {
  border-spacing: 3px;
  padding: 3px 0;
}

columnview > listview > row {
  padding: 0;
}

columnview > listview > row > cell {
  padding: 3px;
}

columnview > listview > row > cell:not(:first-child) {
  border-left: 1px solid transparent;
}

columnview > header > button {
  padding-left: 6px;
  padding-right: 6px;
  border-left: 1px solid transparent;
}

columnview > header > button:first-child {
  border-left-width: 0;
}

columnview.column-separators > listview > row > cell,
columnview.column-separators > header > button {
  border-left-color: rgba(255, 255, 255, 0.12);
}

columnview > listview:not(.horizontal).separators > row:not(.separator) {
  border-top: 1px solid rgba(255, 255, 255, 0.12);
  border-bottom: none;
}

columnview.data-table > listview > row > cell {
  padding-top: 2px;
  padding-bottom: 2px;
}

columnview ~ undershoot.top {
  box-shadow: none;
}

columnview row:not(:selected) cell editablelabel:not(.editing):focus-within {
  outline: 2px solid alpha(currentColor, 0.06);
}

columnview row:not(:selected) cell editablelabel.editing:focus-within {
  outline: 2px solid #3281EA;
}

columnview row:not(:selected) cell editablelabel.editing text selection {
  color: white;
  background-color: #3281EA;
}

.rich-list {
  /* rich lists usually containing other widgets than just labels/text */
}

.rich-list > row {
  padding: 9px 12px;
  min-height: 32px;
  /* should be tall even when only containing a label */
}

.rich-list > row > box {
  border-spacing: 12px;
}

.rich-list > header {
  padding-left: 12px;
  padding-right: 12px;
}

/****************
 * AdwActionRow *
 ****************/
row label.subtitle {
  font-size: smaller;
}

row > box.header {
  margin-left: 12px;
  margin-right: 12px;
  min-height: 48px;
}

row > box.header > .icon:disabled {
  filter: opacity(0.35);
}

row > box.header > box.title {
  margin-top: 6px;
  margin-bottom: 6px;
  border-spacing: 3px;
  padding: 0;
}

row > box.header > box.title,
row > box.header > box.title > .title,
row > box.header > box.title > .subtitle {
  padding: 0;
  font-weight: inherit;
}

row > box.header > .prefixes,
row > box.header > .suffixes {
  border-spacing: 6px;
}

row > box.header > .icon:dir(ltr),
row > box.header > .prefixes:dir(ltr) {
  margin-right: 6px;
}

row > box.header > .icon:dir(rtl),
row > box.header > .prefixes:dir(rtl) {
  margin-left: 6px;
}

row.property > box.header > box.title > .title {
  font-size: smaller;
}

row.property > box.header > box.title > .subtitle {
  font-size: inherit;
  opacity: 1;
}

row.property.monospace {
  font-family: inherit;
}

row.property.monospace > box.header > box.title > .subtitle {
  font-family: monospace;
}

/******************************
 * AdwEntryRow and AdwSpinRow *
 ******************************/
row.entry:disabled text {
  opacity: 0.45;
}

row.entry:disabled .dim-label, row.entry:disabled row.expander:not(:checked) image.expander-row-arrow, row.expander:not(:checked) row.entry:disabled image.expander-row-arrow, row.entry:disabled .content-pane headerbar entry > text > placeholder, .content-pane headerbar row.entry:disabled entry > text > placeholder, row.entry:disabled entry > text > placeholder, row.entry:disabled row.property > box.header > box.title > .title, row.entry:disabled .subtitle {
  opacity: 1;
}

row.entry .edit-icon, row.entry .indicator {
  min-width: 24px;
  min-height: 24px;
  padding: 6px;
}

row.entry .edit-icon:disabled {
  opacity: 0.5;
}

row.entry .indicator {
  opacity: 0.65;
}

row.entry.monospace {
  font-family: inherit;
}

row.entry.monospace text {
  font-family: monospace;
}

row.spin spinbutton {
  background: none;
  box-shadow: none;
  border-spacing: 6px;
}

row.spin spinbutton, row.spin spinbutton:focus row.spin spinbutton:focus-within {
  outline: none;
  background: none;
}

row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child, row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr):last-child, row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child,
row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque),
row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child,
row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child {
  min-width: 28px;
  min-height: 28px;
  padding: 0;
  margin: 6px 2px;
  border: none;
}

row.spin:disabled spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:disabled, row.spin:disabled spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr):last-child:disabled, row.spin:disabled spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child:disabled,
row.spin:disabled spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):disabled,
row.spin:disabled spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child:disabled,
row.spin:disabled spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child:disabled {
  filter: none;
}

row.entry:not(:selected).activatable.focused:hover, row.entry:not(:selected).activatable.focused:active,
row.spin:not(:selected).activatable.focused:hover,
row.spin:not(:selected).activatable.focused:active {
  background-color: transparent;
}

row.entry.error,
row.spin.error {
  color: #3281EA;
}

row.entry.error .dim-label, row.entry.error row.expander:not(:checked) image.expander-row-arrow, row.expander:not(:checked) row.entry.error image.expander-row-arrow, row.entry.error .content-pane headerbar entry > text > placeholder, .content-pane headerbar row.entry.error entry > text > placeholder, row.entry.error entry > text > placeholder, row.entry.error row.property > box.header > box.title > .title, row.entry.error .subtitle,
row.spin.error .dim-label,
row.spin.error row.expander:not(:checked) image.expander-row-arrow,
row.expander:not(:checked) row.spin.error image.expander-row-arrow,
row.spin.error .content-pane headerbar entry > text > placeholder,
.content-pane headerbar row.spin.error entry > text > placeholder,
row.spin.error entry > text > placeholder,
row.spin.error row.property > box.header > box.title > .title,
row.spin.error .subtitle {
  opacity: 1;
}

row.entry.warning,
row.spin.warning {
  color: #3281EA;
}

row.entry.warning .dim-label, row.entry.warning row.expander:not(:checked) image.expander-row-arrow, row.expander:not(:checked) row.entry.warning image.expander-row-arrow, row.entry.warning .content-pane headerbar entry > text > placeholder, .content-pane headerbar row.entry.warning entry > text > placeholder, row.entry.warning entry > text > placeholder, row.entry.warning row.property > box.header > box.title > .title, row.entry.warning .subtitle,
row.spin.warning .dim-label,
row.spin.warning row.expander:not(:checked) image.expander-row-arrow,
row.expander:not(:checked) row.spin.warning image.expander-row-arrow,
row.spin.warning .content-pane headerbar entry > text > placeholder,
.content-pane headerbar row.spin.warning entry > text > placeholder,
row.spin.warning entry > text > placeholder,
row.spin.warning row.property > box.header > box.title > .title,
row.spin.warning .subtitle {
  opacity: 1;
}

row.entry.success,
row.spin.success {
  color: #3281EA;
}

row.entry.success .dim-label, row.entry.success row.expander:not(:checked) image.expander-row-arrow, row.expander:not(:checked) row.entry.success image.expander-row-arrow, row.entry.success .content-pane headerbar entry > text > placeholder, .content-pane headerbar row.entry.success entry > text > placeholder, row.entry.success entry > text > placeholder, row.entry.success row.property > box.header > box.title > .title, row.entry.success .subtitle,
row.spin.success .dim-label,
row.spin.success row.expander:not(:checked) image.expander-row-arrow,
row.expander:not(:checked) row.spin.success image.expander-row-arrow,
row.spin.success .content-pane headerbar entry > text > placeholder,
.content-pane headerbar row.spin.success entry > text > placeholder,
row.spin.success entry > text > placeholder,
row.spin.success row.property > box.header > box.title > .title,
row.spin.success .subtitle {
  opacity: 1;
}

/***************
 * AdwComboRow *
 ***************/
row.combo image.dropdown-arrow:disabled {
  filter: opacity(0.45);
}

row.combo listview.inline {
  background: none;
  border: none;
  box-shadow: none;
  color: inherit;
}

row.combo listview.inline, row.combo listview.inline:disabled {
  background: none;
  color: inherit;
}

row.combo popover > contents {
  min-width: 120px;
}

row.combo popover > contents .combo-searchbar {
  margin: 6px;
}

row.combo popover > contents .combo-searchbar + scrolledwindow > undershoot.top {
  box-shadow: none;
  background: linear-gradient(to bottom, alpha(rgba(0, 0, 0, 0.25), 0.75), transparent 4px);
}

/******************
 * AdwExpanderRow *
 ******************/
list.boxed-list-separate > row.expander row.header, list.content > row, list.content > row.expander row.header,
list.boxed-list > row,
list.boxed-list > row.expander row.header, row.expander list.nested > row {
  transition: 200ms cubic-bezier(0, 0, 0.2, 1);
  color: rgba(255, 255, 255, 0.7);
  border-bottom: 1px solid rgba(255, 255, 255, 0.12);
}

.osd list.boxed-list-separate > row.expander row.header:focus:focus-visible, list.boxed-list-separate > row.expander .osd row.header:focus:focus-visible, .osd list.content > row:focus:focus-visible, .osd list.content > row.expander row.header:focus:focus-visible, list.content > row.expander .osd row.header:focus:focus-visible,
.osd list.boxed-list > row:focus:focus-visible,
.osd list.boxed-list > row.expander row.header:focus:focus-visible,
list.boxed-list > row.expander .osd row.header:focus:focus-visible, .osd row.expander list.nested > row:focus:focus-visible, row.expander .osd list.nested > row:focus:focus-visible {
  outline-color: alpha(currentColor, 0.08);
}

row.expander {
  background: none;
  padding: 0px;
}

row.expander > box > list {
  background: none;
  color: inherit;
}

row.expander list.nested {
  background-color: #2C2C2C;
  color: inherit;
}

row.expander image.expander-row-arrow {
  transition: 200ms cubic-bezier(0, 0, 0.2, 1);
}

row.expander image.expander-row-arrow:dir(ltr) {
  margin-left: 6px;
}

row.expander image.expander-row-arrow:dir(rtl) {
  margin-right: 6px;
}

row.expander:checked image.expander-row-arrow {
  -gtk-icon-transform: rotate(0turn);
}

row.expander:not(:checked) image.expander-row-arrow:dir(ltr) {
  -gtk-icon-transform: rotate(0.5turn);
}

row.expander:not(:checked) image.expander-row-arrow:dir(rtl) {
  -gtk-icon-transform: rotate(-0.5turn);
}

row.expander:checked image.expander-row-arrow:not(:disabled) {
  color: #3281EA;
}

.osd row.expander:checked image.expander-row-arrow:not(:disabled) {
  color: inherit;
}

row.expander image.expander-row-arrow:disabled {
  filter: opacity(0.35);
}

/***************
 * AdwButtonRow *
 ***************/
row.button > box {
  margin-left: 12px;
  margin-right: 12px;
  border-spacing: 6px;
  min-height: 42px;
}

row.button > box > .icon:disabled {
  filter: opacity(0.45);
}

row.button.suggested-action {
  color: #3281EA;
}

row.button.destructive-action {
  color: #F44336;
}

/*****************
 * Boxed Lists *
 *****************/
list.content > row.expander,
list.boxed-list > row.expander {
  border: none;
}

list.content > row:first-child, list.content > row:first-child.expander row.header,
list.boxed-list > row:first-child,
list.boxed-list > row:first-child.expander row.header {
  border-top-left-radius: 11px;
  border-top-right-radius: 11px;
}

list.content > row:last-child, list.content > row:last-child.expander:not(:checked), list.content > row:last-child.expander:not(:checked) row.header, list.content > row:last-child.expander:checked list.nested, list.content > row:last-child.expander:checked list.nested > row:last-child, list.content > row:only-child, list.content > row:only-child.expander:not(:checked), list.content > row:only-child.expander:not(:checked) row.header, list.content > row:only-child.expander:checked list.nested, list.content > row:only-child.expander:checked list.nested > row:last-child,
list.boxed-list > row:last-child,
list.boxed-list > row:last-child.expander:not(:checked),
list.boxed-list > row:last-child.expander:not(:checked) row.header,
list.boxed-list > row:last-child.expander:checked list.nested,
list.boxed-list > row:last-child.expander:checked list.nested > row:last-child,
list.boxed-list > row:only-child,
list.boxed-list > row:only-child.expander:not(:checked),
list.boxed-list > row:only-child.expander:not(:checked) row.header,
list.boxed-list > row:only-child.expander:checked list.nested,
list.boxed-list > row:only-child.expander:checked list.nested > row:last-child {
  border-bottom-left-radius: 11px;
  border-bottom-right-radius: 11px;
  border-bottom-width: 0;
}

list.boxed-list-separate {
  background: none;
  color: white;
}

list.boxed-list-separate > row {
  border: none;
  margin-bottom: 12px;
}

list.boxed-list-separate > row:selected {
  background-color: alpha(currentColor, 0.06);
}

list.boxed-list-separate > row:last-child {
  margin-bottom: 0;
}

list.boxed-list-separate > row:not(.expander):not(:selected).activatable:hover {
  background-color: #2C2C2C;
  background-image: image(alpha(currentColor, 0.08));
}

list.boxed-list-separate > row:not(.expander):not(:selected).activatable:active {
  background-color: #2C2C2C;
  background-image: image(alpha(currentColor, 0.12));
}

list.boxed-list-separate > row:not(.expander):not(:selected).activatable.has-open-popup {
  background-color: #2C2C2C;
  background-image: image(alpha(currentColor, 0.05));
}

list.boxed-list-separate > row.entry:not(:selected).activatable.focused:hover, list.boxed-list-separate > row.entry:not(:selected).activatable.focused:active, list.boxed-list-separate > row.spin:not(:selected).activatable.focused:hover, list.boxed-list-separate > row.spin:not(:selected).activatable.focused:active {
  background-color: #2C2C2C;
  background-image: none;
}

list.boxed-list-separate > row.expander row.header {
  border-top-left-radius: 12px;
  border-top-right-radius: 12px;
}

list.boxed-list-separate > row.expander:not(:checked) row.header, list.boxed-list-separate > row.expander.expander:checked list.nested, list.boxed-list-separate > row.expander.expander:checked list.nested > row:last-child {
  border-bottom-left-radius: 12px;
  border-bottom-right-radius: 12px;
  border-bottom: none;
}

/*********************
 * App Notifications *
 *********************/
.app-notification {
  margin: 9px;
  border-spacing: 9px;
  padding: 9px;
  border: none;
  background-image: none;
}

.app-notification button.text-button:not(:disabled) {
  color: #3281EA;
}

.app-notification.frame,
.app-notification border {
  border-style: none;
}

/*************
 * Expanders *
 *************/
expander {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1);
  min-width: 16px;
  min-height: 16px;
  color: rgba(255, 255, 255, 0.7);
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
}

expander:dir(rtl) {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl");
}

expander:hover, expander:active {
  color: white;
}

expander:checked {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

expander:disabled {
  color: rgba(255, 255, 255, 0.3);
}

expander-widget > box > title {
  border-radius: 12px;
}

expander-widget > box > title:hover > expander {
  color: rgba(255, 255, 255, 0.7);
}

.navigation-sidebar:not(decoration):not(window):drop(active):focus, .navigation-sidebar:not(decoration):not(window):drop(active),
placessidebar:not(decoration):not(window):drop(active):focus,
placessidebar:not(decoration):not(window):drop(active),
stackswitcher:not(decoration):not(window):drop(active):focus,
stackswitcher:not(decoration):not(window):drop(active),
expander-widget:not(decoration):not(window):drop(active):focus,
expander-widget:not(decoration):not(window):drop(active) {
  box-shadow: none;
}

/************
 * Calendar *
 ************/
calendar {
  padding: 0;
  border: 1px solid rgba(255, 255, 255, 0.12);
  border-radius: 12px;
  color: white;
}

calendar:disabled {
  color: rgba(255, 255, 255, 0.5);
}

calendar:selected {
  border-radius: 12px;
}

calendar > header {
  padding: 3px;
  border-bottom: 1px solid rgba(255, 255, 255, 0.12);
}

calendar > header > button {
  min-height: 24px;
}

calendar > grid {
  margin: 3px;
}

calendar > grid > label {
  border-radius: 9999px;
  margin: 0;
}

calendar > grid > label.today:selected {
  box-shadow: none;
}

calendar > grid > label:focus {
  outline-style: none;
}

calendar > grid > label.day-number {
  padding: 9px;
}

calendar > grid > label.day-number.other-month {
  color: alpha(currentColor, 0.3);
}

/***********
 * Dialogs *
 ***********/
window.dialog.message.background {
  background-color: #3C3C3C;
  background-image: none;
}

window.dialog.message box.dialog-vbox.vertical {
  border-spacing: 10px;
}

window.dialog.message .titlebar {
  min-height: 24px;
  border-style: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
  background-color: #3C3C3C;
  color: white;
}

window.dialog.message .titlebar:backdrop {
  background-color: #3C3C3C;
  color: rgba(255, 255, 255, 0.7);
}

window.dialog.message.csd .dialog-action-area {
  padding: 6px;
  border: none;
  box-shadow: none;
}

window.dialog.message.csd .dialog-action-area > button {
  border: none;
  box-shadow: none;
}

window.dialog.message.csd .dialog-action-area > button, window.dialog.message.csd .dialog-action-area > button:first-child, window.dialog.message.csd .dialog-action-area > button:last-child {
  border-radius: 9999px;
}

window.dialog.message.csd .dialog-action-area > button:not(:last-child) {
  margin-right: 6px;
}

window.dialog.message.csd .dialog-action-area > button:not(:disabled) {
  color: #3281EA;
}

window.dialog.message.csd .dialog-action-area > button.destructive-action:not(:disabled) {
  color: #F44336;
}

window.messagedialog .message-area separator {
  background-color: transparent;
  min-height: 0;
}

window.messagedialog .response-area {
  padding: 6px;
  box-shadow: none;
  border: none;
}

window.messagedialog .response-area button {
  border: none;
  box-shadow: none;
  border-radius: 9999px;
}

window.messagedialog .response-area button:not(:last-child) {
  margin-right: 6px;
}

window.messagedialog .response-area button.suggested:not(:disabled) {
  color: #3281EA;
}

window.messagedialog .response-area button.destructive:not(:disabled) {
  color: #F44336;
}

window.messagedialog .response-area separator {
  background-color: transparent;
  min-width: 0;
}

filechooser .dialog-action-box {
  border-top: 1px solid rgba(255, 255, 255, 0.12);
}

filechooser #pathbarbox {
  border-bottom: 1px solid rgba(255, 255, 255, 0.12);
  background-color: #212121;
}

filechooser stack.view frame > border {
  border: none;
}

filechooser gridview ~ undershoot.top {
  box-shadow: none;
  background: linear-gradient(to bottom, alpha(rgba(0, 0, 0, 0.25), 0.75), transparent 4px);
}

filechooser placesview > stack > scrolledwindow > undershoot.bottom {
  box-shadow: none;
  background: linear-gradient(to top, alpha(rgba(0, 0, 0, 0.25), 0.75), transparent 4px);
}

filechooserbutton > button > box {
  border-spacing: 6px;
}

filechooserbutton:drop(active) {
  box-shadow: none;
  border-color: transparent;
}

window.aboutdialog stack scrolledwindow.frame, window.aboutdialog stack scrolledwindow.frame > .view, window.aboutdialog stack scrolledwindow.frame > .view > text {
  border-radius: 12px;
}

window.aboutdialog .large-icons {
  -gtk-icon-size: 128px;
}

window.about .top-bar {
  background-color: transparent;
  box-shadow: none;
}

window.about headerbar {
  color: rgba(255, 255, 255, 0.7);
}

window.about headerbar, window.about headerbar:backdrop {
  background-color: transparent;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
}

/***********
 * Sidebar *
 ***********/
.sidebar {
  border-style: none;
  background-color: #242424;
}

.sidebar:not(separator):dir(ltr), .sidebar:not(separator).left, .sidebar:not(separator).left:dir(rtl) {
  border-right: 1px solid rgba(255, 255, 255, 0.12);
  border-left-style: none;
}

.sidebar:not(separator):dir(rtl), .sidebar:not(separator).right {
  border-left: 1px solid rgba(255, 255, 255, 0.12);
  border-right-style: none;
}

.sidebar listview.view,
.sidebar list {
  background-color: transparent;
}

paned .sidebar.left, paned .sidebar.right, paned .sidebar.left:dir(rtl), paned .sidebar:dir(rtl), paned .sidebar:dir(ltr), paned .sidebar {
  border-style: none;
}

.sidebar-pane stacksidebar.sidebar, leaflet.unfolded > box > stacksidebar.sidebar {
  border: none;
}

stacksidebar list {
  padding: 6px;
  background-color: #242424;
}

stacksidebar row {
  min-height: 24px;
  padding: 6px 9px;
  border-radius: 6px;
}

stacksidebar row:selected {
  font-weight: 500;
}

stacksidebar row + row {
  margin-top: 4px;
}

stacksidebar row > label {
  padding-left: 6px;
  padding-right: 6px;
  color: inherit;
}

separator.sidebar {
  background-color: rgba(255, 255, 255, 0.12);
  border-right: none;
}

separator.sidebar.selection-mode, .selection-mode separator.sidebar {
  background-color: rgba(255, 255, 255, 0.15);
}

separator.sidebar.spacer {
  background-color: transparent;
}

/**********************
 * Navigation Sidebar *
 **********************/
.navigation-sidebar {
  padding: 6px 0;
  border-right: none;
}

.navigation-sidebar, .navigation-sidebar.view, .navigation-sidebar.view:disabled {
  background-color: transparent;
  color: inherit;
}

.navigation-sidebar.background, .navigation-sidebar.background:disabled {
  background-color: #212121;
  color: white;
}

.navigation-sidebar > row {
  min-height: 36px;
  padding: 0 9px;
  border-radius: 0 9999px 9999px 0;
  margin: 0 6px 0 0;
}

.navigation-sidebar > row:hover, .navigation-sidebar > row:focus-visible:focus-within {
  background-color: alpha(currentColor, 0.08);
}

.navigation-sidebar > row:selected {
  background-color: alpha(currentColor, 0.1);
  color: #3281EA;
}

.navigation-sidebar > row:selected:hover {
  background-color: alpha(currentColor, 0.16);
}

.navigation-sidebar > row:selected:focus-visible:focus-within {
  outline: none;
  background-color: alpha(currentColor, 0.08);
}

.navigation-sidebar > row:selected:focus-visible:focus-within:hover {
  background-color: alpha(currentColor, 0.16);
}

.navigation-sidebar > row:disabled {
  color: rgba(255, 255, 255, 0.5);
}

.navigation-sidebar > separator {
  margin: 6px 0;
}

/****************
 * File chooser *
 ****************/
placessidebar > viewport.frame {
  border-style: none;
}

placessidebar .navigation-sidebar {
  padding: 6px 0;
}

placessidebar .navigation-sidebar > row {
  min-height: 32px;
  margin: 0 4px 0 0;
  padding: 3px;
  border-radius: 0 9999px 9999px 0;
}

placessidebar .navigation-sidebar > row > revealer {
  padding: 0 8px 0 16px;
}

placessidebar .navigation-sidebar > row:selected {
  background-color: alpha(currentColor, 0.1);
  color: #3281EA;
  font-weight: 500;
}

placessidebar .navigation-sidebar > row:disabled {
  color: rgba(255, 255, 255, 0.5);
}

placessidebar .navigation-sidebar > row image.sidebar-icon:dir(ltr) {
  padding-right: 8px;
}

placessidebar .navigation-sidebar > row image.sidebar-icon:dir(rtl) {
  padding-left: 8px;
}

placessidebar .navigation-sidebar > row label.sidebar-label {
  color: inherit;
}

placessidebar .navigation-sidebar > row label.sidebar-label:dir(ltr) {
  padding-right: 2px;
}

placessidebar .navigation-sidebar > row label.sidebar-label:dir(rtl) {
  padding-left: 2px;
}

placessidebar .navigation-sidebar > row.sidebar-placeholder-row {
  background-color: alpha(currentColor, 0.08);
}

placessidebar .navigation-sidebar > row.sidebar-new-bookmark-row {
  color: #3281EA;
}

placessidebar .navigation-sidebar > row:drop(active) {
  background-color: alpha(currentColor, 0.08);
}

placesview .server-list-button > image {
  transition: 200ms cubic-bezier(0, 0, 0.2, 1);
  -gtk-icon-transform: rotate(0turn);
}

placesview .server-list-button:checked > image {
  transition: 200ms cubic-bezier(0, 0, 0.2, 1);
  -gtk-icon-transform: rotate(-0.5turn);
}

placesview > actionbar > revealer > box > label {
  border-spacing: 6px;
}

.fr-sidebar > row:not(.fr-sidebar-row) {
  background-color: transparent;
}

.fr-sidebar > row.fr-sidebar-row {
  padding: 6px 9px;
}

/*********
 * Paned *
 *********/
paned > separator {
  min-width: 1px;
  min-height: 1px;
  -gtk-icon-source: none;
  border-style: none;
  background-color: transparent;
  background-image: image(rgba(255, 255, 255, 0.12));
  background-size: 1px 1px;
  background-clip: content-box;
  box-shadow: none;
}

paned > separator.wide {
  min-width: 6px;
  min-height: 6px;
  background-color: #212121;
  background-image: image(rgba(255, 255, 255, 0.12)), image(rgba(255, 255, 255, 0.12));
  background-size: 1px 1px, 1px 1px;
}

paned.horizontal > separator {
  background-repeat: repeat-y;
}

paned.horizontal > separator:dir(ltr) {
  margin: 0 -8px 0 0;
  padding: 0 8px 0 0;
  background-position: left;
}

paned.horizontal > separator:dir(rtl) {
  margin: 0 0 0 -8px;
  padding: 0 0 0 8px;
  background-position: right;
}

paned.horizontal > separator.wide {
  margin: 0;
  padding: 0;
  background-repeat: repeat-y, repeat-y;
  background-position: left, right;
}

paned.vertical > separator {
  margin: 0 0 -8px 0;
  padding: 0 0 8px 0;
  background-repeat: repeat-x;
  background-position: top;
}

paned.vertical > separator.wide {
  margin: 0;
  padding: 0;
  background-repeat: repeat-x, repeat-x;
  background-position: bottom, top;
}

/************
 * GtkVideo *
 ************/
video {
  background: black;
  border-radius: 12px;
}

video image.osd {
  min-width: 64px;
  min-height: 64px;
  border-radius: 9999px;
  border: none;
}

/**************
 * GtkInfoBar *
 **************/
infobar {
  border: none;
  margin-bottom: 0;
}

infobar > revealer > box {
  padding: 6px;
  border-spacing: 12px;
}

infobar.info > revealer > box, infobar.info:hover > revealer > box, infobar.info:backdrop > revealer > box {
  color: white;
  background-color: #2C2C2C;
}

infobar.info > revealer > box button.text-button:not(.suggested-action):not(.destructive-action):not(:disabled), infobar.info:hover > revealer > box button.text-button:not(.suggested-action):not(.destructive-action):not(:disabled), infobar.info:backdrop > revealer > box button.text-button:not(.suggested-action):not(.destructive-action):not(:disabled) {
  color: #3281EA;
}

infobar.action > revealer > box, infobar.action:backdrop > revealer > box, infobar.question > revealer > box, infobar.question:backdrop > revealer > box {
  background-color: #3281EA;
  color: white;
}

infobar.action > revealer > box button, infobar.action > revealer > box button:hover, infobar.action > revealer > box button:focus, infobar.action > revealer > box button:active, infobar.action > revealer > box button:checked, infobar.action > revealer > box button.text-button:not(:disabled), infobar.action:backdrop > revealer > box button, infobar.action:backdrop > revealer > box button:hover, infobar.action:backdrop > revealer > box button:focus, infobar.action:backdrop > revealer > box button:active, infobar.action:backdrop > revealer > box button:checked, infobar.action:backdrop > revealer > box button.text-button:not(:disabled), infobar.question > revealer > box button, infobar.question > revealer > box button:hover, infobar.question > revealer > box button:focus, infobar.question > revealer > box button:active, infobar.question > revealer > box button:checked, infobar.question > revealer > box button.text-button:not(:disabled), infobar.question:backdrop > revealer > box button, infobar.question:backdrop > revealer > box button:hover, infobar.question:backdrop > revealer > box button:focus, infobar.question:backdrop > revealer > box button:active, infobar.question:backdrop > revealer > box button:checked, infobar.question:backdrop > revealer > box button.text-button:not(:disabled) {
  color: white;
}

infobar.action > revealer > box *:link, infobar.action:backdrop > revealer > box *:link, infobar.question > revealer > box *:link, infobar.question:backdrop > revealer > box *:link {
  color: white;
}

infobar.action:hover > revealer > box, infobar.question:hover > revealer > box {
  background-color: rgba(255, 255, 255, 0.12);
  background-image: image(#3281EA);
}

infobar.warning > revealer > box, infobar.warning:backdrop > revealer > box {
  background-color: #FBC02D;
  color: rgba(0, 0, 0, 0.87);
}

infobar.warning > revealer > box button, infobar.warning > revealer > box button:hover, infobar.warning > revealer > box button:focus, infobar.warning > revealer > box button:active, infobar.warning > revealer > box button:checked, infobar.warning > revealer > box button.text-button:not(:disabled), infobar.warning:backdrop > revealer > box button, infobar.warning:backdrop > revealer > box button:hover, infobar.warning:backdrop > revealer > box button:focus, infobar.warning:backdrop > revealer > box button:active, infobar.warning:backdrop > revealer > box button:checked, infobar.warning:backdrop > revealer > box button.text-button:not(:disabled) {
  color: rgba(0, 0, 0, 0.87);
}

infobar.warning > revealer > box *:link, infobar.warning:backdrop > revealer > box *:link {
  color: rgba(0, 0, 0, 0.87);
}

infobar.warning:hover > revealer > box {
  background-color: #fbb814;
}

infobar.error > revealer > box, infobar.error:backdrop > revealer > box {
  background-color: #F44336;
  color: white;
}

infobar.error > revealer > box button, infobar.error > revealer > box button:hover, infobar.error > revealer > box button:focus, infobar.error > revealer > box button:active, infobar.error > revealer > box button:checked, infobar.error > revealer > box button.text-button:not(:disabled), infobar.error:backdrop > revealer > box button, infobar.error:backdrop > revealer > box button:hover, infobar.error:backdrop > revealer > box button:focus, infobar.error:backdrop > revealer > box button:active, infobar.error:backdrop > revealer > box button:checked, infobar.error:backdrop > revealer > box button.text-button:not(:disabled) {
  color: white;
}

infobar.error > revealer > box *:link, infobar.error:backdrop > revealer > box *:link {
  color: white;
}

infobar.error:hover > revealer > box {
  background-color: #f32c1e;
}

/************
 * Tooltips *
 ************/
tooltip {
  padding: 6px 12px;
  box-shadow: none;
}

tooltip.background, tooltip.background.csd {
  background-color: rgba(25, 25, 25, 0.9);
  color: white;
  box-shadow: 0 2px 2px -1px rgba(0, 0, 0, 0.2), 0 4px 4px 0 rgba(0, 0, 0, 0.14), 0 1px 6px 0 rgba(0, 0, 0, 0.12);
  border-radius: 6px;
  margin: 2px 6px 8px 6px;
  border: none;
}

tooltip > box {
  border-spacing: 6px;
}

/*****************
 * Color Chooser *
 *****************/
colorswatch.top {
  border-top-left-radius: 11px;
  border-top-right-radius: 11px;
}

colorswatch.top overlay {
  border-top-left-radius: 11px;
  border-top-right-radius: 11px;
}

colorswatch.bottom {
  border-bottom-left-radius: 11px;
  border-bottom-right-radius: 11px;
}

colorswatch.bottom overlay {
  border-bottom-left-radius: 11px;
  border-bottom-right-radius: 11px;
}

colorswatch.left, colorswatch:first-child:not(.top) {
  border-top-left-radius: 11px;
  border-bottom-left-radius: 11px;
}

colorswatch.left overlay, colorswatch:first-child:not(.top) overlay {
  border-top-left-radius: 11px;
  border-bottom-left-radius: 11px;
}

colorswatch.right, colorswatch:last-child:not(.bottom) {
  border-top-right-radius: 11px;
  border-bottom-right-radius: 11px;
}

colorswatch.right overlay, colorswatch:last-child:not(.bottom) overlay {
  border-top-right-radius: 11px;
  border-bottom-right-radius: 11px;
}

colorswatch.dark {
  color: white;
}

colorswatch.light {
  color: rgba(0, 0, 0, 0.87);
}

colorswatch#add-color-button {
  border-radius: 11px 11px 0 0;
  color: white;
}

colorswatch#add-color-button:only-child {
  border-radius: 11px;
}

colorswatch#add-color-button overlay {
  background-color: #3C3C3C;
}

colorswatch:disabled {
  opacity: 0.5;
}

colorswatch:disabled overlay {
  box-shadow: none;
}

colorswatch#editor-color-sample {
  border-radius: 11px;
}

colorswatch#editor-color-sample overlay {
  border-radius: 11px;
}

colorchooser .popover.osd {
  transition: box-shadow 75ms cubic-bezier(0, 0, 0.2, 1);
  border-radius: 12px;
  box-shadow: 0 2px 2px -1px rgba(0, 0, 0, 0.2), 0 4px 4px 0 rgba(0, 0, 0, 0.14), 0 1px 6px 0 rgba(0, 0, 0, 0.12), inset 0 1px rgba(255, 255, 255, 0.1);
  background-color: #3C3C3C;
}

colorchooser .popover.osd:backdrop {
  box-shadow: 0 3px 2px -3px rgba(0, 0, 0, 0.3), 0 2px 2px -1px rgba(0, 0, 0, 0.24), 0 1px 3px 0 rgba(0, 0, 0, 0.12), inset 0 1px rgba(255, 255, 255, 0.1);
}

/********
 * Misc *
 ********/
.content-view {
  background-color: #212121;
}

/**********************
 * Window Decorations *
 **********************/
window {
  border: none;
}

window.csd {
  outline: none;
  padding: 0;
  margin: 0;
  transition: none;
  border-radius: 18px;
  box-shadow: 0 8px 6px -5px rgba(0, 0, 0, 0.2), 0 16px 16px 2px rgba(0, 0, 0, 0.14), 0 6px 18px 5px rgba(0, 0, 0, 0.12), 0 16px 16px 2px transparent, 0 6px 18px 5px transparent;
}

window.csd:backdrop {
  transition: box-shadow 75ms cubic-bezier(0, 0, 0.2, 1);
  box-shadow: 0 2px 2px -1px rgba(0, 0, 0, 0.2), 0 4px 4px 0 rgba(0, 0, 0, 0.14), 0 1px 6px 0 rgba(0, 0, 0, 0.12), 0 16px 16px 2px transparent, 0 6px 18px 5px transparent;
}

window.csd.tiled, window.csd.tiled-top, window.csd.tiled-left, window.csd.tiled-right, window.csd.tiled-bottom {
  border-radius: 0;
  outline: none;
}

window.csd.maximized, window.csd.fullscreen {
  border-radius: 0;
  outline: none;
  box-shadow: none;
  transition: none;
}

window.csd.ssd-frame {
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0;
}

window.solid-csd {
  margin: 0;
  padding: 2px;
  border-radius: 0;
  box-shadow: none;
  background-color: #2C2C2C;
}

window.solid-csd:backdrop {
  background-color: #3C3C3C;
}

window.ssd {
  box-shadow: 0 0 0 1px rgba(255, 255, 255, 0.12);
}

gridview > child:selected, calendar:selected, calendar > grid > label.day-number:selected {
  background-color: alpha(currentColor, 0.06);
}

.view:selected, iconview:selected, flowbox > flowboxchild:selected, calendar > grid > label.today, stacksidebar row:selected {
  color: #3281EA;
  background-color: color-mix(in srgb, #3281EA 20%, transparent);
}

textview text selection:focus, textview text selection, label > selection, entry > text > selection, calendar > grid > label.today:selected {
  color: white;
  background-color: #3281EA;
}

.monospace {
  font-family: monospace;
}

.numeric {
  font-feature-settings: "tnum";
}

/**********************
 * Touch Copy & Paste *
 **********************/
cursor-handle {
  color: #3281EA;
  -gtk-icon-source: -gtk-recolor(url("assets/scalable/cursor-handle-symbolic.svg"));
}

cursor-handle.insertion-cursor:dir(ltr), cursor-handle.insertion-cursor:dir(rtl) {
  padding-top: 6px;
}

shortcuts-section {
  margin: 20px;
}

.shortcuts-search-results {
  margin: 20px;
  border-spacing: 24px;
}

shortcut {
  border-spacing: 6px;
}

shortcut > .keycap {
  min-width: 12px;
  min-height: 26px;
  margin-top: 2px;
  padding-bottom: 2px;
  padding-left: 8px;
  padding-right: 8px;
  border: solid 1px rgba(255, 255, 255, 0.12);
  border-radius: 8px;
  box-shadow: inset 0 -2px rgba(255, 255, 255, 0.12);
  background-color: #3C3C3C;
  background-clip: border-box;
  color: white;
  font-size: smaller;
}

:not(decoration):not(window):drop(active) {
  caret-color: #3281EA;
}

stackswitcher {
  min-height: 0;
  padding: 0;
  border-radius: 9999px;
  background-color: alpha(currentColor, 0.05);
}

stackswitcher.linked:not(.vertical) > button:not(.suggested-action):not(.destructive-action) {
  margin: 0 0;
  border-radius: 9999px;
}

stackswitcher.linked:not(.vertical) > button:not(.suggested-action):not(.destructive-action).text-button {
  min-width: 100px;
}

stackswitcher.linked:not(.vertical) > button:not(.suggested-action):not(.destructive-action):checked {
  background-color: #3281EA;
  color: white;
}

stackswitcher button.text-button {
  min-width: 100px;
}

stackswitcher.circular {
  border-spacing: 12px;
}

stackswitcher.circular button.circular,
stackswitcher.circular button.text-button.circular {
  min-width: 36px;
  min-height: 36px;
  padding: 0;
}

/*************
 * App Icons *
 *************/
.lowres-icon {
  -gtk-icon-shadow: none;
}

.icon-dropshadow {
  -gtk-icon-shadow: none;
}

/*********
 * Emoji *
 *********/
popover.emoji-picker {
  padding: 0;
}

popover.emoji-picker > contents {
  padding: 0;
}

.emoji-searchbar {
  padding: 6px;
  border-spacing: 6px;
  border-bottom: 1px solid rgba(255, 255, 255, 0.12);
  background: none;
}

.emoji-searchbar entry {
  margin: 0;
}

.emoji-searchbar entry text {
  background: none;
  box-shadow: none;
}

.emoji-toolbar {
  padding: 0;
  border-spacing: 3px;
  border-top: 1px solid rgba(255, 255, 255, 0.12);
  background: none;
  box-shadow: none;
}

button.emoji-section {
  margin: 0;
  padding: 6px;
  border-radius: 9px;
}

button.emoji-section:checked {
  color: #3281EA;
}

popover.emoji-picker emoji {
  font-size: x-large;
  padding: 6px;
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1);
  border-radius: 12px;
}

popover.emoji-picker emoji:focus, popover.emoji-picker emoji:hover {
  background: alpha(currentColor, 0.08);
}

emoji-completion-row {
  min-height: 28px;
  padding: 0 12px;
}

emoji-completion-row > box {
  border-spacing: 6px;
  padding: 2px 6px;
}

emoji-completion-row:focus, emoji-completion-row:hover,
emoji-completion-row emoji:hover, emoji-completion-row emoji:focus {
  background-color: alpha(currentColor, 0.08);
  color: white;
}

popover.entry-completion > contents {
  padding: 0;
}

.nautilus-window.background.csd {
  color: rgba(255, 255, 255, 0.7);
}

.nautilus-window.background.csd, .nautilus-window.background.csd:backdrop {
  background-image: none;
  background-color: #2C2C2C;
}

.nautilus-window:not(.view) headerbar {
  background-color: transparent;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
}

.nautilus-window .content-pane, .nautilus-window .content-pane:backdrop {
  background-color: transparent;
}

.nautilus-window flap > separator {
  background: none;
  min-width: 0;
}

.nautilus-window .sidebar-pane, .nautilus-window .sidebar-pane:backdrop {
  background-color: transparent;
}

.nautilus-window .sidebar-pane:dir(ltr), .nautilus-window .sidebar-pane:dir(ltr) banner > revealer > widget, .nautilus-window .sidebar-pane.end:dir(rtl), .nautilus-window .sidebar-pane.end:dir(rtl) banner > revealer > widget {
  box-shadow: none;
  border-right: none;
}

.nautilus-window .sidebar-pane:dir(rtl), .nautilus-window .sidebar-pane:dir(rtl) banner > revealer > widget, .nautilus-window .sidebar-pane.end:dir(ltr), .nautilus-window .sidebar-pane.end:dir(ltr) banner > revealer > widget {
  box-shadow: none;
  border-left: none;
}

.nautilus-window .sidebar-pane .toolbar {
  margin: 0 0 12px 6px;
}

.nautilus-window flap.unfolded > placessidebar,
.nautilus-window .sidebar-pane > toolbarview > placessidebar {
  background-color: #2C2C2C;
  border-radius: 18px;
  color: rgba(255, 255, 255, 0.7);
}

.nautilus-window flap.unfolded > placessidebar > scrolledwindow,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow {
  margin: 0 0 12px 12px;
  border-radius: 12px;
  background-color: rgba(50, 129, 234, 0.08);
}

.nautilus-window flap.unfolded > placessidebar > scrolledwindow > overshoot.top, .nautilus-window flap.unfolded > placessidebar > scrolledwindow > undershoot.top,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > overshoot.top,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > undershoot.top {
  border-radius: 12px 12px 0 0;
}

.nautilus-window flap.unfolded > placessidebar > scrolledwindow > overshoot.bottom, .nautilus-window flap.unfolded > placessidebar > scrolledwindow > undershoot.bottom,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > overshoot.bottom,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > undershoot.bottom {
  border-radius: 0 0 12px 12px;
}

.nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar {
  padding: 16px 0 16px 0;
  background: none;
  border-radius: 12px;
}

.nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > separator,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > separator {
  background: none;
}

.nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable {
  border-radius: 0;
  padding: 0;
  margin: -8px 0 -8px 0;
  animation: none;
}

.nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable > revealer.sidebar-revealer,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable > revealer.sidebar-revealer {
  padding-left: 12px;
  padding-right: 0;
}

.nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable > revealer.sidebar-revealer > box,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable > revealer.sidebar-revealer > box {
  padding-right: 18px;
  padding-left: 0;
}

.nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable, .nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:focus, .nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:hover, .nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:active,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:focus,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:hover,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:active {
  background: none;
  box-shadow: none;
  animation: none;
}

.nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable, .nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable image.sidebar-icon, .nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable label.sidebar-label,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable image.sidebar-icon,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable label.sidebar-label {
  color: rgba(255, 255, 255, 0.7);
}

.nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable image.sidebar-icon,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable image.sidebar-icon {
  padding-right: 6px;
}

.nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable label.sidebar-label,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable label.sidebar-label {
  color: inherit;
  min-height: 54px;
  padding-left: 6px;
}

.nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable.sidebar-placeholder-row,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable.sidebar-placeholder-row {
  background-color: transparent;
}

.nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:drop(active),
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:drop(active) {
  border-radius: 0;
  border-radius: 9999px 0 0 9999px;
  background-color: rgba(245, 124, 0, 0.1);
}

.nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:drop(active), .nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:drop(active) image.sidebar-icon, .nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:drop(active) label.sidebar-label,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:drop(active),
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:drop(active) image.sidebar-icon,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:drop(active) label.sidebar-label {
  color: #F57C00;
}

.nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:hover image.sidebar-icon, .nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:hover label.sidebar-label,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:hover image.sidebar-icon,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:hover label.sidebar-label {
  color: #3281EA;
}

.nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:selected,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:selected {
  background-color: transparent;
  font-weight: 700;
}

.nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:selected image.sidebar-icon,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:selected image.sidebar-icon {
  color: #3281EA;
}

.nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:selected image.sidebar-icon, .nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:selected label.sidebar-label,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:selected image.sidebar-icon,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:selected label.sidebar-label {
  color: #3281EA;
}

.nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:selected button.sidebar-button,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:selected button.sidebar-button {
  color: #3281EA;
}

.nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:selected > revealer > box,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:selected > revealer > box {
  color: #3281EA;
  background-color: #2C2C2C;
  border: none;
  border-image-width: 16px 9px 16px 46px;
  border-image-slice: 16 9 16 46;
  border-image-repeat: stretch;
  border-image-source: -gtk-scaled(url("assets/row-selected-dark.png"), url("assets/row-selected-dark@2.png"));
}

.nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:selected label.sidebar-label,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:selected label.sidebar-label {
  margin-left: 10px;
}

.nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:selected button.sidebar-button,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:selected button.sidebar-button {
  color: #3281EA;
}

.nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:disabled, .nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:disabled image.sidebar-icon, .nautilus-window flap.unfolded > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:disabled label.sidebar-label,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:disabled,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:disabled image.sidebar-icon,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > viewport > list.navigation-sidebar > row.activatable:disabled label.sidebar-label {
  color: rgba(255, 255, 255, 0.3);
}

.nautilus-window flap.unfolded > placessidebar > scrolledwindow > scrollbar,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > scrollbar {
  margin: 3px 3px 3px 0;
  background: none;
  border: none;
}

.nautilus-window flap.unfolded > placessidebar > scrolledwindow > scrollbar though,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > scrollbar though {
  background: none;
}

.nautilus-window flap.unfolded > placessidebar > scrolledwindow > scrollbar though > slider,
.nautilus-window .sidebar-pane > toolbarview > placessidebar > scrolledwindow > scrollbar though > slider {
  border: none;
}

.nautilus-window tabbar .box {
  padding: 0 12px;
  background-color: transparent;
  box-shadow: inset 0 -1px #404040;
}

.nautilus-window tabbar tab {
  color: rgba(255, 255, 255, 0.7);
}

.nautilus-window tabbar tab:hover:not(:selected):not(:active):not(:checked) {
  color: white;
  background-color: rgba(255, 255, 255, 0.05);
}

.nautilus-window tabbar tab:active, .nautilus-window tabbar tab:checked, .nautilus-window tabbar tab:selected {
  color: white;
}

.nautilus-window tabbar tab:active:disabled, .nautilus-window tabbar tab:checked:disabled, .nautilus-window tabbar tab:selected:disabled {
  color: rgba(255, 255, 255, 0.5);
}

.nautilus-window tabbar tab:disabled {
  color: rgba(255, 255, 255, 0.3);
}

.nautilus-window placesview label {
  color: rgba(255, 255, 255, 0.7);
}

.nautilus-window placesview label:disabled {
  color: rgba(255, 255, 255, 0.3);
}

.nautilus-window .nautilus-list-view #NautilusViewCell {
  padding: 0;
}

.nautilus-window infobar {
  margin: 3px;
}

.nautilus-window infobar > revealer > box {
  border-radius: 6px;
}

.nautilus-window label.search-information {
  margin: 3px;
  border-radius: 6px;
}

.nautilus-window #NautilusPathBar {
  background-color: rgba(255, 255, 255, 0.04);
}

.nautilus-window #NautilusPathBar #NautilusPathButton.current-dir {
  color: white;
}

.floating-bar {
  min-height: 28px;
  padding: 3px;
  margin: 6px;
  border: none;
  border-radius: 9999px;
  background-color: rgba(33, 33, 33, 0.95);
  box-shadow: none;
  color: white;
}

.floating-bar button {
  margin: 4px;
}

#NautilusViewCell clamp box {
  margin: 0;
  border-spacing: 0;
}

#NautilusQueryEditor {
  border-radius: 9999px;
  padding: 0 4px 0 8px;
}

#NautilusQueryEditor > menubutton > button.image-button {
  min-width: 28px;
  min-height: 28px;
  padding: 0;
}

#NautilusQueryEditor > * {
  margin: 4px 0;
}

#NautilusPathBar {
  background-color: rgba(255, 255, 255, 0.04);
  border-radius: 9999px;
}

#NautilusPathBar #NautilusPathButton {
  margin: 0 3px;
  border-radius: 9999px;
}

#NautilusPathBar #NautilusPathButton.current-dir {
  color: white;
}

#NautilusPathBar #NautilusPathButton.current-dir:hover, #NautilusPathBar #NautilusPathButton.current-dir:active {
  background: none;
  box-shadow: none;
}

#NautilusPathBar #NautilusPathButton:first-child {
  margin-left: 0;
}

#NautilusPathBar > menubutton > button {
  border-radius: 9999px;
}

#NautilusQueryEditorTag {
  border-radius: 9999px;
}

#NautilusQueryEditorTag > button {
  margin: 3px;
  padding: 0;
  min-height: 22px;
  min-width: 22px;
}

#NautilusFileChooser .content-pane {
  background-color: #2C2C2C;
}

window.dialog > box > stack > box > box > notebook.frame {
  border-width: 0 0 0 1px;
  border-radius: 0;
}

window > contents leaflet {
  background-color: transparent;
}

window > contents leaflet stack.background {
  background-color: transparent;
}

window > contents leaflet.unfolded stack.background leaflet box:last-child > headerbar,
window > contents leaflet.unfolded stack.background leaflet + headerbar {
  border-top-left-radius: 0;
}

window > contents leaflet.unfolded > separator + box > headerbar {
  border-top-right-radius: 0;
}

window > contents leaflet > box > scrolledwindow > viewport > widget > stack {
  background-color: #2C2C2C;
}

window > widget leaflet {
  background-color: transparent;
}

window > widget leaflet stack.background {
  background-color: transparent;
}

window > widget leaflet.unfolded stack.background > widget > overlay > leaflet > box > headerbar,
window > widget leaflet.unfolded stack.background > widget > box > widget > headerbar,
window > widget leaflet.unfolded > box:not(:last-child) headerbar {
  border-top-left-radius: 0;
}

window > widget leaflet.unfolded > separator + box > headerbar {
  border-top-right-radius: 0;
}

window > widget leaflet > box > scrolledwindow > viewport > widget > stack {
  background-color: #2C2C2C;
}

.tweak-titlebar-left + separator {
  background-color: #2C2C2C;
}

.tweak-titlebar-left + separator:backdrop {
  background-color: #3C3C3C;
}

.large-button {
  padding: 6px;
}

.alarm-time {
  font-size: 2.5em;
  font-weight: 300;
}

.clocks-ampm-toggle-button,
.clocks-secondary-standalone-label {
  font-size: 18pt;
}

.clocks-standalone-label,
.clocks-ringing-label {
  font-size: 6em;
  font-weight: 300;
}

.clocks-ringing-title {
  font-size: 1.5em;
  font-weight: bold;
}

.clocks-alarm-setup-time {
  font-size: 32pt;
}

.clocks-timer-label,
.clocks-spinbutton {
  font-size: 48pt;
}

.timer-panel .timer-header {
  font-size: 20pt;
  font-weight: 300;
}

.timer-countdown {
  font-size: 40pt;
  font-weight: 300;
}

/* Stopwatch Panel */
.lap-time {
  font-weight: bold;
}

.stopped-stopwatch label,
.running-stopwatch label,
.paused-stopwatch label {
  font-size: 70px;
  font-weight: lighter;
}

.stopped-stopwatch .seconds-label {
  font-weight: 300;
}

.running-stopwatch .seconds-label,
.running-stopwatch .miliseconds-label {
  color: #3281EA;
}

.stopped-stopwatch .miliseconds-label,
.running-stopwatch .miliseconds-label,
.paused-stopwatch .miliseconds-label {
  font-size: 50px;
}

.running-stopwatch .seconds-label,
.paused-stopwatch .seconds-label {
  font-weight: 300;
}

.clock-location {
  font-weight: bolder;
}

.hidden {
  opacity: 0;
}

.clock-time {
  font-size: 2em;
  padding: 0.2em 0.5em;
  border-radius: 1em;
}

.none .clock-time {
  background: alpha(currentColor, 0.2);
}

.night .clock-time {
  color: #1A73E8;
  background-color: alpha(#3281EA, 0.25);
}

.naut .clock-time,
.astro .clock-time {
  color: #F57C00;
  background-color: alpha(#FB8C00, 0.25);
}

.civil .clock-time,
.day .clock-time {
  color: #FFD600;
  background: alpha(#FBC02D, 0.25);
}

.contacts-contact-list list.navigation-sidebar {
  background: none;
}

window > contents leaflet.unfolded > box.vertical > headerbar {
  border-top-left-radius: 0;
}

.history-view {
  background-color: #2C2C2C;
}

#displayitem {
  border-top: 1px solid rgba(255, 255, 255, 0.12);
}

.small .card {
  border-radius: 0;
  box-shadow: none;
}

.small .card.forecast-card {
  border-width: 1px 0;
}

.small .card.display-container {
  border-width: 0 0 1px 0;
}

leaflet button.number-button {
  background-color: rgba(255, 255, 255, 0.1);
}

leaflet button.number-button:hover {
  background-color: rgba(255, 255, 255, 0.2);
}

leaflet button.number-button:active {
  background-color: rgba(255, 255, 255, 0.3);
}

leaflet button.clear-button.image-button {
  border-radius: 12px;
}

label.primary-label, label.month-name, label.secondary-label {
  font-size: 16pt;
  font-weight: bold;
  padding: 12px;
}

label.primary-label, label.month-name {
  color: #3281EA;
}

label.secondary-label {
  color: rgba(255, 255, 255, 0.5);
}

calendar-view {
  font-size: 10pt;
}

calendar-view:selected {
  color: #3281EA;
  font-weight: bold;
}

calendar-view.header,
label.header {
  font-size: 10pt;
  font-weight: bold;
  color: rgba(255, 255, 255, 0.5);
}

calendar-view.current,
weekgrid.current {
  background-color: alpha(#3281EA, 0.3);
}

popover.events {
  background-color: #212121;
  padding: 0;
}

popover.events box {
  border-top-left-radius: 12px;
  border-top-right-radius: 12px;
}

popover.events list {
  background-color: #2C2C2C;
  border-radius: 12px;
}

popover.events scrolledwindow {
  border-width: 0;
}

popover.events button {
  border-radius: 12px;
  border-top-left-radius: 0;
  border-top-right-radius: 0;
  border-style: solid none none;
  box-shadow: none;
}

event {
  margin: 1px;
  font-size: 0.9rem;
}

event widget.content {
  margin: 4px;
}

weekgrid > event {
  margin: 5px 4px 0 3px;
}

event.timed, event:not(.slanted):not(.slanted-start):not(.slanted-end) {
  border-radius: 5px;
}

event.timed widget.edge {
  border-radius: 5px;
  min-width: 5px;
}

event.slanted-start, event.slanted-end:dir(rtl) {
  padding-left: 16px;
  border-radius: 0 5px 5px 0;
}

event.slanted-end, event.slanted-start:dir(rtl) {
  padding-right: 16px;
  border-radius: 5px 0 0 5px;
}

event:not(.timed).color-dark {
  color: white;
  outline-color: rgba(0, 0, 0, 0.3);
}

event:not(.timed).color-light {
  color: alpha(black, 0.75);
  outline-color: rgba(255, 255, 255, 0.5);
}

event.timed {
  color: rgba(255, 255, 255, 0.7);
}

popover.event-popover,
popover.event-popover > contents {
  padding: 0;
}

.search-viewport {
  background-color: #2C2C2C;
}

.calendar-list {
  background-color: transparent;
}

.calendar-list > list {
  border-radius: 4px;
}

.calendar-color-image {
  -gtk-icon-filter: none;
}

image.calendar-color-image,
button:active:not(:backdrop) .calendar-color-image,
button:checked:not(:backdrop) .calendar-color-image,
.calendars-list .calendar-color-image:not(:backdrop):not(:disabled),
.calendar-list .calendar-color-image:not(:backdrop):not(:disabled),
.sources-button:not(:backdrop):not(:disabled) .calendar-color-image {
  -gtk-icon-shadow: 0 1px alpha(black, 0.1);
}

datechooser {
  padding: 6px;
}

datechooser .current-week {
  background-color: rgba(255, 255, 255, 0.04);
  color: white;
  border-radius: 12px;
}

datechooser navigator {
  margin-right: 6px;
  margin-left: 6px;
  margin-bottom: 6px;
}

datechooser navigator label {
  font-weight: bold;
}

datechooser navigator button, datechooser navigator button.popup, datechooser navigator button.image-button {
  min-height: 36px;
  min-width: 36px;
  padding: 0;
}

datechooser .weeknum, datechooser .weekday {
  color: rgba(255, 255, 255, 0.5);
  font-size: smaller;
}

.sidebar-pane datechooser .current-week {
  background-color: rgba(255, 255, 255, 0.04);
  color: white;
}

.sidebar-pane datechooser .weeknum, .sidebar-pane datechooser .weekday {
  color: rgba(255, 255, 255, 0.5);
}

datechooser button.day, datechooser button.day.text-button {
  font-size: 10pt;
  font-weight: normal;
  margin: 3px;
  padding: 0;
  min-height: 36px;
  min-width: 36px;
  transition: none;
}

datechooser button.day dot, datechooser button.day.text-button dot {
  background-color: white;
  border-radius: 50%;
  min-height: 3px;
  min-width: 3px;
}

datechooser button.day:selected, datechooser button.day.today:selected, datechooser button.day.text-button:selected, datechooser button.day.text-button.today:selected {
  background-color: #3281EA;
  color: white;
  font-weight: bold;
}

datechooser button.day:selected dot, datechooser button.day.today:selected dot, datechooser button.day.text-button:selected dot, datechooser button.day.text-button.today:selected dot {
  background-color: white;
}

datechooser button.day.today, datechooser button.day.text-button.today {
  color: #3281EA;
}

datechooser button.day.today dot, datechooser button.day.text-button.today dot {
  background-color: #3281EA;
}

datechooser button.day.other-month:not(:hover), datechooser button.day.other-month:backdrop, datechooser button.day.text-button.other-month:not(:hover), datechooser button.day.text-button.other-month:backdrop {
  color: rgba(255, 255, 255, 0.3);
}

datechooser button.day.other-month:not(:hover) dot, datechooser button.day.other-month:backdrop dot, datechooser button.day.text-button.other-month:not(:hover) dot, datechooser button.day.text-button.other-month:backdrop dot {
  background-color: rgba(255, 255, 255, 0.3);
}

.week-header {
  padding: 0;
}

.week-header > box:first-child {
  border-bottom: 1px solid rgba(255, 255, 255, 0.12);
}

.week-header .week-number {
  font-size: 16pt;
  font-weight: bold;
  padding: 12px 12px 18px 12px;
  color: rgba(255, 255, 255, 0.3);
}

.week-header.week-temperature {
  font-size: 10pt;
  font-weight: bold;
  color: rgba(255, 255, 255, 0.5);
}

.week-header.lines {
  color: rgba(255, 255, 255, 0.12);
}

weekhourbar > label {
  font-size: 10pt;
  padding: 4px 6px;
}

.week-view .lines {
  color: rgba(255, 255, 255, 0.12);
}

weekgrid > widget.now-strip {
  background-color: alpha(#3281EA, 0.8);
  margin: 0 0 0 1px;
  min-height: 3px;
}

weekgrid:selected, weekgrid.dnd,
.week-header:selected,
.week-header.dnd {
  background-color: alpha(#3281EA, 0.25);
}

monthcell {
  border: solid 1px rgba(255, 255, 255, 0.12);
  border-width: 1px 0 0 1px;
  background-color: transparent;
  transition: background-color 200ms;
}

monthcell:hover:not(.out-of-month):not(.today) {
  background-color: #242424;
  transition: background-color 200ms;
  color: white;
}

monthcell:selected {
  background-color: alpha(#3281EA, 0.1);
}

monthcell:selected:hover {
  background-color: alpha(#3281EA, 0.2);
}

monthcell:selected label.day-label {
  font-weight: bold;
}

monthcell:nth-child(7n + 1) {
  border-left-width: 0;
}

monthcell.today {
  background-color: alpha(#3281EA, 0.2);
}

monthcell.today:hover {
  background-color: alpha(#3281EA, 0.3);
  color: #3281EA;
}

monthcell.today:selected {
  background-color: alpha(#3281EA, 0.25);
}

monthcell.today:selected:hover {
  background-color: alpha(#3281EA, 0.35);
}

monthcell label {
  color: white;
  font-size: 0.9rem;
}

monthcell label.day-label {
  font-size: 1rem;
}

monthcell.out-of-month {
  background-color: rgba(255, 255, 255, 0.04);
}

monthcell.out-of-month label {
  color: rgba(255, 255, 255, 0.7);
}

monthcell button {
  padding: 0 6px;
  border-radius: 0;
  border-bottom: none;
  border-right: none;
}

monthpopover > box {
  margin: 0;
  padding: 0;
  background-color: transparent;
}

.notes-section box > textview {
  border-radius: 12px;
  padding: 6px;
}

.notes-section box > textview > text {
  background: none;
}

agenda-view list > row {
  padding: 2px 12px;
}

agenda-view list > label {
  padding: 6px 12px;
}

label.no-events {
  font-style: italic;
}

searchbutton > popover > arrow {
  background: none;
  border: none;
}

menubutton.sources-button {
  margin-top: 0;
  margin-bottom: 0;
  border-radius: 0;
  border-top-style: none;
  border-bottom-style: none;
}

menubutton.sources-button:hover:not(:backdrop) {
  background-image: none;
  text-shadow: none;
}

menubutton.sources-button > button {
  border-radius: 0;
}

menubutton.sources-button > button .title {
  font-size: 10pt;
  font-weight: normal;
  padding: 0 6px;
}

menubutton.sources-button > button .subtitle {
  font-size: 8pt;
  padding: 0 6px;
}

menubutton.sources-button > button .calendar-color-image {
  -gtk-icon-size: 12px;
}

menubutton stack > box {
  border-spacing: 6px;
}

.topbar headerbar menubutton.sources-button > button {
  border-radius: 0 0 12px 12px;
}

agenda-view > scrolledwindow > viewport > list.background {
  background-color: transparent;
}

flowboxchild.card:not(.category-tile) {
  border: none;
  box-shadow: none;
  padding: 0;
  background: none;
}

.card.category-tile {
  padding: 21px;
  border: none;
  border-radius: 12px;
  box-shadow: 0 2px 6px rgba(0, 0, 0, 0.1);
}

.card.category-tile-iconless {
  padding: 9px 15px;
  box-shadow: none;
  background-color: alpha(currentColor, 0.05);
}

app-context-bar > box:not(:first-child) > button.flat {
  border-radius: 0;
}

app-context-bar > box:not(:first-child) > button.flat:last-child {
  border-radius: 0 12px 12px 0;
}

app-context-bar > box:first-child > button.flat {
  border-radius: 0;
}

app-context-bar > box:first-child > button.flat:first-child {
  border-radius: 12px 0 0 12px;
}

app-context-bar > box > button.flat {
  border-left-color: rgba(255, 255, 255, 0.12);
}

carousel.card {
  border: none;
}

.context-tile-lozenge {
  min-height: 28px;
  min-width: 28px;
  padding: 6px;
  margin: 6px;
}

.context-tile-lozenge.grey {
  color: white;
  background-color: rgba(255, 255, 255, 0.12);
}

.context-tile-lozenge.green, .context-tile-lozenge.details-rating-0 {
  color: #4cb168;
  background-color: rgba(129, 201, 149, 0.15);
}

.context-tile-lozenge.blue, .context-tile-lozenge.details-rating-5 {
  color: #1A73E8;
  background-color: rgba(26, 115, 232, 0.15);
}

.context-tile-lozenge.yellow, .context-tile-lozenge.details-rating-12 {
  color: #d79b04;
  background-color: rgba(251, 192, 45, 0.15);
}

.context-tile-lozenge.details-rating-15 {
  color: #F57C00;
  background-color: rgba(245, 124, 0, 0.15);
}

.context-tile-lozenge.red, .context-tile-lozenge.details-rating-18 {
  color: #d2190b;
  background-color: rgba(244, 67, 54, 0.15);
}

screenshot-carousel box.frame.view {
  border-width: 1px 0;
  border-radius: 0;
}

/* Styling for specific category buttons. */
.category-tile.category-create {
  background: linear-gradient(180deg, #ce8cd7 0%, #2861c6 100%);
  color: white;
}

.category-tile.category-create:hover {
  background: linear-gradient(180deg, shade(#ce8cd7, 1.07) 0%, shade(#2861c6, 1.1) 100%);
}

.category-tile.category-create:active {
  background: linear-gradient(180deg, shade(#ce8cd7, 0.95) 0%, shade(#2861c6, 0.95) 100%);
}

.category-tile.category-develop {
  background: #5e5c64;
  color: white;
}

.category-tile.category-develop:hover {
  background: shade(#5e5c64, 1.2);
}

.category-tile.category-develop:active {
  background-color: shade(#5e5c64, 0.95);
}

.category-tile.category-learn {
  background: linear-gradient(180deg, #2ec27e 30%, #27a66c 100%);
  color: white;
}

.category-tile.category-learn:hover {
  background: linear-gradient(180deg, shade(#2ec27e, 1.06) 30%, shade(#27a66c, 1.06) 100%);
}

.category-tile.category-learn:active {
  background: linear-gradient(180deg, shade(#2ec27e, 0.95) 30%, shade(#27a66c, 0.95) 100%);
}

.category-tile.category-play {
  background: linear-gradient(75deg, #f9e2a7 0%, #eb5ec3 50%, #6d53e0 100%);
  color: #393484;
}

.category-tile.category-play:hover {
  background: linear-gradient(75deg, shade(#f9e2a7, 1.07) 0%, shade(#eb5ec3, 1.07) 50%, shade(#6d53e0, 1.07) 100%);
}

.category-tile.category-play:active {
  background: linear-gradient(75deg, shade(#f9e2a7, 0.97) 0%, shade(#eb5ec3, 0.95) 50%, shade(#6d53e0, 1.07) 100%);
}

.category-tile.category-socialize {
  background: linear-gradient(90deg, #ef4e9b 0%, #f77466 100%);
  color: rgba(255, 255, 255, 0.7);
}

.category-tile.category-socialize:hover {
  background: linear-gradient(90deg, shade(#ef4e9b, 1.08) 0%, shade(#f77466, 1.08) 100%);
}

.category-tile.category-socialize:active {
  background: linear-gradient(90deg, shade(#ef4e9b, 0.95) 0%, shade(#f77466, 0.95) 100%);
}

.category-tile.category-work {
  padding: 1px;
  /* FIXME: work around https://gitlab.gnome.org/GNOME/gtk/-/issues/4324 */
  color: #1c71d8;
  background-color: #fdf8d7;
  background-image: linear-gradient(rgba(255, 255, 255, 0.12) 1px, transparent 1px), linear-gradient(90deg, rgba(255, 255, 255, 0.12) 1px, transparent 1px);
  background-size: 10px 10px, 10px 10px;
  background-position: -1px -4px, center -1px;
}

.category-tile.category-work:hover {
  background-color: #fefcef;
  background-image: linear-gradient(rgba(255, 255, 255, 0.12) 1px, transparent 1px), linear-gradient(90deg, rgba(255, 255, 255, 0.12) 1px, transparent 1px);
}

.category-tile.category-work:active {
  background-color: #fcf4bf;
  background-image: linear-gradient(rgba(255, 255, 255, 0.12) 1px, transparent 1px), linear-gradient(90deg, rgba(255, 255, 255, 0.12) 1px, transparent 1px);
}

@define-color weather_temp_chart_fill_color rgba(251, 192, 45, 0.5);
@define-color weather_temp_chart_stroke_color #f0ad05;
@define-color weather_thermometer_warm_color #FBC02D;
@define-color weather_thermometer_cold_color #3281EA;
#places-label {
  font-weight: bold;
}

#temperature-label {
  font-size: 32pt;
  font-weight: 900;
  margin-left: 9px;
}

#conditions-grid *:backdrop {
  color: rgba(255, 255, 255, 0.7);
}

.content-view.cell {
  font-weight: bold;
}

#locationEntry {
  margin: 0;
  padding-bottom: 6px;
}

.weather-popover {
  margin-top: 6px;
}

.forecast-card {
  transition: border-radius 100ms ease-out;
  border-radius: 12px;
}

.forecast-card separator {
  background-color: rgba(255, 255, 255, 0.12);
}

#daily-forecast-box > separator:last-child {
  background-color: transparent;
  min-width: 0;
}

#conditions-grid,
#attributionGrid {
  margin-left: 18px;
  margin-right: 18px;
}

#weather-page .small .forecast-card {
  margin-left: 0;
  margin-right: 0;
  border-radius: 0;
  border-width: 1px 0;
}

.forecast-temperature-label {
  font-weight: bold;
  color: #f0ad05;
}

WeatherThermometer {
  margin-bottom: 12px;
}

WeatherThermometer > label.high {
  font-weight: bold;
  color: #FBC02D;
}

WeatherThermometer > label.low {
  font-weight: bold;
  color: #3281EA;
}

.forecast-button {
  margin: 0 12px;
}

.forecast-graphic {
  margin: 18px;
}

button.osd.circular {
  border-radius: 9999px;
  min-width: 24px;
  min-height: 24px;
}

button.osd.circular > image {
  padding: 0;
}

scrolledwindow.inline list,
scrolledwindow.inline listview {
  background: none;
  color: inherit;
}

scrolledwindow.inline undershoot.top {
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.12);
}

.search-view {
  background-color: #1A73E8;
  color: white;
}

.search-view menubutton button:focus:focus-visible {
  outline-color: rgba(255, 255, 255, 0.3);
}

image.circular {
  min-width: 36px;
  min-height: 36px;
  padding: 0;
  border-radius: 9999px;
}

.polari-room-list .sidebar {
  background: none;
}

.polari-room-list .sidebar > row.activatable:selected {
  background-color: #3281EA;
  color: white;
}

.polari-room-list popover.background > arrow,
.polari-room-list popover.background > contents {
  padding: 0;
}

window.org-gnome-Builder headerbar splitbutton notification button {
  margin: 0;
  min-height: 24px;
  min-width: 24px;
  padding: 0;
}

popover.background.global-search > arrow,
popover.background.global-search > contents {
  padding: 0;
}

panelframeswitcher {
  padding: 6px;
  border-bottom: 1px solid rgba(255, 255, 255, 0.12);
}

panelframetabbar {
  border-bottom: none;
}

.frameheader.header {
  min-height: 24px;
  background-color: rgba(255, 255, 255, 0.04);
}

.frameheader.header > button {
  border: none;
  margin: 0;
  padding: 3px;
}

.frameheader.header tabbar.inline > revealer > box {
  min-height: 24px;
}

.frameheader.header tabbar.inline > revealer > box .start-action {
  padding: 0;
  border: none;
}

.frameheader.header tabbar.inline > revealer > box .end-action {
  padding: 0;
  border-left: 1px solid rgba(255, 255, 255, 0.12);
}

.frameheader.header tabbar.inline > revealer > box .end-action menubutton > button {
  margin: 3px;
  min-height: 24px;
  min-width: 24px;
  padding: 6px;
  border-radius: 12px;
}

.frameheader.header tabbar.inline > revealer > box tabbox {
  border: none;
  background: none;
}

panelstatusbar {
  background-color: #212121;
}

panelstatusbar > menubutton > button,
panelstatusbar > paneltogglebutton button.image-button {
  border-radius: 0;
}

.style-variant {
  padding: 0 12px;
}

.style-variant button.toggle {
  padding: 0;
}

.style-variant button.toggle, .style-variant button.toggle:hover, .style-variant button.toggle:focus, .style-variant button.toggle:active, .style-variant button.toggle:checked {
  background: none;
  outline: none;
  border: none;
  box-shadow: none;
}

.style-variant button.toggle > stylevariantpreview > .wallpaper {
  border-radius: 12px;
  outline-color: transparent;
  outline-width: 3px;
  outline-offset: 3px;
  outline-style: solid;
  box-shadow: none;
}

.style-variant button.toggle:hover > stylevariantpreview > .wallpaper {
  outline-color: rgba(255, 255, 255, 0.04);
}

.style-variant button.toggle:active > stylevariantpreview > .wallpaper {
  outline-color: rgba(255, 255, 255, 0.3);
}

.style-variant button.toggle:checked > stylevariantpreview > .wallpaper {
  outline-color: #3281EA;
}

window.dialog > .dialog-vbox > box > scrolledwindow > viewport > widget > list.boxed-list {
  border: none;
  border-radius: 0;
}

window.dialog > .dialog-vbox > box > scrolledwindow > viewport > widget > list.boxed-list > row:first-child, window.dialog > .dialog-vbox > box > scrolledwindow > viewport > widget > list.boxed-list > row:last-child {
  border-radius: 0;
}

popover.details-popover > contents {
  padding: 12px;
}

button.colorpad {
  padding: 0px;
  margin: 0px;
  background-blend-mode: screen;
  background-image: linear-gradient(45deg, #0f0f0f55 25%, transparent 25%, transparent 75%, #0f0f0f55 75%, #0f0f0f55), linear-gradient(45deg, #0f0f0f55 25%, transparent 25%, transparent 75%, #0f0f0f55 75%, #0f0f0f55);
  background-color: @colorpad_color;
  color: @colorpad_fg_color;
  background-size: 18px 18px;
  background-position: 0px 0px, 9px 9px;
}

button.colorpad:hover {
  filter: brightness(93%);
}

button.colorpad:active {
  filter: brightness(86%);
}

button.colorpad:checked {
  filter: brightness(100%);
}

window#desktopwindow {
  background: none;
}

themeselector,
panelthemeselector {
  margin: 9px;
}

themeselector checkbutton,
panelthemeselector checkbutton {
  padding: 0;
  min-height: 44px;
  min-width: 44px;
  padding: 1px;
  background-clip: content-box;
  border-radius: 9999px;
  box-shadow: inset 0 0 0 1px rgba(255, 255, 255, 0.12);
}

themeselector checkbutton.follow:checked, themeselector checkbutton.light:checked, themeselector checkbutton.dark:checked,
panelthemeselector checkbutton.follow:checked,
panelthemeselector checkbutton.light:checked,
panelthemeselector checkbutton.dark:checked {
  box-shadow: inset 0 0 0 2px #3281EA;
}

themeselector checkbutton.follow,
panelthemeselector checkbutton.follow {
  background-image: linear-gradient(to bottom right, #ffffff 50%, #202020 50%);
}

themeselector checkbutton.light,
panelthemeselector checkbutton.light {
  background-color: #ffffff;
}

themeselector checkbutton.dark,
panelthemeselector checkbutton.dark {
  background-color: #202020;
}

themeselector checkbutton.theme-selector radio,
panelthemeselector checkbutton.theme-selector radio {
  -gtk-icon-source: none;
  border: none;
  background: none;
  box-shadow: none;
  min-height: 20px;
  min-width: 20px;
  padding: 0;
  margin: 0;
}

themeselector checkbutton.theme-selector radio:hover, themeselector checkbutton.theme-selector radio:active, themeselector checkbutton.theme-selector radio:checked,
panelthemeselector checkbutton.theme-selector radio:hover,
panelthemeselector checkbutton.theme-selector radio:active,
panelthemeselector checkbutton.theme-selector radio:checked {
  background-color: transparent;
  background-image: none;
}

themeselector checkbutton.theme-selector radio:checked,
panelthemeselector checkbutton.theme-selector radio:checked {
  -gtk-icon-size: 20px;
  -gtk-icon-source: -gtk-scaled(-gtk-recolor(url("assets/scalable/select-symbolic.svg")), -gtk-recolor(url("assets/scalable/select-symbolic@2.svg")));
  color: white;
  background-color: #3281EA;
}

themeselector checkbutton.theme-selector radio:checked, themeselector checkbutton.theme-selector radio:checked:hover, themeselector checkbutton.theme-selector radio:checked:active,
panelthemeselector checkbutton.theme-selector radio:checked,
panelthemeselector checkbutton.theme-selector radio:checked:hover,
panelthemeselector checkbutton.theme-selector radio:checked:active {
  box-shadow: 0 2px 3px -1px rgba(0, 0, 0, 0.08), 0 1px 2px 0 rgba(0, 0, 0, 0.1);
}

themeswitcher {
  padding: 6px;
}

themeswitcher .check {
  min-height: 20px;
  min-width: 20px;
  background: none;
  padding: 0;
  margin: 0;
  border-radius: 9999px;
  color: white;
  background-color: #3281EA;
}

themeswitcher .check, themeswitcher .check:hover, themeswitcher .check:active {
  box-shadow: 0 2px 3px -1px rgba(0, 0, 0, 0.08), 0 1px 2px 0 rgba(0, 0, 0, 0.1);
}

themeswitcher checkbutton {
  padding: 0;
  min-height: 44px;
  min-width: 44px;
  padding: 1px;
  background-clip: content-box;
  border-radius: 9999px;
  box-shadow: inset 0 0 0 1px rgba(255, 255, 255, 0.12);
}

themeswitcher checkbutton:checked {
  box-shadow: inset 0 0 0 2px #3281EA;
}

themeswitcher checkbutton radio, themeswitcher checkbutton radio:hover, themeswitcher checkbutton radio:active, themeswitcher checkbutton radio:checked, themeswitcher checkbutton radio:checked:hover, themeswitcher checkbutton radio:checked:active {
  background-color: transparent;
  border: none;
  background: none;
  box-shadow: none;
  color: transparent;
  -gtk-icon-source: none;
  -gtk-icon-size: 0;
}

themeswitcher checkbutton.system {
  background: linear-gradient(-45deg, #1e1e1e 50%, white 50%);
}

themeswitcher checkbutton.light {
  color: alpha(black, 0.8);
  background-color: white;
}

themeswitcher checkbutton.dark {
  color: white;
  background-color: #1e1e1e;
}

styleselector checkbutton {
  padding: 0;
  min-height: 44px;
  min-width: 44px;
  padding: 0;
  background-clip: content-box;
  border-radius: 9999px;
  box-shadow: inset 0 0 0 1px rgba(255, 255, 255, 0.12);
}

styleselector checkbutton:hover {
  box-shadow: inset 0 0 0 2px rgba(255, 255, 255, 0.12);
}

styleselector checkbutton:checked {
  box-shadow: inset 0 0 0 2px #3281EA;
}

styleselector checkbutton > radio {
  min-height: 20px;
  min-width: 20px;
  padding: 0;
  margin: 0;
}

styleselector checkbutton > radio, styleselector checkbutton > radio:hover, styleselector checkbutton > radio:focus, styleselector checkbutton > radio:not(:focus) {
  color: transparent;
  border: none;
  background: none;
  box-shadow: none;
  -gtk-icon-source: none;
  -gtk-icon-size: 0;
}

styleselector checkbutton > radio:checked, styleselector checkbutton > radio:checked:hover, styleselector checkbutton > radio:checked:focus, styleselector checkbutton > radio:checked:not(:focus), styleselector checkbutton > radio:active, styleselector checkbutton > radio:active:hover, styleselector checkbutton > radio:active:focus, styleselector checkbutton > radio:active:not(:focus) {
  -gtk-icon-size: 20px;
  -gtk-icon-source: -gtk-scaled(-gtk-recolor(url("assets/scalable/select-symbolic.svg")), -gtk-recolor(url("assets/scalable/select-symbolic@2.svg")));
  color: white;
  background-color: #3281EA;
  box-shadow: 0 2px 3px -1px rgba(0, 0, 0, 0.08), 0 1px 2px 0 rgba(0, 0, 0, 0.1);
}

.note-window headerbar, .note-window headerbar:backdrop {
  box-shadow: none;
}

.note-window.style-yellow, .note-window.style-yellow .text-view.view, .note-window.style-yellow .text-view.view > text, .note-window.style-yellow headerbar {
  background-color: #FBC02D;
  color: rgba(0, 0, 0, 0.87);
}

.note-window.style-yellow * {
  color: rgba(0, 0, 0, 0.87);
}

.note-window.style-yellow .text-view.view > text > selection {
  background-color: rgba(0, 0, 0, 0.26);
}

.note-window.style-yellow popover > arrow,
.note-window.style-yellow popover > contents {
  background-color: #fccf5f;
  color: rgba(0, 0, 0, 0.87);
}

.note-window.style-pink, .note-window.style-pink .text-view.view, .note-window.style-pink .text-view.view > text, .note-window.style-pink headerbar {
  background-color: #F06292;
  color: white;
}

.note-window.style-pink * {
  color: white;
}

.note-window.style-pink .text-view.view > text > selection {
  background-color: rgba(255, 255, 255, 0.3);
}

.note-window.style-pink popover > arrow,
.note-window.style-pink popover > contents {
  background-color: #f491b2;
  color: white;
}

.note-window.style-green, .note-window.style-green .text-view.view, .note-window.style-green .text-view.view > text, .note-window.style-green headerbar {
  background-color: #66BB6A;
  color: white;
}

.note-window.style-green * {
  color: white;
}

.note-window.style-green .text-view.view > text > selection {
  background-color: rgba(255, 255, 255, 0.3);
}

.note-window.style-green popover > arrow,
.note-window.style-green popover > contents {
  background-color: #89cb8c;
  color: white;
}

.note-window.style-purple, .note-window.style-purple .text-view.view, .note-window.style-purple .text-view.view > text, .note-window.style-purple headerbar {
  background-color: #BA68C8;
  color: white;
}

.note-window.style-purple * {
  color: white;
}

.note-window.style-purple .text-view.view > text > selection {
  background-color: rgba(255, 255, 255, 0.3);
}

.note-window.style-purple popover > arrow,
.note-window.style-purple popover > contents {
  background-color: #cb8dd6;
  color: white;
}

.note-window.style-blue, .note-window.style-blue .text-view.view, .note-window.style-blue .text-view.view > text, .note-window.style-blue headerbar {
  background-color: #3281EA;
  color: white;
}

.note-window.style-blue * {
  color: white;
}

.note-window.style-blue .text-view.view > text > selection {
  background-color: rgba(255, 255, 255, 0.3);
}

.note-window.style-blue popover > arrow,
.note-window.style-blue popover > contents {
  background-color: #609def;
  color: white;
}

.note-window.style-gray, .note-window.style-gray .text-view.view, .note-window.style-gray .text-view.view > text, .note-window.style-gray headerbar {
  background-color: #727272;
  color: white;
}

.note-window.style-gray * {
  color: white;
}

.note-window.style-gray .text-view.view > text > selection {
  background-color: rgba(255, 255, 255, 0.3);
}

.note-window.style-gray popover > arrow,
.note-window.style-gray popover > contents {
  background-color: #8c8c8c;
  color: white;
}

.note-window.style-charcoal, .note-window.style-charcoal .text-view.view, .note-window.style-charcoal .text-view.view > text, .note-window.style-charcoal headerbar {
  background-color: #333333;
  color: white;
}

.note-window.style-charcoal * {
  color: white;
}

.note-window.style-charcoal .text-view.view > text > selection {
  background-color: rgba(255, 255, 255, 0.3);
}

.note-window.style-charcoal popover > arrow,
.note-window.style-charcoal popover > contents {
  background-color: #444444;
  color: white;
}

avatar {
  border-radius: 9999px;
  font-weight: bold;
}

avatar.color1 {
  background-image: linear-gradient(#83b6ec, #337fdc);
  color: #cfe1f5;
}

avatar.color2 {
  background-image: linear-gradient(#7ad9f1, #0f9ac8);
  color: #caeaf2;
}

avatar.color3 {
  background-image: linear-gradient(#8de6b1, #29ae74);
  color: #cef8d8;
}

avatar.color4 {
  background-image: linear-gradient(#b5e98a, #6ab85b);
  color: #e6f9d7;
}

avatar.color5 {
  background-image: linear-gradient(#f8e359, #d29d09);
  color: #f9f4e1;
}

avatar.color6 {
  background-image: linear-gradient(#ffcb62, #d68400);
  color: #ffead1;
}

avatar.color7 {
  background-image: linear-gradient(#ffa95a, #ed5b00);
  color: #ffe5c5;
}

avatar.color8 {
  background-image: linear-gradient(#f78773, #e62d42);
  color: #f8d2ce;
}

avatar.color9 {
  background-image: linear-gradient(#e973ab, #e33b6a);
  color: #fac7de;
}

avatar.color10 {
  background-image: linear-gradient(#cb78d4, #9945b5);
  color: #e7c2e8;
}

avatar.color11 {
  background-image: linear-gradient(#9e91e8, #7a59ca);
  color: #d5d2f5;
}

avatar.color12 {
  background-image: linear-gradient(#e3cf9c, #b08952);
  color: #f2eade;
}

avatar.color13 {
  background-image: linear-gradient(#be916d, #785336);
  color: #e5d6ca;
}

avatar.color14 {
  background-image: linear-gradient(#c0bfbc, #6e6d71);
  color: #d8d7d3;
}

avatar.contrasted {
  color: white;
}

avatar.image {
  background: none;
}

splitbutton.suggested-action > button, splitbutton.suggested-action > menubutton > button, splitbutton.destructive-action > button, splitbutton.destructive-action > menubutton > button, splitbutton.opaque > button, splitbutton.opaque > menubutton > button, menubutton.suggested-action > button, menubutton.destructive-action > button, menubutton.opaque > button, button.suggested-action, button.destructive-action, button.opaque {
  box-shadow: none;
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1), box-shadow 225ms cubic-bezier(0, 0, 0.2, 1);
}

.osd splitbutton.suggested-action > button:focus:focus-visible, .osd splitbutton.suggested-action > menubutton > button:focus:focus-visible, .osd splitbutton.destructive-action > button:focus:focus-visible, .osd splitbutton.destructive-action > menubutton > button:focus:focus-visible, .osd splitbutton.opaque > button:focus:focus-visible, .osd splitbutton.opaque > menubutton > button:focus:focus-visible, .osd menubutton.suggested-action > button:focus:focus-visible, .osd menubutton.destructive-action > button:focus:focus-visible, .osd menubutton.opaque > button:focus:focus-visible, .osd button.suggested-action:focus:focus-visible, .osd button.destructive-action:focus:focus-visible, .osd button.opaque:focus:focus-visible {
  outline: none;
}

splitbutton.suggested-action > button:hover, splitbutton.suggested-action > menubutton > button:hover, splitbutton.destructive-action > button:hover, splitbutton.destructive-action > menubutton > button:hover, splitbutton.opaque > button:hover, splitbutton.opaque > menubutton > button:hover, menubutton.suggested-action > button:hover, menubutton.destructive-action > button:hover, menubutton.opaque > button:hover, button.suggested-action:hover, button.destructive-action:hover, button.opaque:hover {
  background-image: image(alpha(currentColor, 0.1));
}

splitbutton.suggested-action > button.keyboard-activating, splitbutton.suggested-action > menubutton > button.keyboard-activating, splitbutton.destructive-action > button.keyboard-activating, splitbutton.destructive-action > menubutton > button.keyboard-activating, splitbutton.opaque > button.keyboard-activating, splitbutton.opaque > menubutton > button.keyboard-activating, menubutton.suggested-action > button.keyboard-activating, menubutton.destructive-action > button.keyboard-activating, menubutton.opaque > button.keyboard-activating, button.keyboard-activating.suggested-action, button.keyboard-activating.destructive-action, button.keyboard-activating.opaque, splitbutton.suggested-action > button:active, splitbutton.suggested-action > menubutton > button:active, splitbutton.destructive-action > button:active, splitbutton.destructive-action > menubutton > button:active, splitbutton.opaque > button:active, splitbutton.opaque > menubutton > button:active, menubutton.suggested-action > button:active, menubutton.destructive-action > button:active, menubutton.opaque > button:active, button.suggested-action:active, button.destructive-action:active, button.opaque:active {
  background-image: image(rgba(0, 0, 0, 0.2));
}

splitbutton.suggested-action > button:checked, splitbutton.suggested-action > menubutton > button:checked, splitbutton.destructive-action > button:checked, splitbutton.destructive-action > menubutton > button:checked, splitbutton.opaque > button:checked, splitbutton.opaque > menubutton > button:checked, menubutton.suggested-action > button:checked, menubutton.destructive-action > button:checked, menubutton.opaque > button:checked, button.suggested-action:checked, button.destructive-action:checked, button.opaque:checked {
  background-image: image(rgba(0, 0, 0, 0.15));
}

splitbutton.suggested-action > button:checked:hover, splitbutton.suggested-action > menubutton > button:checked:hover, splitbutton.destructive-action > button:checked:hover, splitbutton.destructive-action > menubutton > button:checked:hover, splitbutton.opaque > button:checked:hover, splitbutton.opaque > menubutton > button:checked:hover, menubutton.suggested-action > button:checked:hover, menubutton.destructive-action > button:checked:hover, menubutton.opaque > button:checked:hover, button.suggested-action:checked:hover, button.destructive-action:checked:hover, button.opaque:checked:hover {
  background-image: image(rgba(0, 0, 0, 0.05));
}

splitbutton.suggested-action > button:checked.keyboard-activating, splitbutton.suggested-action > menubutton > button:checked.keyboard-activating, splitbutton.destructive-action > button:checked.keyboard-activating, splitbutton.destructive-action > menubutton > button:checked.keyboard-activating, splitbutton.opaque > button:checked.keyboard-activating, splitbutton.opaque > menubutton > button:checked.keyboard-activating, menubutton.suggested-action > button:checked.keyboard-activating, menubutton.destructive-action > button:checked.keyboard-activating, menubutton.opaque > button:checked.keyboard-activating, button.suggested-action:checked.keyboard-activating, button.destructive-action:checked.keyboard-activating, button.opaque:checked.keyboard-activating, splitbutton.suggested-action > button:checked:active, splitbutton.suggested-action > menubutton > button:checked:active, splitbutton.destructive-action > button:checked:active, splitbutton.destructive-action > menubutton > button:checked:active, splitbutton.opaque > button:checked:active, splitbutton.opaque > menubutton > button:checked:active, menubutton.suggested-action > button:checked:active, menubutton.destructive-action > button:checked:active, menubutton.opaque > button:checked:active, button.suggested-action:checked:active, button.destructive-action:checked:active, button.opaque:checked:active {
  background-image: image(rgba(0, 0, 0, 0.3));
}

button.opaque {
  background-color: #4c4c4c;
  color: white;
}

button.destructive-action {
  color: white;
}

button.destructive-action, button.destructive-action:checked {
  background-color: #F44336;
}

button.suggested-action {
  color: white;
}

button.suggested-action, button.suggested-action:checked {
  background-color: #3281EA;
}

button.font separator {
  background-color: transparent;
}

button.font > box {
  border-spacing: 6px;
}

button.font > box > box > label {
  font-weight: bold;
}

menubutton.pill > button, button.pill {
  padding: 10px 32px;
  border-radius: 9999px;
}

button.card {
  background-clip: padding-box;
  font-weight: inherit;
  box-shadow: none;
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1);
}

button.card:hover {
  background-color: alpha(currentColor, 0.08);
}

button.card.keyboard-activating, button.card:active {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1), background-size 0ms, background-image 0ms, border 0ms;
  animation: ripple 225ms cubic-bezier(0, 0, 0.2, 1) forwards;
  background-color: alpha(currentColor, 0.08);
  background-image: radial-gradient(circle, alpha(currentColor, 0.12) 10%, transparent 0%);
  background-size: 100% 100%;
}

button.card:checked {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1), background-size 0ms, background-image 0ms, border 0ms;
  animation: ripple 225ms cubic-bezier(0, 0, 0.2, 1) forwards;
  background-color: alpha(currentColor, 0.08);
  background-image: radial-gradient(circle, alpha(currentColor, 0.12) 10%, transparent 0%);
  background-size: 100% 100%;
}

button.card:drop(active) {
  color: #F57C00;
  box-shadow: inset 0 0 0 1px #F57C00;
}

menubutton.osd {
  background: none;
  color: inherit;
}

menubutton.suggested-action {
  background-color: #3281EA;
  color: white;
}

menubutton.destructive-action {
  background-color: #F44336;
  color: white;
}

menubutton.opaque {
  background-color: #4c4c4c;
  color: white;
}

menubutton.suggested-action, menubutton.destructive-action, menubutton.opaque {
  border-radius: 12px;
}

menubutton.suggested-action.circular, menubutton.suggested-action.pill, menubutton.destructive-action.circular, menubutton.destructive-action.pill, menubutton.opaque.circular, menubutton.opaque.pill {
  border-radius: 9999px;
}

menubutton.suggested-action > button, menubutton.suggested-action > button:checked, menubutton.destructive-action > button, menubutton.destructive-action > button:checked, menubutton.opaque > button, menubutton.opaque > button:checked {
  background-color: transparent;
  color: inherit;
}

menubutton.image-button > button {
  min-width: 24px;
  padding-left: 6px;
  padding-right: 6px;
}

menubutton arrow {
  min-height: 16px;
  min-width: 16px;
}

menubutton arrow.none {
  -gtk-icon-source: -gtk-icontheme("open-menu-symbolic");
}

menubutton arrow.down {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

menubutton arrow.up {
  -gtk-icon-source: -gtk-icontheme("pan-up-symbolic");
}

menubutton arrow.left {
  -gtk-icon-source: -gtk-icontheme("pan-start-symbolic");
}

menubutton arrow.right {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
}

splitbutton {
  border-radius: 12px;
}

splitbutton:disabled {
  filter: none;
  opacity: 1;
}

splitbutton, splitbutton > separator {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1);
  transition-property: background;
}

splitbutton > separator {
  margin-top: 6px;
  margin-bottom: 6px;
  background: none;
}

splitbutton > menubutton > button {
  padding-left: 6px;
  padding-right: 6px;
}

splitbutton.image-button > button {
  min-height: 24px;
  min-width: 24px;
  padding: 6px;
}

splitbutton.text-button.image-button > button, splitbutton.image-text-button > button {
  padding-left: 9px;
  padding-right: 9px;
}

splitbutton.text-button.image-button > button > box, splitbutton.image-text-button > button > box {
  border-spacing: 6px;
}

splitbutton > button:dir(ltr),
splitbutton > menubutton > button:dir(rtl) {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
  margin-right: 0;
}

splitbutton > button:dir(rtl),
splitbutton > menubutton > button:dir(ltr) {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
  margin-left: 0;
}

splitbutton.flat > separator {
  background: rgba(255, 255, 255, 0.12);
}

splitbutton.flat:hover, splitbutton.flat:active, splitbutton.flat:checked {
  background: alpha(currentColor, 0.1);
  color: white;
}

splitbutton.flat:hover > separator, splitbutton.flat:active > separator, splitbutton.flat:checked > separator {
  background: none;
}

splitbutton.flat:focus-within:focus-visible > separator {
  background: none;
}

splitbutton.flat > button,
splitbutton.flat > menubutton > button {
  border-radius: 12px;
}

splitbutton.suggested-action {
  background-color: #3281EA;
  color: white;
}

splitbutton.destructive-action {
  background-color: #F44336;
  color: white;
}

splitbutton.opaque {
  background-color: #4c4c4c;
  color: white;
}

splitbutton.suggested-action > button, splitbutton.suggested-action > button:checked, splitbutton.suggested-action > menubutton > button, splitbutton.suggested-action > menubutton > button:checked, splitbutton.destructive-action > button, splitbutton.destructive-action > button:checked, splitbutton.destructive-action > menubutton > button, splitbutton.destructive-action > menubutton > button:checked, splitbutton.opaque > button, splitbutton.opaque > button:checked, splitbutton.opaque > menubutton > button, splitbutton.opaque > menubutton > button:checked {
  color: inherit;
  background-color: transparent;
}

splitbutton.suggested-action > menubutton > button:dir(ltr), splitbutton.destructive-action > menubutton > button:dir(ltr), splitbutton.opaque > menubutton > button:dir(ltr) {
  box-shadow: inset 1px 0 rgba(255, 255, 255, 0.12);
}

splitbutton.suggested-action > menubutton > button:dir(rtl), splitbutton.destructive-action > menubutton > button:dir(rtl), splitbutton.opaque > menubutton > button:dir(rtl) {
  box-shadow: inset -1px 0 rgba(255, 255, 255, 0.12);
}

splitbutton > menubutton > button > arrow.none {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

buttoncontent {
  border-spacing: 6px;
}

buttoncontent > label {
  font-weight: bold;
}

buttoncontent > label:dir(ltr) {
  padding-right: 2px;
}

buttoncontent > label:dir(rtl) {
  padding-left: 2px;
}

.arrow-button > box > buttoncontent > label:dir(ltr), splitbutton > button > buttoncontent > label:dir(ltr) {
  padding-right: 0;
}

.arrow-button > box > buttoncontent > label:dir(rtl), splitbutton > button > buttoncontent > label:dir(rtl) {
  padding-left: 0;
}

toast {
  margin: 12px;
  margin-bottom: 24px;
  border-radius: 9999px;
  border-spacing: 6px;
  padding: 6px;
  box-shadow: 0 3px 3px -1px rgba(0, 0, 0, 0.2), 0 6px 6px 0 rgba(0, 0, 0, 0.14), 0 1px 11px 0 rgba(0, 0, 0, 0.12), inset 0 1px rgba(255, 255, 255, 0.1);
  color: rgba(255, 255, 255, 0.7);
  font-weight: normal;
}

toast:dir(ltr) {
  padding-left: 12px;
}

toast:dir(rtl) {
  padding-right: 12px;
}

toast > widget {
  margin: 0 6px;
}

statuspage > scrolledwindow > viewport > box {
  margin: 36px 12px;
  border-spacing: 36px;
}

statuspage > scrolledwindow > viewport > box > clamp > box {
  border-spacing: 12px;
}

statuspage > scrolledwindow > viewport > box > clamp > box > .icon {
  -gtk-icon-size: 128px;
  color: alpha(currentColor, 0.45);
}

statuspage > scrolledwindow > viewport > box > clamp > box > .icon:disabled {
  opacity: 0.45;
}

statuspage > scrolledwindow > viewport > box > clamp > box > .icon:not(:last-child) {
  margin-bottom: 24px;
}

statuspage.compact > scrolledwindow > viewport > box {
  margin: 24px 12px;
  border-spacing: 24px;
}

statuspage.compact > scrolledwindow > viewport > box > clamp > box > .icon {
  -gtk-icon-size: 96px;
}

statuspage.compact > scrolledwindow > viewport > box > clamp > box > .icon:not(:last-child) {
  margin-bottom: 12px;
}

statuspage.compact > scrolledwindow > viewport > box > clamp > box > .title {
  font-size: 18pt;
}

.card, list.content,
list.boxed-list, list.boxed-list-separate > row {
  border-radius: 12px;
  box-shadow: none;
  border: 1px solid rgba(255, 255, 255, 0.12);
  background-clip: padding-box;
  background-color: #2C2C2C;
  color: rgba(255, 255, 255, 0.7);
}

preferencespage > scrolledwindow > viewport > clamp > box {
  margin: 24px 12px;
  border-spacing: 24px;
}

preferencesgroup > box, preferencesgroup > box .labels {
  border-spacing: 6px;
}

preferencesgroup > box > box.header:not(.single-line) {
  margin-bottom: 6px;
}

preferencesgroup > box > box.single-line {
  min-height: 36px;
}

preferencesgroup > box button.background-preview-button.toggle {
  padding: 0;
  background: none;
  box-shadow: none;
  outline-color: transparent;
  outline-width: 3px;
  outline-offset: 3px;
  outline-style: solid;
}

preferencesgroup > box button.background-preview-button.toggle, preferencesgroup > box button.background-preview-button.toggle > background-preview {
  border-radius: 6px;
}

preferencesgroup > box button.background-preview-button.toggle:hover {
  outline-color: rgba(255, 255, 255, 0.04);
}

preferencesgroup > box button.background-preview-button.toggle:active {
  outline-color: rgba(255, 255, 255, 0.3);
}

preferencesgroup > box button.background-preview-button.toggle:checked {
  outline-color: #3281EA;
}

preferencesgroup > box flowbox.background-flowbox > flowboxchild {
  outline: 2px solid transparent;
  outline-offset: 0;
  border-radius: 12px;
  padding: 3px;
}

preferencesgroup > box flowbox.background-flowbox > flowboxchild .background-thumbnail {
  border-radius: 9px;
}

preferencesgroup > box flowbox.background-flowbox > flowboxchild:hover {
  outline-color: rgba(255, 255, 255, 0.12);
}

preferencesgroup > box flowbox.background-flowbox > flowboxchild:active {
  outline-color: rgba(255, 255, 255, 0.3);
}

preferencesgroup > box flowbox.background-flowbox > flowboxchild:selected {
  outline-color: #3281EA;
  background-color: transparent;
}

preferencesgroup > box .cutout-button {
  background-color: #3C3C3C;
}

banner > revealer > widget {
  /* There are 2 more instances in _sidebars.css, keep in sync with that */
  background-color: mix(#3281EA,#2C2C2C,0.7);
  color: white;
  padding: 6px;
}

banner > revealer > widget:backdrop {
  background-color: mix(#3281EA,#2C2C2C,0.85);
}

banner > revealer > widget:backdrop > label, banner > revealer > widget:backdrop > button {
  filter: opacity(0.5);
}

viewswitcher {
  border-spacing: 3px;
  min-height: 24px;
}

viewswitcher.narrow {
  margin-top: 0;
  margin-bottom: 0;
  min-height: 6px;
}

headerbar viewswitcher.narrow {
  margin-top: -6px;
  margin-bottom: -6px;
}

viewswitcher.wide {
  border-spacing: 0;
  border-radius: 9999px;
  background-color: rgba(255, 255, 255, 0.04);
}

viewswitcher.wide button.toggle:checked, viewswitcher.wide button.toggle.flat:checked {
  background-color: #3281EA;
  color: white;
}

viewswitcher.wide button.toggle:checked:backdrop, viewswitcher.wide button.toggle.flat:checked:backdrop {
  color: rgba(255, 255, 255, 0.5);
}

viewswitcher.wide button.toggle:checked indicatorbin.needs-attention > indicator, viewswitcher.wide button.toggle.flat:checked indicatorbin.needs-attention > indicator {
  background-color: white;
}

viewswitcher.wide button.toggle:checked indicatorbin.needs-attention > indicator > label, viewswitcher.wide button.toggle.flat:checked indicatorbin.needs-attention > indicator > label {
  color: #3281EA;
}

viewswitcher.narrow button.toggle {
  border-radius: 0;
  border: none;
}

viewswitcher button.toggle {
  font-weight: bold;
  padding: 0;
  min-height: 0;
}

viewswitcher button.toggle > stack > box.narrow {
  font-size: 0.75rem;
  padding-top: 6px;
  padding-bottom: 6px;
  border-spacing: 3px;
}

viewswitcher button.toggle > stack > box.narrow > stack > label {
  padding-left: 8px;
  padding-right: 8px;
}

viewswitcher button.toggle > stack > box.narrow > label {
  min-height: 18px;
  padding-left: 3px;
  padding-right: 3px;
  padding-bottom: 0;
}

viewswitcher button.toggle > stack > box.wide {
  padding: 0 12px;
  border-spacing: 6px;
}

viewswitcherbar actionbar > revealer > box {
  padding: 0;
}

headerbar viewswitchertitle {
  margin-top: -6px;
  margin-bottom: -6px;
}

headerbar viewswitchertitle viewswitcher {
  margin-left: 12px;
  margin-right: 12px;
}

headerbar viewswitchertitle viewswitcher.narrow {
  margin-top: 0;
  margin-bottom: 0;
}

headerbar viewswitchertitle viewswitcher.wide {
  margin-top: 6px;
  margin-bottom: 6px;
}

headerbar viewswitchertitle windowtitle {
  margin-top: 0;
  margin-bottom: 0;
}

indicatorbin > indicator, indicatorbin > mask {
  min-width: 6px;
  min-height: 6px;
  border-radius: 9999px;
}

indicatorbin > indicator {
  margin: 1px;
  padding: 0;
  background: alpha(currentColor, 0.4);
}

indicatorbin > indicator > label {
  font-size: 0.6rem;
  font-weight: bold;
  padding: 2px 5px;
  color: white;
}

indicatorbin > mask {
  padding: 1px;
  background: black;
}

indicatorbin.needs-attention > indicator {
  background-color: #3281EA;
}

indicatorbin.needs-attention > indicator > label {
  color: white;
}

tabbar .box {
  min-height: 28px;
  background-color: #212121;
  color: rgba(255, 255, 255, 0.7);
  padding: 0;
  box-shadow: inset 0 -1px #404040;
  border-bottom: none;
}

tabbar tabbox {
  padding: 0;
  min-height: 28px;
}

tabbar tabbox > tabboxchild {
  border-radius: 0;
  margin: 0;
  padding-top: 4px;
}

tabbar tabbox > separator {
  margin-top: 9px;
  margin-bottom: 9px;
  transition: opacity 150ms ease-in-out;
}

tabbar tabbox > separator.hidden {
  opacity: 0;
}

tabbar tabbox > revealer > indicator {
  min-width: 2px;
  border-radius: 2px;
  margin: 9px 6px;
  background: alpha(#3281EA, 0.5);
}

tabbar tab {
  transition: none;
  border-radius: 12px 12px 0 0;
  border: 1px solid transparent;
  border-bottom-width: 0;
  color: rgba(255, 255, 255, 0.7);
  padding: 6px 12px;
}

tabbar tab:hover:not(:selected):not(:active):not(:checked) {
  transition: none;
  background-color: #404040;
  box-shadow: none;
  color: white;
  border-color: #404040;
  border-radius: 12px 12px 0 0;
}

tabbar tab:selected, tabbar tab:checked, tabbar tab:active {
  transition: background-color 150ms ease-in-out;
  background-color: #2C2C2C;
  box-shadow: none;
  color: white;
  border-color: #404040;
  border-radius: 12px 12px 0 0;
}

tabbar .start-action,
tabbar .end-action {
  padding: 6px;
}

tabbar .start-action:dir(ltr),
tabbar .end-action:dir(rtl) {
  padding-right: 0;
}

tabbar .start-action:dir(rtl),
tabbar .end-action:dir(ltr) {
  padding-left: 0;
}

tabview > stack {
  background-color: #2C2C2C;
}

dnd tab {
  background-color: #212121;
  color: rgba(255, 255, 255, 0.7);
  box-shadow: none;
  margin: 24px;
}

tabbar tab button.image-button,
dnd tab button.image-button {
  padding: 0;
  margin: 0;
  min-width: 20px;
  min-height: 20px;
  border-radius: 9999px;
  border: none;
}

tabbar tab indicator,
dnd tab indicator {
  min-height: 2px;
  border-radius: 2px;
  background: alpha(#3281EA, 0.5);
}

tabview:drop(active),
tabbox:drop(active) {
  box-shadow: none;
}

flap > dimming,
leaflet > dimming,
navigation-view > dimming,
overlay-split-view > dimming {
  background: rgba(0, 0, 0, 0.25);
}

flap > border,
leaflet > border,
navigation-view > border,
overlay-split-view > border {
  background: none;
}

flap > shadow,
leaflet > shadow,
navigation-view > shadow,
overlay-split-view > shadow {
  min-width: 56px;
  min-height: 56px;
}

flap > shadow.left,
leaflet > shadow.left,
navigation-view > shadow.left,
overlay-split-view > shadow.left {
  background-image: linear-gradient(to right, alpha(rgba(0, 0, 0, 0.25), 0.7), alpha(rgba(0, 0, 0, 0.25), 0.14) 40px, alpha(rgba(0, 0, 0, 0.25), 0) 56px), linear-gradient(to right, alpha(rgba(0, 0, 0, 0.25), 0.4), alpha(rgba(0, 0, 0, 0.25), 0.14) 7px, alpha(rgba(0, 0, 0, 0.25), 0) 24px);
}

flap > shadow.right,
leaflet > shadow.right,
navigation-view > shadow.right,
overlay-split-view > shadow.right {
  background-image: linear-gradient(to left, alpha(rgba(0, 0, 0, 0.25), 0.7), alpha(rgba(0, 0, 0, 0.25), 0.14) 40px, alpha(rgba(0, 0, 0, 0.25), 0) 56px), linear-gradient(to left, alpha(rgba(0, 0, 0, 0.25), 0.4), alpha(rgba(0, 0, 0, 0.25), 0.14) 7px, alpha(rgba(0, 0, 0, 0.25), 0) 24px);
}

flap > shadow.up,
leaflet > shadow.up,
navigation-view > shadow.up,
overlay-split-view > shadow.up {
  background-image: linear-gradient(to bottom, alpha(rgba(0, 0, 0, 0.25), 0.7), alpha(rgba(0, 0, 0, 0.25), 0.14) 40px, alpha(rgba(0, 0, 0, 0.25), 0) 56px), linear-gradient(to bottom, alpha(rgba(0, 0, 0, 0.25), 0.4), alpha(rgba(0, 0, 0, 0.25), 0.14) 7px, alpha(rgba(0, 0, 0, 0.25), 0) 24px);
}

flap > shadow.down,
leaflet > shadow.down,
navigation-view > shadow.down,
overlay-split-view > shadow.down {
  background-image: linear-gradient(to top, alpha(rgba(0, 0, 0, 0.25), 0.7), alpha(rgba(0, 0, 0, 0.25), 0.14) 40px, alpha(rgba(0, 0, 0, 0.25), 0) 56px), linear-gradient(to top, alpha(rgba(0, 0, 0, 0.25), 0.4), alpha(rgba(0, 0, 0, 0.25), 0.14) 7px, alpha(rgba(0, 0, 0, 0.25), 0) 24px);
}

toolbarview.undershoot-top scrolledwindow > undershoot.top {
  box-shadow: none;
  background: linear-gradient(to bottom, alpha(rgba(0, 0, 0, 0.25), 0.75), transparent 4px);
}

toolbarview.undershoot-bottom scrolledwindow > undershoot.bottom {
  box-shadow: none;
  background: linear-gradient(to top, alpha(rgba(0, 0, 0, 0.25), 0.75), transparent 4px);
}

navigation-view navigation-view-page .medium stack > button {
  margin-top: 12px;
}

.unfolded stacksidebar.sidebar {
  border: none;
}

.sidebar-pane,
.content-pane .sidebar-pane,
.sidebar-pane .content-pane {
  background-color: #242424;
  color: white;
}

.sidebar-pane:backdrop,
.content-pane .sidebar-pane:backdrop,
.sidebar-pane .content-pane:backdrop {
  background-color: #212121;
  transition: background-color 75ms cubic-bezier(0, 0, 0.2, 1);
}

.sidebar-pane flap > dimming,
.sidebar-pane leaflet > dimming,
.sidebar-pane navigation-view > dimming,
.sidebar-pane overlay-split-view > dimming,
.content-pane .sidebar-pane flap > dimming,
.content-pane .sidebar-pane leaflet > dimming,
.content-pane .sidebar-pane navigation-view > dimming,
.content-pane .sidebar-pane overlay-split-view > dimming,
.sidebar-pane .content-pane flap > dimming,
.sidebar-pane .content-pane leaflet > dimming,
.sidebar-pane .content-pane navigation-view > dimming,
.sidebar-pane .content-pane overlay-split-view > dimming {
  background: rgba(0, 0, 0, 0.25);
}

.sidebar-pane flap > border,
.sidebar-pane leaflet > border,
.sidebar-pane navigation-view > border,
.sidebar-pane overlay-split-view > border,
.content-pane .sidebar-pane flap > border,
.content-pane .sidebar-pane leaflet > border,
.content-pane .sidebar-pane navigation-view > border,
.content-pane .sidebar-pane overlay-split-view > border,
.sidebar-pane .content-pane flap > border,
.sidebar-pane .content-pane leaflet > border,
.sidebar-pane .content-pane navigation-view > border,
.sidebar-pane .content-pane overlay-split-view > border {
  background: none;
}

.sidebar-pane flap > shadow,
.sidebar-pane leaflet > shadow,
.sidebar-pane navigation-view > shadow,
.sidebar-pane overlay-split-view > shadow,
.content-pane .sidebar-pane flap > shadow,
.content-pane .sidebar-pane leaflet > shadow,
.content-pane .sidebar-pane navigation-view > shadow,
.content-pane .sidebar-pane overlay-split-view > shadow,
.sidebar-pane .content-pane flap > shadow,
.sidebar-pane .content-pane leaflet > shadow,
.sidebar-pane .content-pane navigation-view > shadow,
.sidebar-pane .content-pane overlay-split-view > shadow {
  min-width: 56px;
  min-height: 56px;
}

.sidebar-pane flap > shadow.left,
.sidebar-pane leaflet > shadow.left,
.sidebar-pane navigation-view > shadow.left,
.sidebar-pane overlay-split-view > shadow.left,
.content-pane .sidebar-pane flap > shadow.left,
.content-pane .sidebar-pane leaflet > shadow.left,
.content-pane .sidebar-pane navigation-view > shadow.left,
.content-pane .sidebar-pane overlay-split-view > shadow.left,
.sidebar-pane .content-pane flap > shadow.left,
.sidebar-pane .content-pane leaflet > shadow.left,
.sidebar-pane .content-pane navigation-view > shadow.left,
.sidebar-pane .content-pane overlay-split-view > shadow.left {
  background-image: linear-gradient(to right, alpha(rgba(0, 0, 0, 0.25), 0.7), alpha(rgba(0, 0, 0, 0.25), 0.14) 40px, alpha(rgba(0, 0, 0, 0.25), 0) 56px), linear-gradient(to right, alpha(rgba(0, 0, 0, 0.25), 0.4), alpha(rgba(0, 0, 0, 0.25), 0.14) 7px, alpha(rgba(0, 0, 0, 0.25), 0) 24px);
}

.sidebar-pane flap > shadow.right,
.sidebar-pane leaflet > shadow.right,
.sidebar-pane navigation-view > shadow.right,
.sidebar-pane overlay-split-view > shadow.right,
.content-pane .sidebar-pane flap > shadow.right,
.content-pane .sidebar-pane leaflet > shadow.right,
.content-pane .sidebar-pane navigation-view > shadow.right,
.content-pane .sidebar-pane overlay-split-view > shadow.right,
.sidebar-pane .content-pane flap > shadow.right,
.sidebar-pane .content-pane leaflet > shadow.right,
.sidebar-pane .content-pane navigation-view > shadow.right,
.sidebar-pane .content-pane overlay-split-view > shadow.right {
  background-image: linear-gradient(to left, alpha(rgba(0, 0, 0, 0.25), 0.7), alpha(rgba(0, 0, 0, 0.25), 0.14) 40px, alpha(rgba(0, 0, 0, 0.25), 0) 56px), linear-gradient(to left, alpha(rgba(0, 0, 0, 0.25), 0.4), alpha(rgba(0, 0, 0, 0.25), 0.14) 7px, alpha(rgba(0, 0, 0, 0.25), 0) 24px);
}

.sidebar-pane flap > shadow.up,
.sidebar-pane leaflet > shadow.up,
.sidebar-pane navigation-view > shadow.up,
.sidebar-pane overlay-split-view > shadow.up,
.content-pane .sidebar-pane flap > shadow.up,
.content-pane .sidebar-pane leaflet > shadow.up,
.content-pane .sidebar-pane navigation-view > shadow.up,
.content-pane .sidebar-pane overlay-split-view > shadow.up,
.sidebar-pane .content-pane flap > shadow.up,
.sidebar-pane .content-pane leaflet > shadow.up,
.sidebar-pane .content-pane navigation-view > shadow.up,
.sidebar-pane .content-pane overlay-split-view > shadow.up {
  background-image: linear-gradient(to bottom, alpha(rgba(0, 0, 0, 0.25), 0.7), alpha(rgba(0, 0, 0, 0.25), 0.14) 40px, alpha(rgba(0, 0, 0, 0.25), 0) 56px), linear-gradient(to bottom, alpha(rgba(0, 0, 0, 0.25), 0.4), alpha(rgba(0, 0, 0, 0.25), 0.14) 7px, alpha(rgba(0, 0, 0, 0.25), 0) 24px);
}

.sidebar-pane flap > shadow.down,
.sidebar-pane leaflet > shadow.down,
.sidebar-pane navigation-view > shadow.down,
.sidebar-pane overlay-split-view > shadow.down,
.content-pane .sidebar-pane flap > shadow.down,
.content-pane .sidebar-pane leaflet > shadow.down,
.content-pane .sidebar-pane navigation-view > shadow.down,
.content-pane .sidebar-pane overlay-split-view > shadow.down,
.sidebar-pane .content-pane flap > shadow.down,
.sidebar-pane .content-pane leaflet > shadow.down,
.sidebar-pane .content-pane navigation-view > shadow.down,
.sidebar-pane .content-pane overlay-split-view > shadow.down {
  background-image: linear-gradient(to top, alpha(rgba(0, 0, 0, 0.25), 0.7), alpha(rgba(0, 0, 0, 0.25), 0.14) 40px, alpha(rgba(0, 0, 0, 0.25), 0) 56px), linear-gradient(to top, alpha(rgba(0, 0, 0, 0.25), 0.4), alpha(rgba(0, 0, 0, 0.25), 0.14) 7px, alpha(rgba(0, 0, 0, 0.25), 0) 24px);
}

.sidebar-pane banner > revealer > widget,
.content-pane .sidebar-pane banner > revealer > widget,
.sidebar-pane .content-pane banner > revealer > widget {
  background-color: mix(#3281EA,#242424,0.7);
  color: white;
}

.sidebar-pane banner > revealer > widget:backdrop,
.content-pane .sidebar-pane banner > revealer > widget:backdrop,
.sidebar-pane .content-pane banner > revealer > widget:backdrop {
  background-color: mix(#3281EA,#242424,0.7);
}

.sidebar-pane:dir(ltr), .sidebar-pane:dir(ltr) banner > revealer > widget, .sidebar-pane.end:dir(rtl), .sidebar-pane.end:dir(rtl) banner > revealer > widget,
.content-pane .sidebar-pane:dir(ltr),
.content-pane .sidebar-pane:dir(ltr) banner > revealer > widget,
.content-pane .sidebar-pane.end:dir(rtl),
.content-pane .sidebar-pane.end:dir(rtl) banner > revealer > widget,
.sidebar-pane .content-pane:dir(ltr),
.sidebar-pane .content-pane:dir(ltr) banner > revealer > widget,
.sidebar-pane .content-pane.end:dir(rtl),
.sidebar-pane .content-pane.end:dir(rtl) banner > revealer > widget {
  box-shadow: none;
  border-right: 1px solid rgba(255, 255, 255, 0.12);
}

.sidebar-pane:dir(rtl), .sidebar-pane:dir(rtl) banner > revealer > widget, .sidebar-pane.end:dir(ltr), .sidebar-pane.end:dir(ltr) banner > revealer > widget,
.content-pane .sidebar-pane:dir(rtl),
.content-pane .sidebar-pane:dir(rtl) banner > revealer > widget,
.content-pane .sidebar-pane.end:dir(ltr),
.content-pane .sidebar-pane.end:dir(ltr) banner > revealer > widget,
.sidebar-pane .content-pane:dir(rtl),
.sidebar-pane .content-pane:dir(rtl) banner > revealer > widget,
.sidebar-pane .content-pane.end:dir(ltr),
.sidebar-pane .content-pane.end:dir(ltr) banner > revealer > widget {
  box-shadow: none;
  border-left: 1px solid rgba(255, 255, 255, 0.12);
}

.sidebar-pane .sidebar-pane {
  background-color: transparent;
  color: inherit;
}

.sidebar-pane .top-bar,
.sidebar-pane .sidebar,
.sidebar-pane .toolbar,
.sidebar-pane .navigation-sidebar,
.sidebar-pane searchbar > revealer > box {
  background-color: transparent;
  box-shadow: none;
  border: none;
}

.sidebar-pane headerbar {
  border-top-right-radius: 0;
}

.sidebar-pane headerbar, .sidebar-pane headerbar:backdrop {
  background-color: transparent;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
}

window.maximized .sidebar-pane headerbar, window.tiled .sidebar-pane headerbar {
  box-shadow: none;
}

.content-pane, .content-pane:backdrop {
  background-color: #212121;
}

.content-pane headerbar {
  color: white;
  border-top-left-radius: 0;
}

.content-pane headerbar, .content-pane headerbar:backdrop {
  background-color: transparent;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
}

.content-pane headerbar .subtitle,
.content-pane headerbar .dim-label,
.content-pane headerbar entry > text > placeholder,
.content-pane headerbar entry > text > placeholder,
.content-pane headerbar row.property > box.header > box.title > .title,
.content-pane headerbar row.expander:not(:checked) image.expander-row-arrow,
row.expander:not(:checked) .content-pane headerbar image.expander-row-arrow {
  color: rgba(255, 255, 255, 0.7);
}

.content-pane headerbar .subtitle:backdrop,
.content-pane headerbar .dim-label:backdrop,
.content-pane headerbar entry > text > placeholder:backdrop,
.content-pane headerbar entry > text > placeholder:backdrop,
.content-pane headerbar row.property > box.header > box.title > .title:backdrop,
.content-pane headerbar row.expander:not(:checked) image.expander-row-arrow:backdrop,
row.expander:not(:checked) .content-pane headerbar image.expander-row-arrow:backdrop {
  color: rgba(255, 255, 255, 0.5);
}

.content-pane headerbar viewswitcher.wide {
  background-color: rgba(255, 255, 255, 0.04);
}

window.maximized .content-pane headerbar, window.tiled .content-pane headerbar {
  box-shadow: none;
}

.sidebar-pane toolbarview.undershoot-top:not(.view) scrolledwindow > undershoot.top,
.content-pane toolbarview.undershoot-top:not(.view) scrolledwindow > undershoot.top {
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.12);
  background: linear-gradient(to bottom, alpha(rgba(0, 0, 0, 0.25), 0.75), transparent 4px);
}

.sidebar-pane toolbarview.undershoot-bottom:not(.view) scrolledwindow > undershoot.bottom,
.content-pane toolbarview.undershoot-bottom:not(.view) scrolledwindow > undershoot.bottom {
  box-shadow: inset 0 -1px rgba(255, 255, 255, 0.12);
  background: linear-gradient(to top, alpha(rgba(0, 0, 0, 0.25), 0.75), transparent 4px);
}

.sidebar-pane scrolledwindow.undershoot-top > undershoot.top,
.content-pane scrolledwindow.undershoot-top > undershoot.top {
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.12);
  background: linear-gradient(to bottom, alpha(rgba(0, 0, 0, 0.25), 0.75), transparent 4px);
}

.sidebar-pane scrolledwindow.undershoot-bottom > undershoot.bottom,
.content-pane scrolledwindow.undershoot-bottom > undershoot.bottom {
  box-shadow: inset 0 -1px rgba(255, 255, 255, 0.12);
  background: linear-gradient(to top, alpha(rgba(0, 0, 0, 0.25), 0.75), transparent 4px);
}

.sidebar-pane scrolledwindow.undershoot-start:dir(ltr) > undershoot.left,
.content-pane scrolledwindow.undershoot-start:dir(ltr) > undershoot.left {
  box-shadow: inset 1px 0 rgba(255, 255, 255, 0.12);
  background: linear-gradient(to right, alpha(rgba(0, 0, 0, 0.25), 0.75), transparent 4px);
}

.sidebar-pane scrolledwindow.undershoot-start:dir(rtl) > undershoot.right,
.content-pane scrolledwindow.undershoot-start:dir(rtl) > undershoot.right {
  box-shadow: inset -1px 0 rgba(255, 255, 255, 0.12);
  background: linear-gradient(to left, alpha(rgba(0, 0, 0, 0.25), 0.75), transparent 4px);
}

.sidebar-pane scrolledwindow.undershoot-end:dir(ltr) > undershoot.right,
.content-pane scrolledwindow.undershoot-end:dir(ltr) > undershoot.right {
  box-shadow: inset -1px 0 rgba(255, 255, 255, 0.12);
  background: linear-gradient(to left, alpha(rgba(0, 0, 0, 0.25), 0.75), transparent 4px);
}

.sidebar-pane scrolledwindow.undershoot-end:dir(rtl) > undershoot.left,
.content-pane scrolledwindow.undershoot-end:dir(rtl) > undershoot.left {
  box-shadow: inset 1px 0 rgba(255, 255, 255, 0.12);
  background: linear-gradient(to right, alpha(rgba(0, 0, 0, 0.25), 0.75), transparent 4px);
}

toolbarview > .top-bar searchbar > revealer > box,
toolbarview > .bottom-bar searchbar > revealer > box {
  background-color: transparent;
  box-shadow: none;
}

toolbarview > .top-bar actionbar > revealer > box,
toolbarview > .bottom-bar actionbar > revealer > box {
  background-color: transparent;
  border: none;
  box-shadow: none;
}

toolbarview > .top-bar .toolbar,
toolbarview > .bottom-bar .toolbar {
  background-color: transparent;
  padding: 0 0 0 6px;
  border-spacing: 0;
}

toolbarview > .top-bar .collapse-spacing,
toolbarview > .bottom-bar .collapse-spacing {
  padding-top: 0;
  padding-bottom: 0;
}

toolbarview > .top-bar .collapse-spacing headerbar,
toolbarview > .bottom-bar .collapse-spacing headerbar {
  min-height: 48px;
}

toolbarview > .top-bar .collapse-spacing headerbar > windowhandle > box,
toolbarview > .bottom-bar .collapse-spacing headerbar > windowhandle > box {
  padding-top: 6px;
  padding-bottom: 6px;
}

toolbarview > .top-bar .collapse-spacing headerbar.default-decoration,
toolbarview > .bottom-bar .collapse-spacing headerbar.default-decoration {
  min-height: 24px;
}

toolbarview > .top-bar .collapse-spacing headerbar.default-decoration > windowhandle > box,
toolbarview > .bottom-bar .collapse-spacing headerbar.default-decoration > windowhandle > box {
  padding-top: 6px;
  padding-bottom: 6px;
}

toolbarview > .top-bar .collapse-spacing searchbar > revealer > box,
toolbarview > .top-bar .collapse-spacing actionbar > revealer > box,
toolbarview > .bottom-bar .collapse-spacing searchbar > revealer > box,
toolbarview > .bottom-bar .collapse-spacing actionbar > revealer > box {
  padding-top: 6px;
  padding-bottom: 6px;
}

toolbarview > .top-bar .collapse-spacing .toolbar,
toolbarview > .bottom-bar .collapse-spacing .toolbar {
  padding-top: 6px;
  padding-bottom: 6px;
}

toolbarview > .top-bar .collapse-spacing tabbar,
toolbarview > .bottom-bar .collapse-spacing tabbar {
  padding-top: 0;
  padding-bottom: 0;
}

toolbarview > .top-bar.raised,
toolbarview > .bottom-bar.raised {
  background-color: transparent;
  color: white;
}

toolbarview > .top-bar.raised:backdrop,
toolbarview > .bottom-bar.raised:backdrop {
  background-color: transparent;
}

toolbarview > .top-bar:backdrop > windowhandle,
toolbarview > .bottom-bar:backdrop > windowhandle {
  filter: none;
}

toolbarview .top-bar {
  box-shadow: none;
  background-color: #2C2C2C;
}

toolbarview .top-bar:backdrop {
  background-color: #3C3C3C;
}

.info toolbarview .top-bar, .info toolbarview .top-bar:backdrop, .about toolbarview .top-bar, .about toolbarview .top-bar:backdrop {
  background-color: transparent;
}

tabview toolbarview .top-bar, tabview toolbarview .top-bar:backdrop {
  background-color: #2C2C2C;
}

toolbarview .top-bar .collapse-spacing {
  padding: 0;
}

toolbarview .top-bar windowhandle {
  filter: none;
}

toolbarview > .bottom-bar {
  padding: 0;
  border-spacing: 0;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.12);
  background-color: #242424;
  color: white;
}

toolbarview > .bottom-bar:backdrop {
  background-color: #212121;
  color: rgba(255, 255, 255, 0.5);
}

toolbarview > .bottom-bar actionbar > revealer > box {
  background-color: transparent;
  color: inherit;
  box-shadow: none;
  padding-top: 6px;
}

toolbarview > .bottom-bar actionbar > revealer > box:backdrop {
  background-color: transparent;
  transition: none;
}

toolbarview > .bottom-bar actionbar > revealer > box:backdrop > * {
  filter: none;
  transition: none;
}

toolbarview > .top-bar.raised {
  box-shadow: none;
}

toolbarview > .top-bar.raised.border {
  box-shadow: none;
}

toolbarview > .bottom-bar.raised {
  box-shadow: none;
}

toolbarview > .bottom-bar.raised.border {
  box-shadow: none;
}

.sidebar-pane .top-bar,
.sidebar-pane .bottom-bar,
.sidebar-pane .top-bar:backdrop,
.sidebar-pane .bottom-bar:backdrop,
.content-pane .top-bar,
.content-pane .bottom-bar,
.content-pane .top-bar:backdrop,
.content-pane .bottom-bar:backdrop {
  background-color: transparent;
  box-shadow: none;
}

floating-sheet > dimming {
  background-color: rgba(0, 0, 0, 0.25);
}

floating-sheet > sheet.background {
  box-shadow: 0 8px 6px -5px rgba(0, 0, 0, 0.2), 0 16px 16px 2px rgba(0, 0, 0, 0.14), 0 6px 18px 5px rgba(0, 0, 0, 0.12);
  border-radius: 18px;
  outline: none;
}

/* GTK NAMED COLORS
   ----------------
   use responsibly! */
/*
widget text/foreground color */
@define-color theme_fg_color white;
/*
text color for entries, views and content in general */
@define-color theme_text_color white;
/*
widget base background color */
@define-color theme_bg_color #212121;
/*
text widgets and the like base background color */
@define-color theme_base_color #2C2C2C;
/*
base background color of selections */
@define-color theme_selected_bg_color #3281EA;
/*
text/foreground color of selections */
@define-color theme_selected_fg_color white;
/*
base background color of insensitive widgets */
@define-color insensitive_bg_color #212121;
/*
text foreground color of insensitive widgets */
@define-color insensitive_fg_color rgba(255, 255, 255, 0.5);
/*
insensitive text widgets and the like base background color */
@define-color insensitive_base_color #242424;
/*
widget text/foreground color on backdrop windows */
@define-color theme_unfocused_fg_color white;
/*
text color for entries, views and content in general on backdrop windows */
@define-color theme_unfocused_text_color white;
/*
widget base background color on backdrop windows */
@define-color theme_unfocused_bg_color #212121;
/*
text widgets and the like base background color on backdrop windows */
@define-color theme_unfocused_base_color #2C2C2C;
/*
base background color of selections on backdrop windows */
@define-color theme_unfocused_selected_bg_color #3281EA;
/*
text/foreground color of selections on backdrop windows */
@define-color theme_unfocused_selected_fg_color white;
/*
insensitive color on backdrop windows */
@define-color unfocused_insensitive_color rgba(255, 255, 255, 0.5);
/*
widgets main borders color */
@define-color borders rgba(255, 255, 255, 0.12);
/*
widgets main borders color on backdrop windows */
@define-color unfocused_borders rgba(255, 255, 255, 0.12);
/*
these are pretty self explicative */
@define-color warning_color #FBC02D;
@define-color error_color #F44336;
@define-color success_color #81C995;
/*
these colors are exported for the window manager and shouldn't be used in applications,
read if you used those and something break with a version upgrade you're on your own... */
@define-color wm_title white;
@define-color wm_unfocused_title rgba(255, 255, 255, 0.7);
@define-color wm_highlight rgba(255, 255, 255, 0.1);
@define-color wm_bg #2C2C2C;
@define-color wm_unfocused_bg #3C3C3C;
/*
FIXME this is really an API */
@define-color content_view_bg #2C2C2C;
@define-color placeholder_text_color silver;
/* Very contrasty background for text views (@theme_text_color foreground) */
@define-color text_view_bg #1d1d1d;
@define-color budgie_tasklist_indicator_color rgba(255, 255, 255, 0.7);
@define-color budgie_tasklist_indicator_color_active #3281EA;
@define-color budgie_tasklist_indicator_color_active_window rgba(44, 93, 160, 0.8075);
@define-color budgie_tasklist_indicator_color_attention #FBC02D;
@define-color STRAWBERRY_100 #FF9262;
@define-color STRAWBERRY_300 #FF793E;
@define-color STRAWBERRY_500 #F15D22;
@define-color STRAWBERRY_700 #CF3B00;
@define-color STRAWBERRY_900 #AC1800;
@define-color ORANGE_100 #FFDB91;
@define-color ORANGE_300 #FFCA40;
@define-color ORANGE_500 #FAA41A;
@define-color ORANGE_700 #DE8800;
@define-color ORANGE_900 #C26C00;
@define-color BANANA_100 #FFFFA8;
@define-color BANANA_300 #FFFA7D;
@define-color BANANA_500 #FFCE51;
@define-color BANANA_700 #D1A023;
@define-color BANANA_900 #A27100;
@define-color LIME_100 #A2F3BE;
@define-color LIME_300 #8ADBA6;
@define-color LIME_500 #73C48F;
@define-color LIME_700 #479863;
@define-color LIME_900 #1C6D38;
@define-color BLUEBERRY_100 #94A6FF;
@define-color BLUEBERRY_300 #6A7CE0;
@define-color BLUEBERRY_500 #3F51B5;
@define-color BLUEBERRY_700 #213397;
@define-color BLUEBERRY_900 #031579;
@define-color GRAPE_100 #D25DE6;
@define-color GRAPE_300 #B84ACB;
@define-color GRAPE_500 #9C27B0;
@define-color GRAPE_700 #830E97;
@define-color GRAPE_900 #6A007E;
@define-color COCOA_100 #9F9792;
@define-color COCOA_300 #7B736E;
@define-color COCOA_500 #574F4A;
@define-color COCOA_700 #463E39;
@define-color COCOA_900 #342C27;
@define-color SILVER_100 #EEE;
@define-color SILVER_300 #CCC;
@define-color SILVER_500 #AAA;
@define-color SILVER_700 #888;
@define-color SILVER_900 #666;
@define-color SLATE_100 #888;
@define-color SLATE_300 #666;
@define-color SLATE_500 #444;
@define-color SLATE_700 #222;
@define-color SLATE_900 #111;
@define-color BLACK_100 #474341;
@define-color BLACK_300 #403C3A;
@define-color BLACK_500 #393634;
@define-color BLACK_700 #33302F;
@define-color BLACK_900 #2B2928;
